package org.broadinstitute.hellbender.tools.funcotator.dataSources.gencode;

import java.util.Arrays;
import java.util.List;

/**
 * A simple holder class for MNP data providers for the MUC16 gene.
 * These cases were pulled directly from Oncotator (MUC16ChangeTestdata.py).
 * Created by jonn on 9/21/17.
 */
public class DataProviderForMuc16MnpFullData {
    static List<Object[]> provideMnpDataForMuc16_1() {
        return Arrays.asList(
                new Object[]{"MUC16", 19, 9091811, 9091811, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091811G>A", "-", "c.4C>T", "c.(4-6)Ctg>Ttg", "p.L2L"},
                new Object[]{"MUC16", 19, 9091812, 9091812, GencodeFuncotation.VariantClassification.START_CODON_SNP, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9091812C>A", "-", "c.3G>T", "c.(1-3)atG>atT", "p.M1I"},
                new Object[]{"MUC16", 19, 9091813, 9091813, GencodeFuncotation.VariantClassification.START_CODON_SNP, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9091813A>G", "-", "c.2T>C", "c.(1-3)aTg>aCg", "p.M1T"},
                new Object[]{"MUC16", 19, 9091814, 9091814, GencodeFuncotation.VariantClassification.START_CODON_SNP, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9091814T>A", "-", "c.1A>T", "c.(1-3)Atg>Ttg", "p.M1L"},
                new Object[]{"MUC16", 19, 9091815, 9091815, GencodeFuncotation.VariantClassification.FIVE_PRIME_UTR, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091815G>A", "-", null, null, null},
                new Object[]{"MUC16", 19, 8959605, 8959605, GencodeFuncotation.VariantClassification.THREE_PRIME_UTR, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8959605C>A", "-", null, null, null},
                new Object[]{"MUC16", 19, 8959606, 8959606, GencodeFuncotation.VariantClassification.THREE_PRIME_UTR, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:8959606A>G", "-", null, null, null},
                new Object[]{"MUC16", 19, 8959607, 8959607, GencodeFuncotation.VariantClassification.THREE_PRIME_UTR, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8959607G>A", "-", null, null, null},
                new Object[]{"MUC16", 19, 8959611, 8959611, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:8959611T>A", "-", "c.43521A>T", "c.(43519-43521)caA>caT", "p.Q14507H"},
                // Had to change gt transcript change.  Had to change protein change for proper codon
                new Object[]{"MUC16", 19, 9002672, 9002672, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9002672G>A", "-", "c.40144C>T", "c.(40144-40146)Cct>Tct", "p.P13382S"},
                // Had to change GT for the protein change, since this is an intron splice site.
                new Object[]{"MUC16", 19, 8994416, 8994416, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8994416C>T", "-", "c.e64-1G>A", "c.e64+1", null},
                // Had to change GT for the transcript change
                new Object[]{"MUC16", 19, 9008345, 9008345, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9008345C>T", "-", "c.39207G>A", "c.(39205-39207)agG>agA", "p.R13069R"},
                // Had to change GT for the protein change, since this is an intron splice site.
                new Object[]{"MUC16", 19, 9050244, 9050244, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050244C>A", "-", "c.e5+1G>T", "c.e5-1", null},
                new Object[]{"MUC16", 19, 9057555, 9057555, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9057555C>A", "-", "c.29891G>T", "c.(29890-29892)gGg>gTg", "p.G9964V"},
                new Object[]{"MUC16", 19, 9064688, 9064688, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9064688G>T", "-", "c.22758C>A", "c.(22756-22758)tcC>tcA", "p.S7586S"},
                new Object[]{"MUC16", 19, 9067291, 9067291, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067291G>T", "-", "c.20155C>A", "c.(20155-20157)Ccc>Acc", "p.P6719T"},
                new Object[]{"MUC16", 19, 9071155, 9071155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071155C>A", "-", "c.16291G>T", "c.(16291-16293)Ggg>Tgg", "p.G5431W"},
                new Object[]{"MUC16", 19, 9047571, 9047571, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047571G>A", "-", "c.34060C>T", "c.(34060-34062)Cct>Tct", "p.P11354S"},
                new Object[]{"MUC16", 19, 9075901, 9075901, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9075901T>C", "-", "c.11545A>G", "c.(11545-11547)Act>Gct", "p.T3849A"},
                new Object[]{"MUC16", 19, 9064628, 9064628, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064628C>T", "-", "c.22818G>A", "c.(22816-22818)agG>agA", "p.R7606R"},
                new Object[]{"MUC16", 19, 9076673, 9076673, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9076673G>T", "-", "c.10773C>A", "c.(10771-10773)tcC>tcA", "p.S3591S"},
                new Object[]{"MUC16", 19, 9076914, 9076914, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9076914G>T", "-", "c.10532C>A", "c.(10531-10533)cCt>cAt", "p.P3511H"},
                new Object[]{"MUC16", 19, 9083281, 9083281, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083281G>A", "-", "c.8534C>T", "c.(8533-8535)cCc>cTc", "p.P2845L"},
                new Object[]{"MUC16", 19, 9087200, 9087200, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087200G>T", "-", "c.4615C>A", "c.(4615-4617)Cca>Aca", "p.P1539T"},
                new Object[]{"MUC16", 19, 9088334, 9088334, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088334G>A", "-", "c.3481C>T", "c.(3481-3483)Cct>Tct", "p.P1161S"},
                new Object[]{"MUC16", 19, 9018458, 9018458, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9018458A>T", "-", "c.37716T>A", "c.(37714-37716)acT>acA", "p.T12572T"},
                new Object[]{"MUC16", 19, 9063777, 9063777, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9063777C>A", "-", "c.23669G>T", "c.(23668-23670)tGg>tTg", "p.W7890L"},
                new Object[]{"MUC16", 19, 9071965, 9071965, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071965C>A", "-", "c.15481G>T", "c.(15481-15483)Gga>Tga", "p.G5161*"},
                new Object[]{"MUC16", 19, 9073131, 9073131, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073131G>A", "-", "c.14315C>T", "c.(14314-14316)cCt>cTt", "p.P4772L"},
                new Object[]{"MUC16", 19, 9073306, 9073306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9073306C>A", "-", "c.14140G>T", "c.(14140-14142)Ggg>Tgg", "p.G4714W"},
                new Object[]{"MUC16", 19, 9077387, 9077387, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077387C>T", "-", "c.10059G>A", "c.(10057-10059)ggG>ggA", "p.G3353G"},
                new Object[]{"MUC16", 19, 9083555, 9083555, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9083555C>A", "-", "c.8260G>T", "c.(8260-8262)Gga>Tga", "p.G2754*"},
                new Object[]{"MUC16", 19, 9090344, 9090344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9090344C>A", "-", "c.1471G>T", "c.(1471-1473)Ggg>Tgg", "p.G491W"},
                new Object[]{"MUC16", 19, 9005597, 9005597, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9005597C>T", "-", "c.39809G>A", "c.(39808-39810)gGa>gAa", "p.G13270E"},
                new Object[]{"MUC16", 19, 9046505, 9046505, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046505G>A", "-", "c.35126C>T", "c.(35125-35127)tCc>tTc", "p.S11709F"},
                new Object[]{"MUC16", 19, 9046965, 9046965, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046965C>T", "-", "c.34666G>A", "c.(34666-34668)Gac>Aac", "p.D11556N"},
                new Object[]{"MUC16", 19, 9047228, 9047228, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047228C>A", "-", "c.34403G>T", "c.(34402-34404)gGg>gTg", "p.G11468V"},
                new Object[]{"MUC16", 19, 9050038, 9050038, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9050038G>A", "-", "c.31593C>T", "c.(31591-31593)ttC>ttT", "p.F10531F"},
                new Object[]{"MUC16", 19, 9066659, 9066659, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066659G>T", "-", "c.20787C>A", "c.(20785-20787)tcC>tcA", "p.S6929S"},
                new Object[]{"MUC16", 19, 9067654, 9067654, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067654C>A", "-", "c.19792G>T", "c.(19792-19794)Ggg>Tgg", "p.G6598W"},
                new Object[]{"MUC16", 19, 9068209, 9068209, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9068209C>A", "-", "c.19237G>T", "c.(19237-19239)Ggc>Tgc", "p.G6413C"},
                new Object[]{"MUC16", 19, 9068327, 9068327, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068327G>A", "-", "c.19119C>T", "c.(19117-19119)acC>acT", "p.T6373T"},
                new Object[]{"MUC16", 19, 9071155, 9071155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071155C>A", "-", "c.16291G>T", "c.(16291-16293)Ggg>Tgg", "p.G5431W"},
                new Object[]{"MUC16", 19, 9071204, 9071204, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071204G>T", "-", "c.16242C>A", "c.(16240-16242)gcC>gcA", "p.A5414A"},
                new Object[]{"MUC16", 19, 9082454, 9082454, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9082454G>T", "-", "c.9361C>A", "c.(9361-9363)Cca>Aca", "p.P3121T"},
                new Object[]{"MUC16", 19, 9085397, 9085397, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9085397T>A", "-", "c.6418A>T", "c.(6418-6420)Atc>Ttc", "p.I2140F"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 8976592, 8976592, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8976592C>T", "-", "c.42384G>A", "c.(42382-42384)ctG>ctA", "p.L14128L"},
                new Object[]{"MUC16", 19, 9016683, 9016683, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9016683G>A", "-", "c.38054C>T", "c.(38053-38055)cCa>cTa", "p.P12685L"},
                new Object[]{"MUC16", 19, 9049091, 9049091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049091G>A", "-", "c.32540C>T", "c.(32539-32541)tCa>tTa", "p.S10847L"},
                new Object[]{"MUC16", 19, 9070835, 9070835, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070835G>A", "-", "c.16611C>T", "c.(16609-16611)ccC>ccT", "p.P5537P"},
                new Object[]{"MUC16", 19, 9049537, 9049537, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049537G>A", "-", "c.32094C>T", "c.(32092-32094)atC>atT", "p.I10698I"},
                new Object[]{"MUC16", 19, 9064721, 9064721, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064721G>A", "-", "c.22725C>T", "c.(22723-22725)tcC>tcT", "p.S7575S"},
                new Object[]{"MUC16", 19, 9066184, 9066184, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066184G>A", "-", "c.21262C>T", "c.(21262-21264)Ccc>Tcc", "p.P7088S"},
                new Object[]{"MUC16", 19, 9066520, 9066520, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066520G>A", "-", "c.20926C>T", "c.(20926-20928)Ccc>Tcc", "p.P6976S"},
                new Object[]{"MUC16", 19, 9073897, 9073897, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9073897C>T", "-", "c.13549G>A", "c.(13549-13551)Gag>Aag", "p.E4517K"},
                new Object[]{"MUC16", 19, 9021104, 9021104, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9021104G>A", "-", "c.37219C>T", "c.(37219-37221)Cac>Tac", "p.H12407Y"},
                new Object[]{"MUC16", 19, 9062082, 9062082, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062082G>A", "-", "c.25364C>T", "c.(25363-25365)tCc>tTc", "p.S8455F"},
                new Object[]{"MUC16", 19, 9063434, 9063434, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063434G>A", "-", "c.24012C>T", "c.(24010-24012)ctC>ctT", "p.L8004L"},
                new Object[]{"MUC16", 19, 9063268, 9063268, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063268C>T", "-", "c.24178G>A", "c.(24178-24180)Gat>Aat", "p.D8060N"},
                new Object[]{"MUC16", 19, 9067445, 9067445, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067445G>A", "-", "c.20001C>T", "c.(19999-20001)gaC>gaT", "p.D6667D"},
                new Object[]{"MUC16", 19, 9088178, 9088178, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088178C>T", "-", "c.3637G>A", "c.(3637-3639)Gga>Aga", "p.G1213R"},
                new Object[]{"MUC16", 19, 9090831, 9090831, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9090831A>G", "-", "c.984T>C", "c.(982-984)ccT>ccC", "p.P328P"},
                new Object[]{"MUC16", 19, 9049888, 9049888, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049888C>A", "-", "c.31743G>T", "c.(31741-31743)ccG>ccT", "p.P10581P"},
                new Object[]{"MUC16", 19, 9059377, 9059377, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9059377G>T", "-", "c.28069C>A", "c.(28069-28071)Ctc>Atc", "p.L9357I"},
                new Object[]{"MUC16", 19, 9068907, 9068907, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9068907G>T", "-", "c.18539C>A", "c.(18538-18540)tCa>tAa", "p.S6180*"},
                new Object[]{"MUC16", 19, 9075992, 9075992, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9075992G>T", "-", "c.11454C>A", "c.(11452-11454)ccC>ccA", "p.P3818P"},
                new Object[]{"MUC16", 19, 9088055, 9088055, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088055C>A", "-", "c.3760G>T", "c.(3760-3762)Gga>Tga", "p.G1254*"},
                new Object[]{"MUC16", 19, 9047480, 9047480, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047480C>A", "-", "c.34151G>T", "c.(34150-34152)gGg>gTg", "p.G11384V"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9066012, 9066012, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066012G>T", "-", "c.21434C>A", "c.(21433-21435)cCa>cAa", "p.P7145Q"},
                new Object[]{"MUC16", 19, 9067377, 9067377, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067377C>A", "-", "c.20069G>T", "c.(20068-20070)aGg>aTg", "p.R6690M"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9071237, 9071237, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071237C>A", "-", "c.16209G>T", "c.(16207-16209)ccG>ccT", "p.P5403P"},
                new Object[]{"MUC16", 19, 9072660, 9072660, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072660C>A", "-", "c.14786G>T", "c.(14785-14787)aGg>aTg", "p.R4929M"},
                new Object[]{"MUC16", 19, 9073819, 9073819, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9073819C>A", "-", "c.13627G>T", "c.(13627-13629)Ggg>Tgg", "p.G4543W"},
                new Object[]{"MUC16", 19, 9087950, 9087950, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087950G>T", "-", "c.3865C>A", "c.(3865-3867)Cac>Aac", "p.H1289N"},
                new Object[]{"MUC16", 19, 9061148, 9061148, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061148G>A", "-", "c.26298C>T", "c.(26296-26298)tcC>tcT", "p.S8766S"},
                new Object[]{"MUC16", 19, 9069754, 9069754, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069754G>A", "-", "c.17692C>T", "c.(17692-17694)Cca>Tca", "p.P5898S"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 8995693, 8995693, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8995693C>T", "-", "c.41295G>A", "c.(41293-41295)ggG>ggA", "p.G13765G"},
                new Object[]{"MUC16", 19, 9000160, 9000160, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9000160G>A", "-", "c.40597C>T", "c.(40597-40599)Ctg>Ttg", "p.L13533L"},
                new Object[]{"MUC16", 19, 9057771, 9057771, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9057771G>T", "-", "c.29675C>A", "c.(29674-29676)aCa>aAa", "p.T9892K"},
                new Object[]{"MUC16", 19, 9061464, 9061464, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061464G>A", "-", "c.25982C>T", "c.(25981-25983)tCc>tTc", "p.S8661F"},
                new Object[]{"MUC16", 19, 9064451, 9064451, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064451G>A", "-", "c.22995C>T", "c.(22993-22995)tcC>tcT", "p.S7665S"},
                new Object[]{"MUC16", 19, 9085016, 9085016, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085016G>A", "-", "c.6799C>T", "c.(6799-6801)Cca>Tca", "p.P2267S"},
                new Object[]{"MUC16", 19, 9086149, 9086149, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086149C>T", "-", "c.5666G>A", "c.(5665-5667)gGa>gAa", "p.G1889E"},
                new Object[]{"MUC16", 19, 9089699, 9089699, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089699G>A", "-", "c.2116C>T", "c.(2116-2118)Ccc>Tcc", "p.P706S"},
                new Object[]{"MUC16", 19, 9011379, 9011379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9011379G>T", "-", "c.38854C>A", "c.(38854-38856)Cat>Aat", "p.H12952N"},
                new Object[]{"MUC16", 19, 9014566, 9014566, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9014566G>T", "-", "c.38409C>A", "c.(38407-38409)ccC>ccA", "p.P12803P"},
                new Object[]{"MUC16", 19, 9047535, 9047535, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9047535G>T", "-", "c.34096C>A", "c.(34096-34098)Cct>Act", "p.P11366T"},
                new Object[]{"MUC16", 19, 9050072, 9050072, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050072G>T", "-", "c.31559C>A", "c.(31558-31560)cCc>cAc", "p.P10520H"},
                new Object[]{"MUC16", 19, 9059391, 9059391, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059391C>T", "-", "c.28055G>A", "c.(28054-28056)aGa>aAa", "p.R9352K"},
                new Object[]{"MUC16", 19, 9069895, 9069895, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069895G>A", "-", "c.17551C>T", "c.(17551-17553)Cct>Tct", "p.P5851S"},
                new Object[]{"MUC16", 19, 9084701, 9084701, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084701C>T", "-", "c.7114G>A", "c.(7114-7116)Gat>Aat", "p.D2372N"},
                new Object[]{"MUC16", 19, 9088023, 9088023, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088023G>T", "-", "c.3792C>A", "c.(3790-3792)acC>acA", "p.T1264T"},
                new Object[]{"MUC16", 19, 9088055, 9088055, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088055C>A", "-", "c.3760G>T", "c.(3760-3762)Gga>Tga", "p.G1254*"},
                new Object[]{"MUC16", 19, 8997475, 8997475, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8997475C>A", "-", "c.40947G>T", "c.(40945-40947)gaG>gaT", "p.E13649D"},
                new Object[]{"MUC16", 19, 8999412, 8999412, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8999412C>A", "-", "c.40763G>T", "c.(40762-40764)aGg>aTg", "p.R13588M"},
                new Object[]{"MUC16", 19, 9065925, 9065925, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065925G>A", "-", "c.21521C>T", "c.(21520-21522)gCt>gTt", "p.A7174V"},
                new Object[]{"MUC16", 19, 9071189, 9071189, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071189G>T", "-", "c.16257C>A", "c.(16255-16257)tcC>tcA", "p.S5419S"},
                new Object[]{"MUC16", 19, 9075775, 9075775, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075775C>T", "-", "c.11671G>A", "c.(11671-11673)Gaa>Aaa", "p.E3891K"},
                new Object[]{"MUC16", 19, 9075992, 9075992, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9075992G>T", "-", "c.11454C>A", "c.(11452-11454)ccC>ccA", "p.P3818P"},
                new Object[]{"MUC16", 19, 9077276, 9077276, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077276G>T", "-", "c.10170C>A", "c.(10168-10170)acC>acA", "p.T3390T"},
                new Object[]{"MUC16", 19, 9086846, 9086846, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9086846G>T", "-", "c.4969C>A", "c.(4969-4971)Cca>Aca", "p.P1657T"},
                new Object[]{"MUC16", 19, 9087143, 9087143, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087143G>T", "-", "c.4672C>A", "c.(4672-4674)Ctt>Att", "p.L1558I"},
                new Object[]{"MUC16", 19, 9087679, 9087679, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087679G>T", "-", "c.4136C>A", "c.(4135-4137)cCg>cAg", "p.P1379Q"},
                new Object[]{"MUC16", 19, 9087950, 9087950, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087950G>T", "-", "c.3865C>A", "c.(3865-3867)Cac>Aac", "p.H1289N"},
                new Object[]{"MUC16", 19, 9090826, 9090826, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090826G>A", "-", "c.989C>T", "c.(988-990)tCc>tTc", "p.S330F"},
                new Object[]{"MUC16", 19, 9064689, 9064689, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064689G>A", "-", "c.22757C>T", "c.(22756-22758)tCc>tTc", "p.S7586F"},
                new Object[]{"MUC16", 19, 9070973, 9070973, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070973C>T", "-", "c.16473G>A", "c.(16471-16473)gaG>gaA", "p.E5491E"},
                new Object[]{"MUC16", 19, 9077538, 9077538, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077538C>T", "-", "c.9908G>A", "c.(9907-9909)gGg>gAg", "p.G3303E"},
                new Object[]{"MUC16", 19, 9084244, 9084244, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084244G>A", "-", "c.7571C>T", "c.(7570-7572)cCt>cTt", "p.P2524L"},
                new Object[]{"MUC16", 19, 9000512, 9000512, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9000512C>A", "-", "c.40472G>T", "c.(40471-40473)cGg>cTg", "p.R13491L"},
                new Object[]{"MUC16", 19, 9012790, 9012790, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9012790C>A", "-", "c.38654G>T", "c.(38653-38655)cGg>cTg", "p.R12885L"},
                new Object[]{"MUC16", 19, 9012839, 9012839, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9012839C>A", "-", "c.38605G>T", "c.(38605-38607)Gag>Tag", "p.E12869*"},
                new Object[]{"MUC16", 19, 9049546, 9049546, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9049546G>T", "-", "c.32085C>A", "c.(32083-32085)ccC>ccA", "p.P10695P"},
                new Object[]{"MUC16", 19, 9059573, 9059573, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059573C>A", "-", "c.27873G>T", "c.(27871-27873)atG>atT", "p.M9291I"},
                new Object[]{"MUC16", 19, 9065576, 9065576, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9065576G>T", "-", "c.21870C>A", "c.(21868-21870)tcC>tcA", "p.S7290S"},
                new Object[]{"MUC16", 19, 9066675, 9066675, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066675C>A", "-", "c.20771G>T", "c.(20770-20772)gGg>gTg", "p.G6924V"},
                new Object[]{"MUC16", 19, 9068753, 9068753, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9068753G>T", "-", "c.18693C>A", "c.(18691-18693)acC>acA", "p.T6231T"},
                new Object[]{"MUC16", 19, 9069230, 9069230, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9069230G>T", "-", "c.18216C>A", "c.(18214-18216)tcC>tcA", "p.S6072S"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9071965, 9071965, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071965C>A", "-", "c.15481G>T", "c.(15481-15483)Gga>Tga", "p.G5161*"},
                new Object[]{"MUC16", 19, 9073155, 9073155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9073155G>T", "-", "c.14291C>A", "c.(14290-14292)cCg>cAg", "p.P4764Q"},
                new Object[]{"MUC16", 19, 9075927, 9075927, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9075927G>T", "-", "c.11519C>A", "c.(11518-11520)cCa>cAa", "p.P3840Q"},
                new Object[]{"MUC16", 19, 9076671, 9076671, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9076671C>A", "-", "c.10775G>T", "c.(10774-10776)tGg>tTg", "p.W3592L"},
                new Object[]{"MUC16", 19, 9080502, 9080502, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9080502C>A", "-", "c.9529G>T", "c.(9529-9531)Gga>Tga", "p.G3177*"},
                new Object[]{"MUC16", 19, 9088023, 9088023, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088023G>T", "-", "c.3792C>A", "c.(3790-3792)acC>acA", "p.T1264T"},
                new Object[]{"MUC16", 19, 9088249, 9088249, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088249C>A", "-", "c.3566G>T", "c.(3565-3567)cGg>cTg", "p.R1189L"},
                new Object[]{"MUC16", 19, 9091668, 9091668, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9091668C>A", "-", "c.147G>T", "c.(145-147)gtG>gtT", "p.V49V"},
                new Object[]{"MUC16", 19, 9060909, 9060909, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060909G>A", "-", "c.26537C>T", "c.(26536-26538)tCa>tTa", "p.S8846L"},
                new Object[]{"MUC16", 19, 9069117, 9069117, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069117C>T", "-", "c.18329G>A", "c.(18328-18330)aGg>aAg", "p.R6110K"},
                new Object[]{"MUC16", 19, 9085554, 9085554, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085554C>T", "-", "c.6261G>A", "c.(6259-6261)acG>acA", "p.T2087T"},
                new Object[]{"MUC16", 19, 9091023, 9091023, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091023G>T", "-", "c.792C>A", "c.(790-792)ccC>ccA", "p.P264P"},
                new Object[]{"MUC16", 19, 9060186, 9060186, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9060186C>A", "-", "c.27260G>T", "c.(27259-27261)gGg>gTg", "p.G9087V"},
                new Object[]{"MUC16", 19, 9065721, 9065721, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065721G>A", "-", "c.21725C>T", "c.(21724-21726)tCc>tTc", "p.S7242F"},
                new Object[]{"MUC16", 19, 9066519, 9066519, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066519G>A", "-", "c.20927C>T", "c.(20926-20928)cCc>cTc", "p.P6976L"},
                new Object[]{"MUC16", 19, 9072723, 9072723, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072723G>A", "-", "c.14723C>T", "c.(14722-14724)tCg>tTg", "p.S4908L"},
                new Object[]{"MUC16", 19, 9087495, 9087495, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087495C>T", "-", "c.4320G>A", "c.(4318-4320)ggG>ggA", "p.G1440G"},
                new Object[]{"MUC16", 19, 9089598, 9089598, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089598C>T", "-", "c.2217G>A", "c.(2215-2217)gcG>gcA", "p.A739A"},
                new Object[]{"MUC16", 19, 9088055, 9088055, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088055C>A", "-", "c.3760G>T", "c.(3760-3762)Gga>Tga", "p.G1254*"},
                new Object[]{"MUC16", 19, 9064474, 9064474, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064474G>A", "-", "c.22972C>T", "c.(22972-22974)Cca>Tca", "p.P7658S"},
                new Object[]{"MUC16", 19, 9083586, 9083586, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083586C>T", "-", "c.8229G>A", "c.(8227-8229)tcG>tcA", "p.S2743S"},
                new Object[]{"MUC16", 19, 9086812, 9086812, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086812C>T", "-", "c.5003G>A", "c.(5002-5004)aGa>aAa", "p.R1668K"},
                new Object[]{"MUC16", 19, 9065063, 9065063, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9065063G>T", "-", "c.22383C>A", "c.(22381-22383)acC>acA", "p.T7461T"},
                new Object[]{"MUC16", 19, 9065141, 9065141, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065141C>A", "-", "c.22305G>T", "c.(22303-22305)gaG>gaT", "p.E7435D"},
                new Object[]{"MUC16", 19, 9087062, 9087062, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087062G>T", "-", "c.4753C>A", "c.(4753-4755)Cat>Aat", "p.H1585N"},
                new Object[]{"MUC16", 19, 9087964, 9087964, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087964G>T", "-", "c.3851C>A", "c.(3850-3852)cCc>cAc", "p.P1284H"},
                new Object[]{"MUC16", 19, 9091494, 9091494, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091494G>T", "-", "c.321C>A", "c.(319-321)ccC>ccA", "p.P107P"},
                new Object[]{"MUC16", 19, 9066676, 9066676, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066676C>A", "-", "c.20770G>T", "c.(20770-20772)Ggg>Tgg", "p.G6924W"},
                new Object[]{"MUC16", 19, 9072940, 9072940, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072940C>A", "-", "c.14506G>T", "c.(14506-14508)Ggg>Tgg", "p.G4836W"},
                new Object[]{"MUC16", 19, 9086131, 9086131, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086131G>A", "-", "c.5684C>T", "c.(5683-5685)tCc>tTc", "p.S1895F"},
                new Object[]{"MUC16", 19, 9088011, 9088011, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088011G>T", "-", "c.3804C>A", "c.(3802-3804)acC>acA", "p.T1268T"},
                new Object[]{"MUC16", 19, 9026254, 9026254, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9026254C>A", "-", "c.36732G>T", "c.(36730-36732)gaG>gaT", "p.E12244D"},
                new Object[]{"MUC16", 19, 9060133, 9060133, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060133C>T", "-", "c.27313G>A", "c.(27313-27315)Ggg>Agg", "p.G9105R"},
                new Object[]{"MUC16", 19, 9062451, 9062451, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062451C>T", "-", "c.24995G>A", "c.(24994-24996)aGa>aAa", "p.R8332K"},
                new Object[]{"MUC16", 19, 9063615, 9063615, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9063615G>T", "-", "c.23831C>A", "c.(23830-23832)tCa>tAa", "p.S7944*"},
                new Object[]{"MUC16", 19, 9068756, 9068756, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9068756T>A", "-", "c.18690A>T", "c.(18688-18690)acA>acT", "p.T6230T"},
                new Object[]{"MUC16", 19, 9088326, 9088326, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088326G>T", "-", "c.3489C>A", "c.(3487-3489)ccC>ccA", "p.P1163P"},
                new Object[]{"MUC16", 19, 8994476, 8994476, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8994476C>T", "-", "c.41416G>A", "c.(41416-41418)Gag>Aag", "p.E13806K"},
                new Object[]{"MUC16", 19, 9046026, 9046026, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046026G>A", "-", "c.35605C>T", "c.(35605-35607)Ctt>Ttt", "p.L11869F"},
                new Object[]{"MUC16", 19, 9046272, 9046272, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046272G>A", "-", "c.35359C>T", "c.(35359-35361)Cct>Tct", "p.P11787S"},
                new Object[]{"MUC16", 19, 9060378, 9060378, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060378G>A", "-", "c.27068C>T", "c.(27067-27069)cCt>cTt", "p.P9023L"},
                new Object[]{"MUC16", 19, 9060904, 9060904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060904C>T", "-", "c.26542G>A", "c.(26542-26544)Gaa>Aaa", "p.E8848K"},
                new Object[]{"MUC16", 19, 9061715, 9061715, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061715G>A", "-", "c.25731C>T", "c.(25729-25731)tcC>tcT", "p.S8577S"},
                new Object[]{"MUC16", 19, 9064221, 9064221, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064221G>A", "-", "c.23225C>T", "c.(23224-23226)tCa>tTa", "p.S7742L"},
                new Object[]{"MUC16", 19, 9075654, 9075654, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075654C>T", "-", "c.11792G>A", "c.(11791-11793)aGa>aAa", "p.R3931K"},
                new Object[]{"MUC16", 19, 9084930, 9084930, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084930C>T", "-", "c.6885G>A", "c.(6883-6885)tgG>tgA", "p.W2295*"},
                new Object[]{"MUC16", 19, 9089082, 9089082, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089082G>A", "-", "c.2733C>T", "c.(2731-2733)ttC>ttT", "p.F911F"},
                new Object[]{"MUC16", 19, 9089737, 9089737, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089737C>T", "-", "c.2078G>A", "c.(2077-2079)gGa>gAa", "p.G693E"},
                new Object[]{"MUC16", 19, 9091597, 9091597, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091597C>T", "-", "c.218G>A", "c.(217-219)gGa>gAa", "p.G73E"},
                new Object[]{"MUC16", 19, 9066659, 9066659, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066659G>T", "-", "c.20787C>A", "c.(20785-20787)tcC>tcA", "p.S6929S"},
                new Object[]{"MUC16", 19, 9069346, 9069346, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9069346G>T", "-", "c.18100C>A", "c.(18100-18102)Cag>Aag", "p.Q6034K"},
                new Object[]{"MUC16", 19, 9070729, 9070729, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9070729C>A", "-", "c.16717G>T", "c.(16717-16719)Ggg>Tgg", "p.G5573W"},
                new Object[]{"MUC16", 19, 9073155, 9073155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9073155G>T", "-", "c.14291C>A", "c.(14290-14292)cCg>cAg", "p.P4764Q"},
                new Object[]{"MUC16", 19, 9085933, 9085933, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9085933G>T", "-", "c.5882C>A", "c.(5881-5883)cCc>cAc", "p.P1961H"},
                new Object[]{"MUC16", 19, 9088011, 9088011, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088011G>T", "-", "c.3804C>A", "c.(3802-3804)acC>acA", "p.T1268T"},
                new Object[]{"MUC16", 19, 9047175, 9047175, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047175C>T", "-", "c.34456G>A", "c.(34456-34458)Gag>Aag", "p.E11486K"},
                new Object[]{"MUC16", 19, 9061857, 9061857, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061857C>T", "-", "c.25589G>A", "c.(25588-25590)gGa>gAa", "p.G8530E"},
                new Object[]{"MUC16", 19, 8999426, 8999426, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:8999426G>T", "-", "c.40749C>A", "c.(40747-40749)ccC>ccA", "p.P13583P"},
                new Object[]{"MUC16", 19, 9038404, 9038404, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9038404G>A", "-", "c.36115C>T", "c.(36115-36117)Cgg>Tgg", "p.R12039W"},
                new Object[]{"MUC16", 19, 9062146, 9062146, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:9062146T>G", "-", "c.25300A>C", "c.(25300-25302)Agc>Cgc", "p.S8434R"},
                new Object[]{"MUC16", 19, 9067484, 9067484, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067484G>A", "-", "c.19962C>T", "c.(19960-19962)tcC>tcT", "p.S6654S"},
                new Object[]{"MUC16", 19, 9069346, 9069346, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9069346G>T", "-", "c.18100C>A", "c.(18100-18102)Cag>Aag", "p.Q6034K"},
                new Object[]{"MUC16", 19, 9071877, 9071877, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071877G>T", "-", "c.15569C>A", "c.(15568-15570)cCt>cAt", "p.P5190H"},
                new Object[]{"MUC16", 19, 9091524, 9091524, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091524G>T", "-", "c.291C>A", "c.(289-291)tcC>tcA", "p.S97S"},
                new Object[]{"MUC16", 19, 9072100, 9072100, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072100C>T", "-", "c.15346G>A", "c.(15346-15348)Gaa>Aaa", "p.E5116K"},
                new Object[]{"MUC16", 19, 9073985, 9073985, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073985G>A", "-", "c.13461C>T", "c.(13459-13461)acC>acT", "p.T4487T"},
                new Object[]{"MUC16", 19, 9088886, 9088886, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088886C>A", "-", "c.2929G>T", "c.(2929-2931)Ggg>Tgg", "p.G977W"},
                new Object[]{"MUC16", 19, 9006662, 9006662, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9006662C>T", "-", "c.39586G>A", "c.(39586-39588)Gag>Aag", "p.E13196K"},
                new Object[]{"MUC16", 19, 9046505, 9046505, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046505G>A", "-", "c.35126C>T", "c.(35125-35127)tCc>tTc", "p.S11709F"},
                new Object[]{"MUC16", 19, 9085301, 9085301, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085301C>T", "-", "c.6514G>A", "c.(6514-6516)Gcc>Acc", "p.A2172T"},
                new Object[]{"MUC16", 19, 8969346, 8969346, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:8969346G>T", "-", "c.42998C>A", "c.(42997-42999)cCa>cAa", "p.P14333Q"},
                new Object[]{"MUC16", 19, 8994484, 8994484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8994484C>A", "-", "c.41408G>T", "c.(41407-41409)cGg>cTg", "p.R13803L"},
                new Object[]{"MUC16", 19, 9006663, 9006663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006663C>A", "-", "c.39585G>T", "c.(39583-39585)acG>acT", "p.T13195T"},
                new Object[]{"MUC16", 19, 9008193, 9008193, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9008193C>A", "-", "c.39359G>T", "c.(39358-39360)cGg>cTg", "p.R13120L"},
                new Object[]{"MUC16", 19, 9046638, 9046638, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9046638G>T", "-", "c.34993C>A", "c.(34993-34995)Cat>Aat", "p.H11665N"},
                new Object[]{"MUC16", 19, 9047652, 9047652, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047652C>A", "-", "c.33979G>T", "c.(33979-33981)Ggg>Tgg", "p.G11327W"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9056883, 9056883, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056883G>A", "-", "c.30563C>T", "c.(30562-30564)tCt>tTt", "p.S10188F"},
                new Object[]{"MUC16", 19, 9060338, 9060338, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060338C>T", "-", "c.27108G>A", "c.(27106-27108)atG>atA", "p.M9036I"},
                new Object[]{"MUC16", 19, 9065219, 9065219, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065219G>A", "-", "c.22227C>T", "c.(22225-22227)tcC>tcT", "p.S7409S"},
                new Object[]{"MUC16", 19, 9065230, 9065230, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065230G>A", "-", "c.22216C>T", "c.(22216-22218)Cct>Tct", "p.P7406S"},
                new Object[]{"MUC16", 19, 9067595, 9067595, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067595G>T", "-", "c.19851C>A", "c.(19849-19851)ccC>ccA", "p.P6617P"},
                new Object[]{"MUC16", 19, 9067930, 9067930, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067930C>T", "-", "c.19516G>A", "c.(19516-19518)Gaa>Aaa", "p.E6506K"},
                new Object[]{"MUC16", 19, 9083352, 9083352, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083352C>T", "-", "c.8463G>A", "c.(8461-8463)atG>atA", "p.M2821I"},
                new Object[]{"MUC16", 19, 9049655, 9049655, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049655G>A", "-", "c.31976C>T", "c.(31975-31977)tCg>tTg", "p.S10659L"},
                new Object[]{"MUC16", 19, 9058623, 9058623, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058623G>A", "-", "c.28823C>T", "c.(28822-28824)cCc>cTc", "p.P9608L"},
                new Object[]{"MUC16", 19, 9066659, 9066659, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066659G>T", "-", "c.20787C>A", "c.(20785-20787)tcC>tcA", "p.S6929S"},
                new Object[]{"MUC16", 19, 9083556, 9083556, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9083556C>A", "-", "c.8259G>T", "c.(8257-8259)gcG>gcT", "p.A2753A"},
                new Object[]{"MUC16", 19, 9085314, 9085314, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085314C>T", "-", "c.6501G>A", "c.(6499-6501)ccG>ccA", "p.P2167P"},
                new Object[]{"MUC16", 19, 9070546, 9070546, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9070546G>T", "-", "c.16900C>A", "c.(16900-16902)Ctg>Atg", "p.L5634M"},
                new Object[]{"MUC16", 19, 9013898, 9013898, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9013898G>A", "-", "c.38492C>T", "c.(38491-38493)tCc>tTc", "p.S12831F"},
                new Object[]{"MUC16", 19, 9063802, 9063802, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063802C>T", "-", "c.23644G>A", "c.(23644-23646)Gac>Aac", "p.D7882N"},
                new Object[]{"MUC16", 19, 9003650, 9003650, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9003650G>T", "-", "c.39990C>A", "c.(39988-39990)acC>acA", "p.T13330T"},
                new Object[]{"MUC16", 19, 9047229, 9047229, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047229C>A", "-", "c.34402G>T", "c.(34402-34404)Ggg>Tgg", "p.G11468W"},
                new Object[]{"MUC16", 19, 9050128, 9050128, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050128G>T", "-", "c.31503C>A", "c.(31501-31503)ccC>ccA", "p.P10501P"},
                new Object[]{"MUC16", 19, 9056225, 9056225, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056225C>A", "-", "c.31221G>T", "c.(31219-31221)ctG>ctT", "p.L10407L"},
                new Object[]{"MUC16", 19, 9057011, 9057011, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057011G>A", "-", "c.30435C>T", "c.(30433-30435)tcC>tcT", "p.S10145S"},
                new Object[]{"MUC16", 19, 9071156, 9071156, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071156G>T", "-", "c.16290C>A", "c.(16288-16290)tcC>tcA", "p.S5430S"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9074565, 9074565, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074565G>A", "-", "c.12881C>T", "c.(12880-12882)tCc>tTc", "p.S4294F"},
                new Object[]{"MUC16", 19, 9074987, 9074987, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9074987C>A", "-", "c.12459G>T", "c.(12457-12459)gtG>gtT", "p.V4153V"},
                new Object[]{"MUC16", 19, 9077657, 9077657, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077657G>T", "-", "c.9789C>A", "c.(9787-9789)ccC>ccA", "p.P3263P"},
                new Object[]{"MUC16", 19, 9088011, 9088011, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088011G>T", "-", "c.3804C>A", "c.(3802-3804)acC>acA", "p.T1268T"},
                new Object[]{"MUC16", 19, 9088100, 9088100, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088100G>T", "-", "c.3715C>A", "c.(3715-3717)Ctc>Atc", "p.L1239I"},
                new Object[]{"MUC16", 19, 9027568, 9027568, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9027568G>A", "-", "c.36576C>T", "c.(36574-36576)acC>acT", "p.T12192T"},
                new Object[]{"MUC16", 19, 9045944, 9045944, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045944G>A", "-", "c.35687C>T", "c.(35686-35688)tCc>tTc", "p.S11896F"},
                new Object[]{"MUC16", 19, 9046062, 9046062, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046062C>T", "-", "c.35569G>A", "c.(35569-35571)Gaa>Aaa", "p.E11857K"},
                new Object[]{"MUC16", 19, 9046254, 9046254, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046254G>A", "-", "c.35377C>T", "c.(35377-35379)Cct>Tct", "p.P11793S"},
                new Object[]{"MUC16", 19, 9048845, 9048845, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048845C>T", "-", "c.32786G>A", "c.(32785-32787)gGg>gAg", "p.G10929E"},
                new Object[]{"MUC16", 19, 9056878, 9056878, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056878G>A", "-", "c.30568C>T", "c.(30568-30570)Cct>Tct", "p.P10190S"},
                new Object[]{"MUC16", 19, 9059483, 9059483, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059483G>A", "-", "c.27963C>T", "c.(27961-27963)tcC>tcT", "p.S9321S"},
                new Object[]{"MUC16", 19, 9063850, 9063850, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063850C>T", "-", "c.23596G>A", "c.(23596-23598)Gaa>Aaa", "p.E7866K"},
                new Object[]{"MUC16", 19, 9066695, 9066695, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066695C>A", "-", "c.20751G>T", "c.(20749-20751)atG>atT", "p.M6917I"},
                new Object[]{"MUC16", 19, 9067164, 9067164, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067164C>A", "-", "c.20282G>T", "c.(20281-20283)aGg>aTg", "p.R6761M"},
                new Object[]{"MUC16", 19, 9067233, 9067233, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067233C>A", "-", "c.20213G>T", "c.(20212-20214)cGa>cTa", "p.R6738L"},
                new Object[]{"MUC16", 19, 9067474, 9067474, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067474C>A", "-", "c.19972G>T", "c.(19972-19974)Ggg>Tgg", "p.G6658W"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9072702, 9072702, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9072702A>G", "-", "c.14744T>C", "c.(14743-14745)gTt>gCt", "p.V4915A"},
                new Object[]{"MUC16", 19, 9073819, 9073819, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9073819C>A", "-", "c.13627G>T", "c.(13627-13629)Ggg>Tgg", "p.G4543W"},
                new Object[]{"MUC16", 19, 9077469, 9077469, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077469C>T", "-", "c.9977G>A", "c.(9976-9978)gGg>gAg", "p.G3326E"},
                new Object[]{"MUC16", 19, 9083027, 9083027, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9083027A>T", "-", "c.8788T>A", "c.(8788-8790)Tcc>Acc", "p.S2930T"},
                new Object[]{"MUC16", 19, 9086190, 9086190, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086190C>T", "-", "c.5625G>A", "c.(5623-5625)ttG>ttA", "p.L1875L"},
                new Object[]{"MUC16", 19, 9087026, 9087026, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087026C>A", "-", "c.4789G>T", "c.(4789-4791)Ggg>Tgg", "p.G1597W"},
                new Object[]{"MUC16", 19, 9091647, 9091647, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091647G>T", "-", "c.168C>A", "c.(166-168)ccC>ccA", "p.P56P"},
                new Object[]{"MUC16", 19, 9038403, 9038403, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9038403C>A", "-", "c.36116G>T", "c.(36115-36117)cGg>cTg", "p.R12039L"},
                new Object[]{"MUC16", 19, 9046048, 9046048, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046048C>T", "-", "c.35583G>A", "c.(35581-35583)atG>atA", "p.M11861I"},
                new Object[]{"MUC16", 19, 9069397, 9069397, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9069397C>A", "-", "c.18049G>T", "c.(18049-18051)Ggg>Tgg", "p.G6017W"},
                new Object[]{"MUC16", 19, 9089545, 9089545, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089545G>A", "-", "c.2270C>T", "c.(2269-2271)cCt>cTt", "p.P757L"},
                new Object[]{"MUC16", 19, 9056509, 9056509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056509C>A", "-", "c.30937G>T", "c.(30937-30939)Ggg>Tgg", "p.G10313W"},
                new Object[]{"MUC16", 19, 9068151, 9068151, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068151G>A", "-", "c.19295C>T", "c.(19294-19296)tCt>tTt", "p.S6432F"},
                new Object[]{"MUC16", 19, 9072414, 9072414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072414G>A", "-", "c.15032C>T", "c.(15031-15033)tCa>tTa", "p.S5011L"},
                new Object[]{"MUC16", 19, 8997482, 8997482, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8997482C>A", "-", "c.40940G>T", "c.(40939-40941)cGg>cTg", "p.R13647L"},
                new Object[]{"MUC16", 19, 9057124, 9057124, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9057124C>A", "-", "c.30322G>T", "c.(30322-30324)Gga>Tga", "p.G10108*"},
                new Object[]{"MUC16", 19, 9066283, 9066283, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066283G>T", "-", "c.21163C>A", "c.(21163-21165)Cag>Aag", "p.Q7055K"},
                new Object[]{"MUC16", 19, 9068061, 9068061, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9068061C>A", "-", "c.19385G>T", "c.(19384-19386)tGg>tTg", "p.W6462L"},
                new Object[]{"MUC16", 19, 9068183, 9068183, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9068183C>A", "-", "c.19263G>T", "c.(19261-19263)ccG>ccT", "p.P6421P"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9072770, 9072770, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072770G>T", "-", "c.14676C>A", "c.(14674-14676)tcC>tcA", "p.S4892S"},
                new Object[]{"MUC16", 19, 9088114, 9088114, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088114C>A", "-", "c.3701G>T", "c.(3700-3702)gGg>gTg", "p.G1234V"},
                new Object[]{"MUC16", 19, 9088804, 9088804, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088804G>T", "-", "c.3011C>A", "c.(3010-3012)cCa>cAa", "p.P1004Q"},
                // Had to change GT for the protein change, since this is an intron splice site.
                new Object[]{"MUC16", 19, 9080450, 9080450, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9080450C>T", "-", "c.e2-1G>A", "c.e2+1", null},
                new Object[]{"MUC16", 19, 9045956, 9045956, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045956G>A", "-", "c.35675C>T", "c.(35674-35676)aCt>aTt", "p.T11892I"},
                new Object[]{"MUC16", 19, 9047693, 9047693, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047693G>A", "-", "c.33938C>T", "c.(33937-33939)cCt>cTt", "p.P11313L"},
                new Object[]{"MUC16", 19, 9068223, 9068223, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068223C>T", "-", "c.19223G>A", "c.(19222-19224)aGa>aAa", "p.R6408K"},
                new Object[]{"MUC16", 19, 9071243, 9071243, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9071243C>T", "-", "c.16203G>A", "c.(16201-16203)gaG>gaA", "p.E5401E"},
                new Object[]{"MUC16", 19, 9084930, 9084930, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084930C>T", "-", "c.6885G>A", "c.(6883-6885)tgG>tgA", "p.W2295*"},
                new Object[]{"MUC16", 19, 9088177, 9088177, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088177C>T", "-", "c.3638G>A", "c.(3637-3639)gGa>gAa", "p.G1213E"},
                new Object[]{"MUC16", 19, 9091441, 9091441, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091441C>T", "-", "c.374G>A", "c.(373-375)gGa>gAa", "p.G125E"},
                new Object[]{"MUC16", 19, 9058283, 9058283, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058283C>T", "-", "c.29163G>A", "c.(29161-29163)gtG>gtA", "p.V9721V"},
                new Object[]{"MUC16", 19, 9072326, 9072326, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072326G>A", "-", "c.15120C>T", "c.(15118-15120)ccC>ccT", "p.P5040P"},
                new Object[]{"MUC16", 19, 9074184, 9074184, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074184G>A", "-", "c.13262C>T", "c.(13261-13263)cCa>cTa", "p.P4421L"},
                new Object[]{"MUC16", 19, 9082490, 9082490, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082490C>T", "-", "c.9325G>A", "c.(9325-9327)Gaa>Aaa", "p.E3109K"},
                new Object[]{"MUC16", 19, 9086743, 9086743, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086743C>T", "-", "c.5072G>A", "c.(5071-5073)aGa>aAa", "p.R1691K"},
                new Object[]{"MUC16", 19, 9058034, 9058034, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058034C>T", "-", "c.29412G>A", "c.(29410-29412)gaG>gaA", "p.E9804E"},
                new Object[]{"MUC16", 19, 9063915, 9063915, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063915G>A", "-", "c.23531C>T", "c.(23530-23532)tCa>tTa", "p.S7844L"},
                new Object[]{"MUC16", 19, 9057066, 9057066, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057066G>A", "-", "c.30380C>T", "c.(30379-30381)tCc>tTc", "p.S10127F"},
                new Object[]{"MUC16", 19, 9064403, 9064403, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064403C>T", "-", "c.23043G>A", "c.(23041-23043)gtG>gtA", "p.V7681V"},
                new Object[]{"MUC16", 19, 9069660, 9069660, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069660G>A", "-", "c.17786C>T", "c.(17785-17787)tCc>tTc", "p.S5929F"},
                new Object[]{"MUC16", 19, 9082794, 9082794, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082794G>A", "-", "c.9021C>T", "c.(9019-9021)acC>acT", "p.T3007T"},
                new Object[]{"MUC16", 19, 9084492, 9084492, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084492G>A", "-", "c.7323C>T", "c.(7321-7323)tcC>tcT", "p.S2441S"},
                new Object[]{"MUC16", 19, 9085237, 9085237, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085237G>A", "-", "c.6578C>T", "c.(6577-6579)tCc>tTc", "p.S2193F"},
                new Object[]{"MUC16", 19, 9086687, 9086687, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086687C>T", "-", "c.5128G>A", "c.(5128-5130)Gaa>Aaa", "p.E1710K"},
                new Object[]{"MUC16", 19, 9089550, 9089550, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089550C>T", "-", "c.2265G>A", "c.(2263-2265)ggG>ggA", "p.G755G"},
                new Object[]{"MUC16", 19, 9074964, 9074964, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074964G>A", "-", "c.12482C>T", "c.(12481-12483)tCc>tTc", "p.S4161F"},
                new Object[]{"MUC16", 19, 9048429, 9048429, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048429C>T", "-", "c.33202G>A", "c.(33202-33204)Gaa>Aaa", "p.E11068K"},
                new Object[]{"MUC16", 19, 9058282, 9058282, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058282C>T", "-", "c.29164G>A", "c.(29164-29166)Gaa>Aaa", "p.E9722K"},
                new Object[]{"MUC16", 19, 9059611, 9059611, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059611G>A", "-", "c.27835C>T", "c.(27835-27837)Caa>Taa", "p.Q9279*"},
                new Object[]{"MUC16", 19, 9060263, 9060263, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060263C>T", "-", "c.27183G>A", "c.(27181-27183)gtG>gtA", "p.V9061V"},
                new Object[]{"MUC16", 19, 9064344, 9064344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064344G>A", "-", "c.23102C>T", "c.(23101-23103)cCt>cTt", "p.P7701L"},
                new Object[]{"MUC16", 19, 9064917, 9064917, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064917G>A", "-", "c.22529C>T", "c.(22528-22530)aCc>aTc", "p.T7510I"},
                new Object[]{"MUC16", 19, 9067233, 9067233, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067233C>T", "-", "c.20213G>A", "c.(20212-20214)cGa>cAa", "p.R6738Q"},
                new Object[]{"MUC16", 19, 9068743, 9068743, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068743G>A", "-", "c.18703C>T", "c.(18703-18705)Cct>Tct", "p.P6235S"},
                new Object[]{"MUC16", 19, 9069352, 9069352, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069352G>A", "-", "c.18094C>T", "c.(18094-18096)Cac>Tac", "p.H6032Y"},
                new Object[]{"MUC16", 19, 9087718, 9087718, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087718C>T", "-", "c.4097G>A", "c.(4096-4098)gGa>gAa", "p.G1366E"},
                new Object[]{"MUC16", 19, 9061180, 9061180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061180G>A", "-", "c.26266C>T", "c.(26266-26268)Cct>Tct", "p.P8756S"},
                new Object[]{"MUC16", 19, 9065866, 9065866, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065866C>T", "-", "c.21580G>A", "c.(21580-21582)Gaa>Aaa", "p.E7194K"},
                new Object[]{"MUC16", 19, 9066532, 9066532, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066532G>A", "-", "c.20914C>T", "c.(20914-20916)Ctt>Ttt", "p.L6972F"},
                new Object[]{"MUC16", 19, 9077304, 9077304, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077304G>A", "-", "c.10142C>T", "c.(10141-10143)tCa>tTa", "p.S3381L"},
                new Object[]{"MUC16", 19, 9067504, 9067504, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067504C>A", "-", "c.19942G>T", "c.(19942-19944)Gag>Tag", "p.E6648*"},
                new Object[]{"MUC16", 19, 9017438, 9017438, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9017438C>T", "-", "c.37886G>A", "c.(37885-37887)aGg>aAg", "p.R12629K"},
                new Object[]{"MUC16", 19, 9050196, 9050196, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9050196G>A", "-", "c.31435C>T", "c.(31435-31437)Ctg>Ttg", "p.L10479L"},
                new Object[]{"MUC16", 19, 9085057, 9085057, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085057G>A", "-", "c.6758C>T", "c.(6757-6759)tCc>tTc", "p.S2253F"},
                new Object[]{"MUC16", 19, 9059370, 9059370, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059370C>T", "-", "c.28076G>A", "c.(28075-28077)aGg>aAg", "p.R9359K"},
                new Object[]{"MUC16", 19, 9063547, 9063547, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9063547T>C", "-", "c.23899A>G", "c.(23899-23901)Aaa>Gaa", "p.K7967E"},
                new Object[]{"MUC16", 19, 9070708, 9070708, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070708G>A", "-", "c.16738C>T", "c.(16738-16740)Ctt>Ttt", "p.L5580F"},
                new Object[]{"MUC16", 19, 9071190, 9071190, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071190G>A", "-", "c.16256C>T", "c.(16255-16257)tCc>tTc", "p.S5419F"},
                new Object[]{"MUC16", 19, 9076306, 9076306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076306G>A", "-", "c.11140C>T", "c.(11140-11142)Cat>Tat", "p.H3714Y"},
                new Object[]{"MUC16", 19, 9077720, 9077720, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077720C>T", "-", "c.9726G>A", "c.(9724-9726)gtG>gtA", "p.V3242V"},
                new Object[]{"MUC16", 19, 9086692, 9086692, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086692G>A", "-", "c.5123C>T", "c.(5122-5124)aCt>aTt", "p.T1708I"},
                new Object[]{"MUC16", 19, 9014639, 9014639, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014639C>T", "-", "c.38336G>A", "c.(38335-38337)aGc>aAc", "p.S12779N"},
                new Object[]{"MUC16", 19, 9068007, 9068007, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068007C>T", "-", "c.19439G>A", "c.(19438-19440)gGa>gAa", "p.G6480E"},
                new Object[]{"MUC16", 19, 9070509, 9070509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070509G>A", "-", "c.16937C>T", "c.(16936-16938)tCc>tTc", "p.S5646F"},
                new Object[]{"MUC16", 19, 9074848, 9074848, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074848G>A", "-", "c.12598C>T", "c.(12598-12600)Ctg>Ttg", "p.L4200L"},
                new Object[]{"MUC16", 19, 9074858, 9074858, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074858C>T", "-", "c.12588G>A", "c.(12586-12588)gaG>gaA", "p.E4196E"},
                new Object[]{"MUC16", 19, 9077349, 9077349, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077349G>A", "-", "c.10097C>T", "c.(10096-10098)tCc>tTc", "p.S3366F"},
                new Object[]{"MUC16", 19, 9090186, 9090186, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090186C>T", "-", "c.1629G>A", "c.(1627-1629)atG>atA", "p.M543I"},
                new Object[]{"MUC16", 19, 9002184, 9002184, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9002184G>A", "-", "c.40320C>T", "c.(40318-40320)ttC>ttT", "p.F13440F"},
                new Object[]{"MUC16", 19, 9057400, 9057400, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057400C>T", "-", "c.30046G>A", "c.(30046-30048)Gaa>Aaa", "p.E10016K"},
                new Object[]{"MUC16", 19, 9060431, 9060431, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060431C>T", "-", "c.27015G>A", "c.(27013-27015)agG>agA", "p.R9005R"},
                new Object[]{"MUC16", 19, 9061149, 9061149, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061149G>A", "-", "c.26297C>T", "c.(26296-26298)tCc>tTc", "p.S8766F"},
                new Object[]{"MUC16", 19, 9064338, 9064338, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064338G>A", "-", "c.23108C>T", "c.(23107-23109)tCc>tTc", "p.S7703F"},
                new Object[]{"MUC16", 19, 9065502, 9065502, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9065502G>T", "-", "c.21944C>A", "c.(21943-21945)tCc>tAc", "p.S7315Y"},
                new Object[]{"MUC16", 19, 9068396, 9068396, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068396G>A", "-", "c.19050C>T", "c.(19048-19050)tcC>tcT", "p.S6350S"},
                new Object[]{"MUC16", 19, 9068671, 9068671, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068671G>A", "-", "c.18775C>T", "c.(18775-18777)Ctg>Ttg", "p.L6259L"},
                new Object[]{"MUC16", 19, 9069839, 9069839, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069839C>T", "-", "c.17607G>A", "c.(17605-17607)ggG>ggA", "p.G5869G"},
                new Object[]{"MUC16", 19, 9090482, 9090482, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090482G>A", "-", "c.1333C>T", "c.(1333-1335)Cct>Tct", "p.P445S"},
                new Object[]{"MUC16", 19, 9064856, 9064856, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064856C>T", "-", "c.22590G>A", "c.(22588-22590)agG>agA", "p.R7530R"},
                new Object[]{"MUC16", 19, 9088132, 9088132, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088132G>A", "-", "c.3683C>T", "c.(3682-3684)tCa>tTa", "p.S1228L"},
                new Object[]{"MUC16", 19, 9089213, 9089213, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089213C>T", "-", "c.2602G>A", "c.(2602-2604)Gaa>Aaa", "p.E868K"},
                new Object[]{"MUC16", 19, 9062982, 9062982, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062982C>T", "-", "c.24464G>A", "c.(24463-24465)aGg>aAg", "p.R8155K"},
                new Object[]{"MUC16", 19, 9072844, 9072844, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072844C>T", "-", "c.14602G>A", "c.(14602-14604)Gaa>Aaa", "p.E4868K"},
                new Object[]{"MUC16", 19, 9091430, 9091430, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091430G>A", "-", "c.385C>T", "c.(385-387)Cca>Tca", "p.P129S"},
                new Object[]{"MUC16", 19, 8987332, 8987332, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8987332C>A", "-", "c.41755G>T", "c.(41755-41757)Ggg>Tgg", "p.G13919W"},
                new Object[]{"MUC16", 19, 9049259, 9049259, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049259C>A", "-", "c.32372G>T", "c.(32371-32373)cGg>cTg", "p.R10791L"},
                new Object[]{"MUC16", 19, 9068456, 9068456, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9068456G>T", "-", "c.18990C>A", "c.(18988-18990)tcC>tcA", "p.S6330S"},
                new Object[]{"MUC16", 19, 9072671, 9072671, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072671G>T", "-", "c.14775C>A", "c.(14773-14775)acC>acA", "p.T4925T"},
                new Object[]{"MUC16", 19, 9083846, 9083846, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "C", "g.chr19:9083846G>C", "-", "c.7969C>G", "c.(7969-7971)Cca>Gca", "p.P2657A"},
                new Object[]{"MUC16", 19, 9084638, 9084638, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084638G>A", "-", "c.7177C>T", "c.(7177-7179)Ccc>Tcc", "p.P2393S"},
                new Object[]{"MUC16", 19, 9006663, 9006663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006663C>A", "-", "c.39585G>T", "c.(39583-39585)acG>acT", "p.T13195T"},
                new Object[]{"MUC16", 19, 9018481, 9018481, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9018481C>A", "-", "c.37693G>T", "c.(37693-37695)Ggc>Tgc", "p.G12565C"},
                new Object[]{"MUC16", 19, 9056225, 9056225, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056225C>A", "-", "c.31221G>T", "c.(31219-31221)ctG>ctT", "p.L10407L"},
                new Object[]{"MUC16", 19, 9087264, 9087264, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087264C>A", "-", "c.4551G>T", "c.(4549-4551)ttG>ttT", "p.L1517F"},
                new Object[]{"MUC16", 19, 9087950, 9087950, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087950G>T", "-", "c.3865C>A", "c.(3865-3867)Cac>Aac", "p.H1289N"},
                new Object[]{"MUC16", 19, 9089419, 9089419, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9089419C>A", "-", "c.2396G>T", "c.(2395-2397)gGg>gTg", "p.G799V"},
                new Object[]{"MUC16", 19, 8995652, 8995652, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8995652G>A", "-", "c.41336C>T", "c.(41335-41337)tCg>tTg", "p.S13779L"},
                new Object[]{"MUC16", 19, 9046923, 9046923, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046923C>T", "-", "c.34708G>A", "c.(34708-34710)Gaa>Aaa", "p.E11570K"},
                new Object[]{"MUC16", 19, 9088081, 9088081, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088081G>A", "-", "c.3734C>T", "c.(3733-3735)tCa>tTa", "p.S1245L"},
                new Object[]{"MUC16", 19, 9056776, 9056776, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056776G>A", "-", "c.30670C>T", "c.(30670-30672)Cca>Tca", "p.P10224S"},
                new Object[]{"MUC16", 19, 9061059, 9061059, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9061059G>T", "-", "c.26387C>A", "c.(26386-26388)gCa>gAa", "p.A8796E"},
                new Object[]{"MUC16", 19, 9091639, 9091639, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091639G>A", "-", "c.176C>T", "c.(175-177)tCc>tTc", "p.S59F"},
                new Object[]{"MUC16", 19, 9049482, 9049482, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049482C>A", "-", "c.32149G>T", "c.(32149-32151)Ggg>Tgg", "p.G10717W"},
                new Object[]{"MUC16", 19, 9067655, 9067655, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067655C>A", "-", "c.19791G>T", "c.(19789-19791)gtG>gtT", "p.V6597V"},
                new Object[]{"MUC16", 19, 9071189, 9071189, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071189G>T", "-", "c.16257C>A", "c.(16255-16257)tcC>tcA", "p.S5419S"},
                new Object[]{"MUC16", 19, 9086653, 9086653, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9086653G>T", "-", "c.5162C>A", "c.(5161-5163)cCa>cAa", "p.P1721Q"},
                new Object[]{"MUC16", 19, 9033650, 9033650, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9033650G>A", "-", "c.36287C>T", "c.(36286-36288)tCc>tTc", "p.S12096F"},
                new Object[]{"MUC16", 19, 9058027, 9058027, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058027G>A", "-", "c.29419C>T", "c.(29419-29421)Cat>Tat", "p.H9807Y"},
                new Object[]{"MUC16", 19, 9045740, 9045740, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045740G>A", "-", "c.35891C>T", "c.(35890-35892)cCa>cTa", "p.P11964L"},
                new Object[]{"MUC16", 19, 9048867, 9048867, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048867G>A", "-", "c.32764C>T", "c.(32764-32766)Cca>Tca", "p.P10922S"},
                new Object[]{"MUC16", 19, 9064566, 9064566, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9064566G>T", "-", "c.22880C>A", "c.(22879-22881)cCt>cAt", "p.P7627H"},
                new Object[]{"MUC16", 19, 9065041, 9065041, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065041C>T", "-", "c.22405G>A", "c.(22405-22407)Gag>Aag", "p.E7469K"},
                new Object[]{"MUC16", 19, 9061307, 9061307, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061307G>A", "-", "c.26139C>T", "c.(26137-26139)atC>atT", "p.I8713I"},
                new Object[]{"MUC16", 19, 9067346, 9067346, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067346G>A", "-", "c.20100C>T", "c.(20098-20100)tcC>tcT", "p.S6700S"},
                new Object[]{"MUC16", 19, 9083238, 9083238, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083238G>A", "-", "c.8577C>T", "c.(8575-8577)ctC>ctT", "p.L2859L"},
                new Object[]{"MUC16", 19, 9061796, 9061796, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061796C>T", "-", "c.25650G>A", "c.(25648-25650)ccG>ccA", "p.P8550P"},
                new Object[]{"MUC16", 19, 9064549, 9064549, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064549C>T", "-", "c.22897G>A", "c.(22897-22899)Gaa>Aaa", "p.E7633K"},
                new Object[]{"MUC16", 19, 9067219, 9067219, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067219G>A", "-", "c.20227C>T", "c.(20227-20229)Ctt>Ttt", "p.L6743F"},
                new Object[]{"MUC16", 19, 9085237, 9085237, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085237G>A", "-", "c.6578C>T", "c.(6577-6579)tCc>tTc", "p.S2193F"},
                new Object[]{"MUC16", 19, 9088300, 9088300, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088300G>A", "-", "c.3515C>T", "c.(3514-3516)tCa>tTa", "p.S1172L"},
                new Object[]{"MUC16", 19, 9089999, 9089999, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089999G>A", "-", "c.1816C>T", "c.(1816-1818)Ccc>Tcc", "p.P606S"},
                new Object[]{"MUC16", 19, 9000458, 9000458, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9000458C>T", "-", "c.40526G>A", "c.(40525-40527)aGa>aAa", "p.R13509K"},
                new Object[]{"MUC16", 19, 9006660, 9006660, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9006660C>T", "-", "c.39588G>A", "c.(39586-39588)gaG>gaA", "p.E13196E"},
                new Object[]{"MUC16", 19, 9047843, 9047843, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9047843T>A", "-", "c.33788A>T", "c.(33787-33789)aAt>aTt", "p.N11263I"},
                new Object[]{"MUC16", 19, 9056480, 9056480, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056480C>T", "-", "c.30966G>A", "c.(30964-30966)gaG>gaA", "p.E10322E"},
                new Object[]{"MUC16", 19, 9058876, 9058876, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058876C>T", "-", "c.28570G>A", "c.(28570-28572)Gaa>Aaa", "p.E9524K"},
                new Object[]{"MUC16", 19, 9059418, 9059418, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059418G>A", "-", "c.28028C>T", "c.(28027-28029)tCa>tTa", "p.S9343L"},
                new Object[]{"MUC16", 19, 9061851, 9061851, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061851G>A", "-", "c.25595C>T", "c.(25594-25596)tCa>tTa", "p.S8532L"},
                new Object[]{"MUC16", 19, 9062055, 9062055, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062055G>A", "-", "c.25391C>T", "c.(25390-25392)cCt>cTt", "p.P8464L"},
                new Object[]{"MUC16", 19, 9063986, 9063986, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063986C>T", "-", "c.23460G>A", "c.(23458-23460)agG>agA", "p.R7820R"},
                new Object[]{"MUC16", 19, 9065739, 9065739, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9065739A>T", "-", "c.21707T>A", "c.(21706-21708)aTt>aAt", "p.I7236N"},
                new Object[]{"MUC16", 19, 9070548, 9070548, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070548G>A", "-", "c.16898C>T", "c.(16897-16899)tCc>tTc", "p.S5633F"},
                new Object[]{"MUC16", 19, 9071745, 9071745, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071745G>A", "-", "c.15701C>T", "c.(15700-15702)tCc>tTc", "p.S5234F"},
                new Object[]{"MUC16", 19, 9072287, 9072287, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072287G>A", "-", "c.15159C>T", "c.(15157-15159)tcC>tcT", "p.S5053S"},
                new Object[]{"MUC16", 19, 9073623, 9073623, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073623G>A", "-", "c.13823C>T", "c.(13822-13824)aCc>aTc", "p.T4608I"},
                new Object[]{"MUC16", 19, 9075829, 9075829, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075829C>T", "-", "c.11617G>A", "c.(11617-11619)Gaa>Aaa", "p.E3873K"},
                new Object[]{"MUC16", 19, 9077847, 9077847, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077847G>A", "-", "c.9599C>T", "c.(9598-9600)cCa>cTa", "p.P3200L"},
                new Object[]{"MUC16", 19, 9088521, 9088521, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088521C>T", "-", "c.3294G>A", "c.(3292-3294)agG>agA", "p.R1098R"},
                new Object[]{"MUC16", 19, 9090343, 9090343, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090343C>T", "-", "c.1472G>A", "c.(1471-1473)gGg>gAg", "p.G491E"},
                new Object[]{"MUC16", 19, 9091810, 9091810, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9091810A>C", "-", "c.5T>G", "c.(4-6)cTg>cGg", "p.L2R"},
                new Object[]{"MUC16", 19, 8996474, 8996474, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8996474C>T", "-", "c.41098G>A", "c.(41098-41100)Gcc>Acc", "p.A13700T"},
                new Object[]{"MUC16", 19, 8997440, 8997440, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:8997440T>G", "-", "c.40982A>C", "c.(40981-40983)aAc>aCc", "p.N13661T"},
                new Object[]{"MUC16", 19, 9066334, 9066334, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066334C>A", "-", "c.21112G>T", "c.(21112-21114)Ggg>Tgg", "p.G7038W"},
                new Object[]{"MUC16", 19, 9066461, 9066461, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066461G>T", "-", "c.20985C>A", "c.(20983-20985)tcC>tcA", "p.S6995S"},
                new Object[]{"MUC16", 19, 9066603, 9066603, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066603G>A", "-", "c.20843C>T", "c.(20842-20844)tCc>tTc", "p.S6948F"},
                new Object[]{"MUC16", 19, 9067326, 9067326, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067326G>A", "-", "c.20120C>T", "c.(20119-20121)tCc>tTc", "p.S6707F"},
                new Object[]{"MUC16", 19, 9070778, 9070778, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070778G>A", "-", "c.16668C>T", "c.(16666-16668)atC>atT", "p.I5556I"},
                new Object[]{"MUC16", 19, 9087904, 9087904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087904G>A", "-", "c.3911C>T", "c.(3910-3912)tCa>tTa", "p.S1304L"},
                new Object[]{"MUC16", 19, 9088087, 9088087, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088087G>T", "-", "c.3728C>A", "c.(3727-3729)cCt>cAt", "p.P1243H"},
                new Object[]{"MUC16", 19, 9088100, 9088100, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088100G>T", "-", "c.3715C>A", "c.(3715-3717)Ctc>Atc", "p.L1239I"},
                new Object[]{"MUC16", 19, 9019292, 9019292, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9019292G>A", "-", "c.37595C>T", "c.(37594-37596)tCc>tTc", "p.S12532F"},
                new Object[]{"MUC16", 19, 9072753, 9072753, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072753C>A", "-", "c.14693G>T", "c.(14692-14694)aGg>aTg", "p.R4898M"},
                new Object[]{"MUC16", 19, 8966742, 8966742, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8966742C>T", "-", "c.43211G>A", "c.(43210-43212)aGa>aAa", "p.R14404K"},
                new Object[]{"MUC16", 19, 9066340, 9066340, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066340G>A", "-", "c.21106C>T", "c.(21106-21108)Cct>Tct", "p.P7036S"},
                new Object[]{"MUC16", 19, 9071592, 9071592, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071592G>A", "-", "c.15854C>T", "c.(15853-15855)cCc>cTc", "p.P5285L"},
                new Object[]{"MUC16", 19, 9073213, 9073213, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073213G>A", "-", "c.14233C>T", "c.(14233-14235)Ccc>Tcc", "p.P4745S"},
                new Object[]{"MUC16", 19, 9074987, 9074987, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074987C>T", "-", "c.12459G>A", "c.(12457-12459)gtG>gtA", "p.V4153V"},
                new Object[]{"MUC16", 19, 9085370, 9085370, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085370C>T", "-", "c.6445G>A", "c.(6445-6447)Gcc>Acc", "p.A2149T"},
                new Object[]{"MUC16", 19, 9086851, 9086851, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086851G>A", "-", "c.4964C>T", "c.(4963-4965)tCc>tTc", "p.S1655F"},
                new Object[]{"MUC16", 19, 9090068, 9090068, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090068C>T", "-", "c.1747G>A", "c.(1747-1749)Gaa>Aaa", "p.E583K"},
                new Object[]{"MUC16", 19, 9091577, 9091577, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091577C>T", "-", "c.238G>A", "c.(238-240)Ggg>Agg", "p.G80R"},
                new Object[]{"MUC16", 19, 9020132, 9020132, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9020132C>T", "-", "c.37363G>A", "c.(37363-37365)Gga>Aga", "p.G12455R"},
                new Object[]{"MUC16", 19, 9062771, 9062771, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062771C>T", "-", "c.24675G>A", "c.(24673-24675)tgG>tgA", "p.W8225*"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9057555, 9057555, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9057555C>A", "-", "c.29891G>T", "c.(29890-29892)gGg>gTg", "p.G9964V"},
                new Object[]{"MUC16", 19, 9083532, 9083532, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083532G>A", "-", "c.8283C>T", "c.(8281-8283)ttC>ttT", "p.F2761F"},
                new Object[]{"MUC16", 19, 9008193, 9008193, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9008193C>A", "-", "c.39359G>T", "c.(39358-39360)cGg>cTg", "p.R13120L"},
                new Object[]{"MUC16", 19, 9046738, 9046738, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046738C>T", "-", "c.34893G>A", "c.(34891-34893)gtG>gtA", "p.V11631V"},
                new Object[]{"MUC16", 19, 9085586, 9085586, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085586G>A", "-", "c.6229C>T", "c.(6229-6231)Cat>Tat", "p.H2077Y"},
                new Object[]{"MUC16", 19, 9047932, 9047932, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047932C>T", "-", "c.33699G>A", "c.(33697-33699)gaG>gaA", "p.E11233E"},
                new Object[]{"MUC16", 19, 9063136, 9063136, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9063136C>A", "-", "c.24310G>T", "c.(24310-24312)Ggc>Tgc", "p.G8104C"},
                new Object[]{"MUC16", 19, 9068414, 9068414, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068414G>A", "-", "c.19032C>T", "c.(19030-19032)tcC>tcT", "p.S6344S"},
                new Object[]{"MUC16", 19, 9090789, 9090789, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090789C>T", "-", "c.1026G>A", "c.(1024-1026)agG>agA", "p.R342R"},
                new Object[]{"MUC16", 19, 9091431, 9091431, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091431G>T", "-", "c.384C>A", "c.(382-384)tcC>tcA", "p.S128S"},
                new Object[]{"MUC16", 19, 9091671, 9091671, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091671G>A", "-", "c.144C>T", "c.(142-144)atC>atT", "p.I48I"},
                new Object[]{"MUC16", 19, 8995663, 8995663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8995663C>T", "-", "c.41325G>A", "c.(41323-41325)aaG>aaA", "p.K13775K"},
                new Object[]{"MUC16", 19, 9047480, 9047480, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047480C>A", "-", "c.34151G>T", "c.(34150-34152)gGg>gTg", "p.G11384V"},
                new Object[]{"MUC16", 19, 9047652, 9047652, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047652C>A", "-", "c.33979G>T", "c.(33979-33981)Ggg>Tgg", "p.G11327W"},
                new Object[]{"MUC16", 19, 9060353, 9060353, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060353C>T", "-", "c.27093G>A", "c.(27091-27093)acG>acA", "p.T9031T"},
                new Object[]{"MUC16", 19, 9061972, 9061972, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061972C>T", "-", "c.25474G>A", "c.(25474-25476)Gaa>Aaa", "p.E8492K"},
                new Object[]{"MUC16", 19, 9062059, 9062059, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9062059C>A", "-", "c.25387G>T", "c.(25387-25389)Ggg>Tgg", "p.G8463W"},
                new Object[]{"MUC16", 19, 9065680, 9065680, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065680C>A", "-", "c.21766G>T", "c.(21766-21768)Gag>Tag", "p.E7256*"},
                new Object[]{"MUC16", 19, 9066594, 9066594, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066594G>T", "-", "c.20852C>A", "c.(20851-20853)cCt>cAt", "p.P6951H"},
                new Object[]{"MUC16", 19, 9071306, 9071306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071306C>A", "-", "c.16140G>T", "c.(16138-16140)ttG>ttT", "p.L5380F"},
                new Object[]{"MUC16", 19, 9076695, 9076695, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076695G>A", "-", "c.10751C>T", "c.(10750-10752)tCt>tTt", "p.S3584F"},
                new Object[]{"MUC16", 19, 9084523, 9084523, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084523G>A", "-", "c.7292C>T", "c.(7291-7293)tCc>tTc", "p.S2431F"},
                new Object[]{"MUC16", 19, 9057803, 9057803, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057803C>T", "-", "c.29643G>A", "c.(29641-29643)gaG>gaA", "p.E9881E"},
                new Object[]{"MUC16", 19, 9076183, 9076183, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9076183G>T", "-", "c.11263C>A", "c.(11263-11265)Cag>Aag", "p.Q3755K"},
                new Object[]{"MUC16", 19, 9085579, 9085579, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9085579C>A", "-", "c.6236G>T", "c.(6235-6237)gGg>gTg", "p.G2079V"},
                new Object[]{"MUC16", 19, 9003603, 9003603, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9003603C>T", "-", "c.40037G>A", "c.(40036-40038)aGg>aAg", "p.R13346K"},
                new Object[]{"MUC16", 19, 9058524, 9058524, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058524G>A", "-", "c.28922C>T", "c.(28921-28923)tCc>tTc", "p.S9641F"},
                new Object[]{"MUC16", 19, 9060792, 9060792, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060792G>A", "-", "c.26654C>T", "c.(26653-26655)tCt>tTt", "p.S8885F"},
                new Object[]{"MUC16", 19, 9066038, 9066038, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9066038C>T", "-", "c.21408G>A", "c.(21406-21408)acG>acA", "p.T7136T"},
                new Object[]{"MUC16", 19, 9083300, 9083300, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083300C>T", "-", "c.8515G>A", "c.(8515-8517)Gct>Act", "p.A2839T"},
                new Object[]{"MUC16", 19, 9083630, 9083630, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083630G>A", "-", "c.8185C>T", "c.(8185-8187)Ccc>Tcc", "p.P2729S"},
                new Object[]{"MUC16", 19, 9091815, 9091815, GencodeFuncotation.VariantClassification.FIVE_PRIME_UTR, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091815G>A", "-", null, null, null},
                new Object[]{"MUC16", 19, 9072618, 9072618, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072618G>A", "-", "c.14828C>T", "c.(14827-14829)cCt>cTt", "p.P4943L"},
                new Object[]{"MUC16", 19, 9082451, 9082451, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9082451T>C", "-", "c.9364A>G", "c.(9364-9366)Aca>Gca", "p.T3122A"},
                new Object[]{"MUC16", 19, 8995651, 8995651, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8995651C>T", "-", "c.41337G>A", "c.(41335-41337)tcG>tcA", "p.S13779S"},
                new Object[]{"MUC16", 19, 8999056, 8999056, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8999056G>A", "-", "c.40788C>T", "c.(40786-40788)ttC>ttT", "p.F13596F"},
                new Object[]{"MUC16", 19, 8999545, 8999545, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999545C>T", "-", "c.40630G>A", "c.(40630-40632)Gcc>Acc", "p.A13544T"},
                new Object[]{"MUC16", 19, 9059785, 9059785, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059785C>T", "-", "c.27661G>A", "c.(27661-27663)Gag>Aag", "p.E9221K"},
                new Object[]{"MUC16", 19, 9064403, 9064403, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064403C>T", "-", "c.23043G>A", "c.(23041-23043)gtG>gtA", "p.V7681V"},
                new Object[]{"MUC16", 19, 9068247, 9068247, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068247C>T", "-", "c.19199G>A", "c.(19198-19200)aGa>aAa", "p.R6400K"},
                new Object[]{"MUC16", 19, 9075392, 9075392, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075392C>T", "-", "c.12054G>A", "c.(12052-12054)agG>agA", "p.R4018R"},
                new Object[]{"MUC16", 19, 9077118, 9077118, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077118G>A", "-", "c.10328C>T", "c.(10327-10329)tCt>tTt", "p.S3443F"},
                new Object[]{"MUC16", 19, 9089119, 9089119, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089119G>A", "-", "c.2696C>T", "c.(2695-2697)cCc>cTc", "p.P899L"},
                new Object[]{"MUC16", 19, 9047545, 9047545, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9047545G>T", "-", "c.34086C>A", "c.(34084-34086)ccC>ccA", "p.P11362P"},
                new Object[]{"MUC16", 19, 9050121, 9050121, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050121C>A", "-", "c.31510G>T", "c.(31510-31512)Gga>Tga", "p.G10504*"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9072736, 9072736, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072736G>T", "-", "c.14710C>A", "c.(14710-14712)Cag>Aag", "p.Q4904K"},
                new Object[]{"MUC16", 19, 9075333, 9075333, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9075333G>T", "-", "c.12113C>A", "c.(12112-12114)cCa>cAa", "p.P4038Q"},
                new Object[]{"MUC16", 19, 8993038, 8993038, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8993038G>A", "-", "c.41721C>T", "c.(41719-41721)ttC>ttT", "p.F13907F"},
                new Object[]{"MUC16", 19, 9046412, 9046412, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9046412G>T", "-", "c.35219C>A", "c.(35218-35220)cCa>cAa", "p.P11740Q"},
                new Object[]{"MUC16", 19, 9056344, 9056344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056344C>T", "-", "c.31102G>A", "c.(31102-31104)Gag>Aag", "p.E10368K"},
                new Object[]{"MUC16", 19, 9062981, 9062981, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062981C>T", "-", "c.24465G>A", "c.(24463-24465)agG>agA", "p.R8155R"},
                new Object[]{"MUC16", 19, 9067595, 9067595, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067595G>T", "-", "c.19851C>A", "c.(19849-19851)ccC>ccA", "p.P6617P"}
        );
    }
    static List<Object[]> provideMnpDataForMuc16_2() {
        return Arrays.asList(
                new Object[]{"MUC16", 19, 9088023, 9088023, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088023G>T", "-", "c.3792C>A", "c.(3790-3792)acC>acA", "p.T1264T"},
                new Object[]{"MUC16", 19, 9057555, 9057555, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9057555C>A", "-", "c.29891G>T", "c.(29890-29892)gGg>gTg", "p.G9964V"},
                new Object[]{"MUC16", 19, 9060665, 9060665, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9060665C>A", "-", "c.26781G>T", "c.(26779-26781)atG>atT", "p.M8927I"},
                new Object[]{"MUC16", 19, 9067289, 9067289, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067289G>T", "-", "c.20157C>A", "c.(20155-20157)ccC>ccA", "p.P6719P"},
                new Object[]{"MUC16", 19, 9067325, 9067325, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067325G>T", "-", "c.20121C>A", "c.(20119-20121)tcC>tcA", "p.S6707S"},
                new Object[]{"MUC16", 19, 9067509, 9067509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067509C>A", "-", "c.19937G>T", "c.(19936-19938)aGg>aTg", "p.R6646M"},
                new Object[]{"MUC16", 19, 9067595, 9067595, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067595G>T", "-", "c.19851C>A", "c.(19849-19851)ccC>ccA", "p.P6617P"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9072947, 9072947, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072947G>T", "-", "c.14499C>A", "c.(14497-14499)acC>acA", "p.T4833T"},
                new Object[]{"MUC16", 19, 9075334, 9075334, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9075334G>T", "-", "c.12112C>A", "c.(12112-12114)Cca>Aca", "p.P4038T"},
                new Object[]{"MUC16", 19, 9087035, 9087035, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087035C>A", "-", "c.4780G>T", "c.(4780-4782)Ggg>Tgg", "p.G1594W"},
                new Object[]{"MUC16", 19, 9087881, 9087881, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087881C>T", "-", "c.3934G>A", "c.(3934-3936)Gag>Aag", "p.E1312K"},
                new Object[]{"MUC16", 19, 9046973, 9046973, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046973G>A", "-", "c.34658C>T", "c.(34657-34659)tCt>tTt", "p.S11553F"},
                new Object[]{"MUC16", 19, 9048951, 9048951, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048951G>A", "-", "c.32680C>T", "c.(32680-32682)Cca>Tca", "p.P10894S"},
                new Object[]{"MUC16", 19, 9056776, 9056776, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056776G>A", "-", "c.30670C>T", "c.(30670-30672)Cca>Tca", "p.P10224S"},
                new Object[]{"MUC16", 19, 9060381, 9060381, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9060381A>G", "-", "c.27065T>C", "c.(27064-27066)gTt>gCt", "p.V9022A"},
                new Object[]{"MUC16", 19, 9072508, 9072508, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072508G>A", "-", "c.14938C>T", "c.(14938-14940)Cct>Tct", "p.P4980S"},
                new Object[]{"MUC16", 19, 9073507, 9073507, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073507G>A", "-", "c.13939C>T", "c.(13939-13941)Cca>Tca", "p.P4647S"},
                new Object[]{"MUC16", 19, 9084790, 9084790, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084790G>A", "-", "c.7025C>T", "c.(7024-7026)tCa>tTa", "p.S2342L"},
                new Object[]{"MUC16", 19, 9088815, 9088815, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9088815T>A", "-", "c.3000A>T", "c.(2998-3000)aaA>aaT", "p.K1000N"},
                new Object[]{"MUC16", 19, 8993535, 8993535, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8993535C>T", "-", "c.41554G>A", "c.(41554-41556)Gat>Aat", "p.D13852N"},
                new Object[]{"MUC16", 19, 9084665, 9084665, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084665C>T", "-", "c.7150G>A", "c.(7150-7152)Gat>Aat", "p.D2384N"},
                new Object[]{"MUC16", 19, 9087944, 9087944, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087944G>A", "-", "c.3871C>T", "c.(3871-3873)Cat>Tat", "p.H1291Y"},
                new Object[]{"MUC16", 19, 9089551, 9089551, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089551C>T", "-", "c.2264G>A", "c.(2263-2265)gGg>gAg", "p.G755E"},
                new Object[]{"MUC16", 19, 9091275, 9091275, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091275C>T", "-", "c.540G>A", "c.(538-540)tgG>tgA", "p.W180*"},
                new Object[]{"MUC16", 19, 9047822, 9047822, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047822G>A", "-", "c.33809C>T", "c.(33808-33810)cCt>cTt", "p.P11270L"},
                new Object[]{"MUC16", 19, 9069347, 9069347, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069347G>A", "-", "c.18099C>T", "c.(18097-18099)tcC>tcT", "p.S6033S"},
                new Object[]{"MUC16", 19, 8974062, 8974062, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8974062C>T", "-", "c.42609G>A", "c.(42607-42609)caG>caA", "p.Q14203Q"},
                new Object[]{"MUC16", 19, 9010676, 9010676, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9010676C>T", "-", "c.38985G>A", "c.(38983-38985)ggG>ggA", "p.G12995G"},
                new Object[]{"MUC16", 19, 9024172, 9024172, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9024172C>T", "-", "c.37100G>A", "c.(37099-37101)aGa>aAa", "p.R12367K"},
                new Object[]{"MUC16", 19, 9026299, 9026299, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9026299C>T", "-", "c.36687G>A", "c.(36685-36687)ctG>ctA", "p.L12229L"},
                new Object[]{"MUC16", 19, 9057930, 9057930, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057930G>A", "-", "c.29516C>T", "c.(29515-29517)aCc>aTc", "p.T9839I"},
                new Object[]{"MUC16", 19, 9062579, 9062579, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062579G>A", "-", "c.24867C>T", "c.(24865-24867)ttC>ttT", "p.F8289F"},
                new Object[]{"MUC16", 19, 9063832, 9063832, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063832G>A", "-", "c.23614C>T", "c.(23614-23616)Cca>Tca", "p.P7872S"},
                new Object[]{"MUC16", 19, 9068846, 9068846, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068846C>T", "-", "c.18600G>A", "c.(18598-18600)atG>atA", "p.M6200I"},
                new Object[]{"MUC16", 19, 9072100, 9072100, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072100C>T", "-", "c.15346G>A", "c.(15346-15348)Gaa>Aaa", "p.E5116K"},
                new Object[]{"MUC16", 19, 9073396, 9073396, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9073396C>T", "-", "c.14050G>A", "c.(14050-14052)Ggg>Agg", "p.G4684R"},
                new Object[]{"MUC16", 19, 9075372, 9075372, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9075372T>A", "-", "c.12074A>T", "c.(12073-12075)gAc>gTc", "p.D4025V"},
                new Object[]{"MUC16", 19, 9077049, 9077049, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077049G>A", "-", "c.10397C>T", "c.(10396-10398)tCt>tTt", "p.S3466F"},
                new Object[]{"MUC16", 19, 9086706, 9086706, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086706G>A", "-", "c.5109C>T", "c.(5107-5109)gtC>gtT", "p.V1703V"},
                new Object[]{"MUC16", 19, 9087251, 9087251, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087251C>T", "-", "c.4564G>A", "c.(4564-4566)Gga>Aga", "p.G1522R"},
                new Object[]{"MUC16", 19, 8976789, 8976789, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8976789C>T", "-", "c.42277G>A", "c.(42277-42279)Ggc>Agc", "p.G14093S"},
                new Object[]{"MUC16", 19, 9007833, 9007833, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9007833G>A", "-", "c.39391C>T", "c.(39391-39393)Cgg>Tgg", "p.R13131W"},
                new Object[]{"MUC16", 19, 9049605, 9049605, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049605C>T", "-", "c.32026G>A", "c.(32026-32028)Gaa>Aaa", "p.E10676K"},
                new Object[]{"MUC16", 19, 9065577, 9065577, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065577G>A", "-", "c.21869C>T", "c.(21868-21870)tCc>tTc", "p.S7290F"},
                new Object[]{"MUC16", 19, 9068354, 9068354, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068354C>T", "-", "c.19092G>A", "c.(19090-19092)ctG>ctA", "p.L6364L"},
                new Object[]{"MUC16", 19, 9068830, 9068830, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068830C>T", "-", "c.18616G>A", "c.(18616-18618)Gat>Aat", "p.D6206N"},
                new Object[]{"MUC16", 19, 9074898, 9074898, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074898G>A", "-", "c.12548C>T", "c.(12547-12549)cCc>cTc", "p.P4183L"},
                new Object[]{"MUC16", 19, 9087098, 9087098, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087098C>T", "-", "c.4717G>A", "c.(4717-4719)Gat>Aat", "p.D1573N"},
                new Object[]{"MUC16", 19, 9058260, 9058260, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058260G>A", "-", "c.29186C>T", "c.(29185-29187)tCt>tTt", "p.S9729F"},
                new Object[]{"MUC16", 19, 9067908, 9067908, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067908G>A", "-", "c.19538C>T", "c.(19537-19539)tCc>tTc", "p.S6513F"},
                new Object[]{"MUC16", 19, 9089612, 9089612, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089612C>T", "-", "c.2203G>A", "c.(2203-2205)Gat>Aat", "p.D735N"},
                new Object[]{"MUC16", 19, 9048836, 9048836, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048836C>T", "-", "c.32795G>A", "c.(32794-32796)gGa>gAa", "p.G10932E"},
                new Object[]{"MUC16", 19, 9017514, 9017514, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9017514C>T", "-", "c.37810G>A", "c.(37810-37812)Gag>Aag", "p.E12604K"},
                new Object[]{"MUC16", 19, 9048383, 9048383, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048383G>A", "-", "c.33248C>T", "c.(33247-33249)tCa>tTa", "p.S11083L"},
                new Object[]{"MUC16", 19, 9019313, 9019313, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9019313C>T", "-", "c.37574G>A", "c.(37573-37575)gGa>gAa", "p.G12525E"},
                new Object[]{"MUC16", 19, 9024180, 9024180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9024180C>T", "-", "c.37092G>A", "c.(37090-37092)gtG>gtA", "p.V12364V"},
                new Object[]{"MUC16", 19, 9058777, 9058777, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058777C>T", "-", "c.28669G>A", "c.(28669-28671)Gac>Aac", "p.D9557N"},
                new Object[]{"MUC16", 19, 9064799, 9064799, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064799G>A", "-", "c.22647C>T", "c.(22645-22647)acC>acT", "p.T7549T"},
                new Object[]{"MUC16", 19, 9066182, 9066182, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066182G>A", "-", "c.21264C>T", "c.(21262-21264)ccC>ccT", "p.P7088P"},
                new Object[]{"MUC16", 19, 9067633, 9067633, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067633C>T", "-", "c.19813G>A", "c.(19813-19815)Gaa>Aaa", "p.E6605K"},
                new Object[]{"MUC16", 19, 9070319, 9070319, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070319G>A", "-", "c.17127C>T", "c.(17125-17127)gcC>gcT", "p.A5709A"},
                new Object[]{"MUC16", 19, 9071657, 9071657, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9071657T>A", "-", "c.15789A>T", "c.(15787-15789)aaA>aaT", "p.K5263N"},
                new Object[]{"MUC16", 19, 9074385, 9074385, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074385G>A", "-", "c.13061C>T", "c.(13060-13062)tCa>tTa", "p.S4354L"},
                new Object[]{"MUC16", 19, 9082654, 9082654, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082654G>A", "-", "c.9161C>T", "c.(9160-9162)tCa>tTa", "p.S3054L"},
                new Object[]{"MUC16", 19, 9083224, 9083224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083224G>A", "-", "c.8591C>T", "c.(8590-8592)tCt>tTt", "p.S2864F"},
                new Object[]{"MUC16", 19, 9089417, 9089417, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089417C>T", "-", "c.2398G>A", "c.(2398-2400)Gaa>Aaa", "p.E800K"},
                new Object[]{"MUC16", 19, 9089977, 9089977, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089977C>T", "-", "c.1838G>A", "c.(1837-1839)gGa>gAa", "p.G613E"},
                new Object[]{"MUC16", 19, 9049206, 9049206, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049206G>A", "-", "c.32425C>T", "c.(32425-32427)Cga>Tga", "p.R10809*"},
                new Object[]{"MUC16", 19, 9090102, 9090102, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090102G>A", "-", "c.1713C>T", "c.(1711-1713)acC>acT", "p.T571T"},
                new Object[]{"MUC16", 19, 9065994, 9065994, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065994G>A", "-", "c.21452C>T", "c.(21451-21453)tCa>tTa", "p.S7151L"},
                new Object[]{"MUC16", 19, 9066578, 9066578, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066578G>A", "-", "c.20868C>T", "c.(20866-20868)acC>acT", "p.T6956T"},
                new Object[]{"MUC16", 19, 9083882, 9083882, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083882G>A", "-", "c.7933C>T", "c.(7933-7935)Ccg>Tcg", "p.P2645S"},
                new Object[]{"MUC16", 19, 8976763, 8976763, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8976763G>A", "-", "c.42303C>T", "c.(42301-42303)tcC>tcT", "p.S14101S"},
                new Object[]{"MUC16", 19, 9089089, 9089089, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089089G>A", "-", "c.2726C>T", "c.(2725-2727)gCt>gTt", "p.A909V"},
                new Object[]{"MUC16", 19, 9059200, 9059200, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059200G>A", "-", "c.28246C>T", "c.(28246-28248)Cct>Tct", "p.P9416S"},
                new Object[]{"MUC16", 19, 9061397, 9061397, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061397C>T", "-", "c.26049G>A", "c.(26047-26049)ggG>ggA", "p.G8683G"},
                new Object[]{"MUC16", 19, 9065681, 9065681, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065681C>T", "-", "c.21765G>A", "c.(21763-21765)gtG>gtA", "p.V7255V"},
                new Object[]{"MUC16", 19, 9048950, 9048950, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048950G>A", "-", "c.32681C>T", "c.(32680-32682)cCa>cTa", "p.P10894L"},
                new Object[]{"MUC16", 19, 9061069, 9061069, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061069G>A", "-", "c.26377C>T", "c.(26377-26379)Cat>Tat", "p.H8793Y"},
                new Object[]{"MUC16", 19, 9071105, 9071105, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9071105C>T", "-", "c.16341G>A", "c.(16339-16341)tcG>tcA", "p.S5447S"},
                new Object[]{"MUC16", 19, 9090567, 9090567, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090567C>T", "-", "c.1248G>A", "c.(1246-1248)gaG>gaA", "p.E416E"},
                new Object[]{"MUC16", 19, 9056557, 9056557, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056557C>T", "-", "c.30889G>A", "c.(30889-30891)Gcc>Acc", "p.A10297T"},
                new Object[]{"MUC16", 19, 9058359, 9058359, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058359C>T", "-", "c.29087G>A", "c.(29086-29088)gGa>gAa", "p.G9696E"},
                new Object[]{"MUC16", 19, 9058106, 9058106, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058106G>A", "-", "c.29340C>T", "c.(29338-29340)acC>acT", "p.T9780T"},
                new Object[]{"MUC16", 19, 9024197, 9024197, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9024197G>A", "-", "c.37075C>T", "c.(37075-37077)Cct>Tct", "p.P12359S"},
                new Object[]{"MUC16", 19, 9047620, 9047620, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047620C>A", "-", "c.34011G>T", "c.(34009-34011)gtG>gtT", "p.V11337V"},
                new Object[]{"MUC16", 19, 9059063, 9059063, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059063G>A", "-", "c.28383C>T", "c.(28381-28383)gtC>gtT", "p.V9461V"},
                new Object[]{"MUC16", 19, 9062027, 9062027, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062027G>A", "-", "c.25419C>T", "c.(25417-25419)atC>atT", "p.I8473I"},
                new Object[]{"MUC16", 19, 9088326, 9088326, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088326G>T", "-", "c.3489C>A", "c.(3487-3489)ccC>ccA", "p.P1163P"},
                new Object[]{"MUC16", 19, 9026203, 9026203, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9026203G>A", "-", "c.36783C>T", "c.(36781-36783)gtC>gtT", "p.V12261V"},
                new Object[]{"MUC16", 19, 9046630, 9046630, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046630C>T", "-", "c.35001G>A", "c.(34999-35001)ggG>ggA", "p.G11667G"},
                new Object[]{"MUC16", 19, 9058049, 9058049, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058049G>A", "-", "c.29397C>T", "c.(29395-29397)atC>atT", "p.I9799I"},
                new Object[]{"MUC16", 19, 9061992, 9061992, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061992G>A", "-", "c.25454C>T", "c.(25453-25455)cCc>cTc", "p.P8485L"},
                new Object[]{"MUC16", 19, 9068001, 9068001, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068001G>A", "-", "c.19445C>T", "c.(19444-19446)tCa>tTa", "p.S6482L"},
                new Object[]{"MUC16", 19, 9068306, 9068306, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068306G>A", "-", "c.19140C>T", "c.(19138-19140)tcC>tcT", "p.S6380S"},
                new Object[]{"MUC16", 19, 9076401, 9076401, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076401C>T", "-", "c.11045G>A", "c.(11044-11046)aGg>aAg", "p.R3682K"},
                new Object[]{"MUC16", 19, 9085991, 9085991, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085991G>A", "-", "c.5824C>T", "c.(5824-5826)Cca>Tca", "p.P1942S"},
                new Object[]{"MUC16", 19, 9087601, 9087601, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087601G>A", "-", "c.4214C>T", "c.(4213-4215)tCa>tTa", "p.S1405L"},
                new Object[]{"MUC16", 19, 9089904, 9089904, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089904G>A", "-", "c.1911C>T", "c.(1909-1911)tcC>tcT", "p.S637S"},
                new Object[]{"MUC16", 19, 9064001, 9064001, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064001G>A", "-", "c.23445C>T", "c.(23443-23445)ttC>ttT", "p.F7815F"},
                new Object[]{"MUC16", 19, 9065029, 9065029, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065029G>A", "-", "c.22417C>T", "c.(22417-22419)Cct>Tct", "p.P7473S"},
                new Object[]{"MUC16", 19, 9075173, 9075173, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075173C>T", "-", "c.12273G>A", "c.(12271-12273)atG>atA", "p.M4091I"},
                new Object[]{"MUC16", 19, 9077809, 9077809, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077809C>T", "-", "c.9637G>A", "c.(9637-9639)Gaa>Aaa", "p.E3213K"},
                new Object[]{"MUC16", 19, 9089658, 9089658, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089658C>T", "-", "c.2157G>A", "c.(2155-2157)aaG>aaA", "p.K719K"},
                new Object[]{"MUC16", 19, 9057123, 9057123, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057123C>T", "-", "c.30323G>A", "c.(30322-30324)gGa>gAa", "p.G10108E"},
                new Object[]{"MUC16", 19, 9072556, 9072556, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072556G>T", "-", "c.14890C>A", "c.(14890-14892)Cca>Aca", "p.P4964T"},
                new Object[]{"MUC16", 19, 9073406, 9073406, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9073406G>T", "-", "c.14040C>A", "c.(14038-14040)acC>acA", "p.T4680T"},
                new Object[]{"MUC16", 19, 9077090, 9077090, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077090G>A", "-", "c.10356C>T", "c.(10354-10356)atC>atT", "p.I3452I"},
                new Object[]{"MUC16", 19, 9077854, 9077854, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077854C>A", "-", "c.9592G>T", "c.(9592-9594)Gga>Tga", "p.G3198*"},
                new Object[]{"MUC16", 19, 9084602, 9084602, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9084602G>T", "-", "c.7213C>A", "c.(7213-7215)Cca>Aca", "p.P2405T"},
                new Object[]{"MUC16", 19, 9085932, 9085932, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9085932G>T", "-", "c.5883C>A", "c.(5881-5883)ccC>ccA", "p.P1961P"},
                new Object[]{"MUC16", 19, 9066699, 9066699, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066699G>T", "-", "c.20747C>A", "c.(20746-20748)cCa>cAa", "p.P6916Q"},
                new Object[]{"MUC16", 19, 9061767, 9061767, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061767G>A", "-", "c.25679C>T", "c.(25678-25680)tCt>tTt", "p.S8560F"},
                new Object[]{"MUC16", 19, 8993030, 8993030, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8993030C>A", "-", "c.41729G>T", "c.(41728-41730)cGg>cTg", "p.R13910L"},
                new Object[]{"MUC16", 19, 8994501, 8994501, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8994501G>A", "-", "c.41391C>T", "c.(41389-41391)ttC>ttT", "p.F13797F"},
                new Object[]{"MUC16", 19, 9009653, 9009653, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9009653C>A", "-", "c.39073G>T", "c.(39073-39075)Ggg>Tgg", "p.G13025W"},
                new Object[]{"MUC16", 19, 9011397, 9011397, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9011397C>T", "-", "c.38836G>A", "c.(38836-38838)Gag>Aag", "p.E12946K"},
                new Object[]{"MUC16", 19, 9020785, 9020785, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9020785G>A", "-", "c.37317C>T", "c.(37315-37317)ggC>ggT", "p.G12439G"},
                new Object[]{"MUC16", 19, 9049298, 9049298, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049298G>A", "-", "c.32333C>T", "c.(32332-32334)tCg>tTg", "p.S10778L"},
                new Object[]{"MUC16", 19, 9049400, 9049400, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049400G>A", "-", "c.32231C>T", "c.(32230-32232)tCt>tTt", "p.S10744F"},
                new Object[]{"MUC16", 19, 9049903, 9049903, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049903C>T", "-", "c.31728G>A", "c.(31726-31728)ggG>ggA", "p.G10576G"},
                new Object[]{"MUC16", 19, 9059043, 9059043, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059043G>A", "-", "c.28403C>T", "c.(28402-28404)aCc>aTc", "p.T9468I"},
                new Object[]{"MUC16", 19, 9062188, 9062188, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062188C>T", "-", "c.25258G>A", "c.(25258-25260)Gag>Aag", "p.E8420K"},
                new Object[]{"MUC16", 19, 9063016, 9063016, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063016C>T", "-", "c.24430G>A", "c.(24430-24432)Gga>Aga", "p.G8144R"},
                new Object[]{"MUC16", 19, 9066494, 9066494, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066494G>A", "-", "c.20952C>T", "c.(20950-20952)tcC>tcT", "p.S6984S"},
                new Object[]{"MUC16", 19, 9070251, 9070251, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070251G>A", "-", "c.17195C>T", "c.(17194-17196)tCa>tTa", "p.S5732L"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 9075747, 9075747, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075747G>A", "-", "c.11699C>T", "c.(11698-11700)tCc>tTc", "p.S3900F"},
                new Object[]{"MUC16", 19, 9085838, 9085838, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085838C>T", "-", "c.5977G>A", "c.(5977-5979)Gaa>Aaa", "p.E1993K"},
                new Object[]{"MUC16", 19, 9085999, 9085999, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085999G>A", "-", "c.5816C>T", "c.(5815-5817)tCa>tTa", "p.S1939L"},
                new Object[]{"MUC16", 19, 9088160, 9088160, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088160G>A", "-", "c.3655C>T", "c.(3655-3657)Ccc>Tcc", "p.P1219S"},
                new Object[]{"MUC16", 19, 9091122, 9091122, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091122C>T", "-", "c.693G>A", "c.(691-693)ggG>ggA", "p.G231G"},
                new Object[]{"MUC16", 19, 8995693, 8995693, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8995693C>T", "-", "c.41295G>A", "c.(41293-41295)ggG>ggA", "p.G13765G"},
                new Object[]{"MUC16", 19, 9005631, 9005631, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9005631G>A", "-", "c.39775C>T", "c.(39775-39777)Ctg>Ttg", "p.L13259L"},
                new Object[]{"MUC16", 19, 9066121, 9066121, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066121G>A", "-", "c.21325C>T", "c.(21325-21327)Cct>Tct", "p.P7109S"},
                new Object[]{"MUC16", 19, 9075211, 9075211, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075211G>A", "-", "c.12235C>T", "c.(12235-12237)Ctg>Ttg", "p.L4079L"},
                new Object[]{"MUC16", 19, 9076139, 9076139, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076139G>A", "-", "c.11307C>T", "c.(11305-11307)atC>atT", "p.I3769I"},
                new Object[]{"MUC16", 19, 9083269, 9083269, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083269G>A", "-", "c.8546C>T", "c.(8545-8547)cCt>cTt", "p.P2849L"},
                new Object[]{"MUC16", 19, 9090293, 9090293, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090293C>T", "-", "c.1522G>A", "c.(1522-1524)Gca>Aca", "p.A508T"},
                new Object[]{"MUC16", 19, 8994489, 8994489, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8994489G>A", "-", "c.41403C>T", "c.(41401-41403)aaC>aaT", "p.N13801N"},
                new Object[]{"MUC16", 19, 9006726, 9006726, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9006726G>T", "-", "c.39522C>A", "c.(39520-39522)acC>acA", "p.T13174T"},
                new Object[]{"MUC16", 19, 9072753, 9072753, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072753C>A", "-", "c.14693G>T", "c.(14692-14694)aGg>aTg", "p.R4898M"},
                new Object[]{"MUC16", 19, 9087035, 9087035, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087035C>A", "-", "c.4780G>T", "c.(4780-4782)Ggg>Tgg", "p.G1594W"},
                new Object[]{"MUC16", 19, 9018457, 9018457, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9018457C>A", "-", "c.37717G>T", "c.(37717-37719)Gag>Tag", "p.E12573*"},
                new Object[]{"MUC16", 19, 9064208, 9064208, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064208C>A", "-", "c.23238G>T", "c.(23236-23238)ttG>ttT", "p.L7746F"},
                new Object[]{"MUC16", 19, 9066676, 9066676, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066676C>A", "-", "c.20770G>T", "c.(20770-20772)Ggg>Tgg", "p.G6924W"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9075927, 9075927, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9075927G>T", "-", "c.11519C>A", "c.(11518-11520)cCa>cAa", "p.P3840Q"},
                new Object[]{"MUC16", 19, 9082643, 9082643, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9082643C>A", "-", "c.9172G>T", "c.(9172-9174)Ggg>Tgg", "p.G3058W"},
                new Object[]{"MUC16", 19, 8995651, 8995651, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8995651C>T", "-", "c.41337G>A", "c.(41335-41337)tcG>tcA", "p.S13779S"},
                new Object[]{"MUC16", 19, 9047148, 9047148, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047148G>A", "-", "c.34483C>T", "c.(34483-34485)Cct>Tct", "p.P11495S"},
                new Object[]{"MUC16", 19, 9058517, 9058517, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9058517T>C", "-", "c.28929A>G", "c.(28927-28929)gaA>gaG", "p.E9643E"},
                new Object[]{"MUC16", 19, 9058519, 9058519, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058519C>T", "-", "c.28927G>A", "c.(28927-28929)Gaa>Aaa", "p.E9643K"},
                new Object[]{"MUC16", 19, 9088734, 9088734, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088734C>T", "-", "c.3081G>A", "c.(3079-3081)acG>acA", "p.T1027T"},
                new Object[]{"MUC16", 19, 9089865, 9089865, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089865G>A", "-", "c.1950C>T", "c.(1948-1950)tcC>tcT", "p.S650S"},
                new Object[]{"MUC16", 19, 9089201, 9089201, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089201G>A", "-", "c.2614C>T", "c.(2614-2616)Cca>Tca", "p.P872S"},
                new Object[]{"MUC16", 19, 9090527, 9090527, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090527C>T", "-", "c.1288G>A", "c.(1288-1290)Gaa>Aaa", "p.E430K"},
                new Object[]{"MUC16", 19, 8976423, 8976423, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8976423C>T", "-", "c.42405G>A", "c.(42403-42405)aaG>aaA", "p.K14135K"},
                new Object[]{"MUC16", 19, 9046165, 9046165, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046165G>A", "-", "c.35466C>T", "c.(35464-35466)ctC>ctT", "p.L11822L"},
                new Object[]{"MUC16", 19, 9058194, 9058194, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058194G>A", "-", "c.29252C>T", "c.(29251-29253)cCc>cTc", "p.P9751L"},
                new Object[]{"MUC16", 19, 9063559, 9063559, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063559G>A", "-", "c.23887C>T", "c.(23887-23889)Ccc>Tcc", "p.P7963S"},
                new Object[]{"MUC16", 19, 9063836, 9063836, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063836G>A", "-", "c.23610C>T", "c.(23608-23610)tcC>tcT", "p.S7870S"},
                new Object[]{"MUC16", 19, 9067427, 9067427, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067427C>T", "-", "c.20019G>A", "c.(20017-20019)gaG>gaA", "p.E6673E"},
                new Object[]{"MUC16", 19, 9068660, 9068660, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068660G>A", "-", "c.18786C>T", "c.(18784-18786)atC>atT", "p.I6262I"},
                new Object[]{"MUC16", 19, 9070817, 9070817, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070817G>A", "-", "c.16629C>T", "c.(16627-16629)atC>atT", "p.I5543I"},
                new Object[]{"MUC16", 19, 9071595, 9071595, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9071595A>G", "-", "c.15851T>C", "c.(15850-15852)cTt>cCt", "p.L5284P"},
                new Object[]{"MUC16", 19, 9074295, 9074295, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074295C>T", "-", "c.13151G>A", "c.(13150-13152)gGa>gAa", "p.G4384E"},
                new Object[]{"MUC16", 19, 9082466, 9082466, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082466G>A", "-", "c.9349C>T", "c.(9349-9351)Cca>Tca", "p.P3117S"},
                new Object[]{"MUC16", 19, 9084598, 9084598, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084598G>A", "-", "c.7217C>T", "c.(7216-7218)tCt>tTt", "p.S2406F"},
                new Object[]{"MUC16", 19, 9085631, 9085631, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9085631T>C", "-", "c.6184A>G", "c.(6184-6186)Aca>Gca", "p.T2062A"},
                new Object[]{"MUC16", 19, 9089128, 9089128, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089128G>A", "-", "c.2687C>T", "c.(2686-2688)cCa>cTa", "p.P896L"},
                new Object[]{"MUC16", 19, 9091160, 9091160, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091160C>T", "-", "c.655G>A", "c.(655-657)Gac>Aac", "p.D219N"},
                new Object[]{"MUC16", 19, 8996361, 8996361, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8996361C>A", "-", "c.41211G>T", "c.(41209-41211)ctG>ctT", "p.L13737L"},
                new Object[]{"MUC16", 19, 9012882, 9012882, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9012882C>A", "-", "c.38562G>T", "c.(38560-38562)ctG>ctT", "p.L12854L"},
                new Object[]{"MUC16", 19, 9050121, 9050121, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050121C>A", "-", "c.31510G>T", "c.(31510-31512)Gga>Tga", "p.G10504*"},
                new Object[]{"MUC16", 19, 9056225, 9056225, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056225C>A", "-", "c.31221G>T", "c.(31219-31221)ctG>ctT", "p.L10407L"},
                new Object[]{"MUC16", 19, 9057172, 9057172, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057172C>T", "-", "c.30274G>A", "c.(30274-30276)Gat>Aat", "p.D10092N"},
                new Object[]{"MUC16", 19, 9057555, 9057555, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9057555C>A", "-", "c.29891G>T", "c.(29890-29892)gGg>gTg", "p.G9964V"},
                new Object[]{"MUC16", 19, 9057890, 9057890, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9057890G>T", "-", "c.29556C>A", "c.(29554-29556)acC>acA", "p.T9852T"},
                new Object[]{"MUC16", 19, 9058358, 9058358, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9058358T>A", "-", "c.29088A>T", "c.(29086-29088)ggA>ggT", "p.G9696G"},
                new Object[]{"MUC16", 19, 9061944, 9061944, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061944G>A", "-", "c.25502C>T", "c.(25501-25503)tCt>tTt", "p.S8501F"},
                new Object[]{"MUC16", 19, 9064106, 9064106, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9064106G>T", "-", "c.23340C>A", "c.(23338-23340)acC>acA", "p.T7780T"},
                new Object[]{"MUC16", 19, 9067202, 9067202, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067202C>A", "-", "c.20244G>T", "c.(20242-20244)caG>caT", "p.Q6748H"},
                new Object[]{"MUC16", 19, 9068511, 9068511, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9068511G>T", "-", "c.18935C>A", "c.(18934-18936)cCa>cAa", "p.P6312Q"},
                new Object[]{"MUC16", 19, 9075170, 9075170, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075170G>A", "-", "c.12276C>T", "c.(12274-12276)atC>atT", "p.I4092I"},
                new Object[]{"MUC16", 19, 9087932, 9087932, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087932C>T", "-", "c.3883G>A", "c.(3883-3885)Gcc>Acc", "p.A1295T"},
                new Object[]{"MUC16", 19, 9088008, 9088008, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088008C>A", "-", "c.3807G>T", "c.(3805-3807)atG>atT", "p.M1269I"},
                new Object[]{"MUC16", 19, 9046044, 9046044, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046044G>A", "-", "c.35587C>T", "c.(35587-35589)Cca>Tca", "p.P11863S"},
                new Object[]{"MUC16", 19, 9056224, 9056224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056224C>T", "-", "c.31222G>A", "c.(31222-31224)Gga>Aga", "p.G10408R"},
                new Object[]{"MUC16", 19, 9068790, 9068790, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9068790T>C", "-", "c.18656A>G", "c.(18655-18657)aAc>aGc", "p.N6219S"},
                new Object[]{"MUC16", 19, 9091259, 9091259, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091259G>A", "-", "c.556C>T", "c.(556-558)Cct>Tct", "p.P186S"},
                new Object[]{"MUC16", 19, 9063944, 9063944, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063944C>T", "-", "c.23502G>A", "c.(23500-23502)agG>agA", "p.R7834R"},
                new Object[]{"MUC16", 19, 9070509, 9070509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070509G>A", "-", "c.16937C>T", "c.(16936-16938)tCc>tTc", "p.S5646F"},
                new Object[]{"MUC16", 19, 9084874, 9084874, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084874C>T", "-", "c.6941G>A", "c.(6940-6942)gGa>gAa", "p.G2314E"},
                new Object[]{"MUC16", 19, 8982215, 8982215, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8982215G>A", "-", "c.42060C>T", "c.(42058-42060)acC>acT", "p.T14020T"},
                new Object[]{"MUC16", 19, 9068901, 9068901, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068901C>T", "-", "c.18545G>A", "c.(18544-18546)gGa>gAa", "p.G6182E"},
                new Object[]{"MUC16", 19, 9087679, 9087679, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087679G>A", "-", "c.4136C>T", "c.(4135-4137)cCg>cTg", "p.P1379L"},
                new Object[]{"MUC16", 19, 9049101, 9049101, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049101G>A", "-", "c.32530C>T", "c.(32530-32532)Cat>Tat", "p.H10844Y"},
                new Object[]{"MUC16", 19, 9061597, 9061597, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061597G>A", "-", "c.25849C>T", "c.(25849-25851)Cca>Tca", "p.P8617S"},
                new Object[]{"MUC16", 19, 9085375, 9085375, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085375G>A", "-", "c.6440C>T", "c.(6439-6441)cCa>cTa", "p.P2147L"},
                new Object[]{"MUC16", 19, 9089206, 9089206, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089206G>A", "-", "c.2609C>T", "c.(2608-2610)tCg>tTg", "p.S870L"},
                new Object[]{"MUC16", 19, 9046005, 9046005, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046005C>T", "-", "c.35626G>A", "c.(35626-35628)Ggc>Agc", "p.G11876S"},
                new Object[]{"MUC16", 19, 9047030, 9047030, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047030G>A", "-", "c.34601C>T", "c.(34600-34602)tCa>tTa", "p.S11534L"},
                new Object[]{"MUC16", 19, 9050067, 9050067, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9050067C>T", "-", "c.31564G>A", "c.(31564-31566)Gaa>Aaa", "p.E10522K"},
                new Object[]{"MUC16", 19, 9056254, 9056254, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056254C>T", "-", "c.31192G>A", "c.(31192-31194)Gat>Aat", "p.D10398N"},
                new Object[]{"MUC16", 19, 9058180, 9058180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058180G>A", "-", "c.29266C>T", "c.(29266-29268)Cct>Tct", "p.P9756S"},
                new Object[]{"MUC16", 19, 9059369, 9059369, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059369C>T", "-", "c.28077G>A", "c.(28075-28077)agG>agA", "p.R9359R"},
                new Object[]{"MUC16", 19, 9060190, 9060190, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060190G>A", "-", "c.27256C>T", "c.(27256-27258)Cct>Tct", "p.P9086S"},
                new Object[]{"MUC16", 19, 9062066, 9062066, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062066G>A", "-", "c.25380C>T", "c.(25378-25380)tcC>tcT", "p.S8460S"},
                new Object[]{"MUC16", 19, 9062157, 9062157, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062157G>A", "-", "c.25289C>T", "c.(25288-25290)gCc>gTc", "p.A8430V"},
                new Object[]{"MUC16", 19, 9062601, 9062601, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062601G>A", "-", "c.24845C>T", "c.(24844-24846)tCc>tTc", "p.S8282F"},
                new Object[]{"MUC16", 19, 9062726, 9062726, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062726C>T", "-", "c.24720G>A", "c.(24718-24720)gaG>gaA", "p.E8240E"},
                new Object[]{"MUC16", 19, 9062910, 9062910, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062910G>A", "-", "c.24536C>T", "c.(24535-24537)tCc>tTc", "p.S8179F"},
                new Object[]{"MUC16", 19, 9063117, 9063117, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063117C>T", "-", "c.24329G>A", "c.(24328-24330)aGa>aAa", "p.R8110K"},
                new Object[]{"MUC16", 19, 9064409, 9064409, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064409G>A", "-", "c.23037C>T", "c.(23035-23037)ccC>ccT", "p.P7679P"},
                new Object[]{"MUC16", 19, 9067148, 9067148, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067148C>T", "-", "c.20298G>A", "c.(20296-20298)tcG>tcA", "p.S6766S"},
                new Object[]{"MUC16", 19, 9067300, 9067300, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067300C>T", "-", "c.20146G>A", "c.(20146-20148)Gaa>Aaa", "p.E6716K"},
                new Object[]{"MUC16", 19, 9071745, 9071745, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071745G>A", "-", "c.15701C>T", "c.(15700-15702)tCc>tTc", "p.S5234F"},
                new Object[]{"MUC16", 19, 9072286, 9072286, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072286G>A", "-", "c.15160C>T", "c.(15160-15162)Ctg>Ttg", "p.L5054L"},
                new Object[]{"MUC16", 19, 9076700, 9076700, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076700G>A", "-", "c.10746C>T", "c.(10744-10746)acC>acT", "p.T3582T"},
                new Object[]{"MUC16", 19, 9085622, 9085622, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085622G>A", "-", "c.6193C>T", "c.(6193-6195)Cca>Tca", "p.P2065S"},
                new Object[]{"MUC16", 19, 9087347, 9087347, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087347G>A", "-", "c.4468C>T", "c.(4468-4470)Cca>Tca", "p.P1490S"},
                new Object[]{"MUC16", 19, 8987295, 8987295, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8987295G>A", "-", "c.41792C>T", "c.(41791-41793)aCc>aTc", "p.T13931I"},
                new Object[]{"MUC16", 19, 8995651, 8995651, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8995651C>T", "-", "c.41337G>A", "c.(41335-41337)tcG>tcA", "p.S13779S"},
                new Object[]{"MUC16", 19, 8996339, 8996339, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8996339C>T", "-", "c.41233G>A", "c.(41233-41235)Gac>Aac", "p.D13745N"},
                new Object[]{"MUC16", 19, 9014700, 9014700, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014700C>T", "-", "c.38275G>A", "c.(38275-38277)Gag>Aag", "p.E12759K"},
                new Object[]{"MUC16", 19, 9047769, 9047769, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047769C>T", "-", "c.33862G>A", "c.(33862-33864)Gaa>Aaa", "p.E11288K"},
                new Object[]{"MUC16", 19, 9048182, 9048182, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048182C>T", "-", "c.33449G>A", "c.(33448-33450)gGa>gAa", "p.G11150E"},
                new Object[]{"MUC16", 19, 9056181, 9056181, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056181C>A", "-", "c.31265G>T", "c.(31264-31266)cGg>cTg", "p.R10422L"},
                new Object[]{"MUC16", 19, 9057157, 9057157, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057157G>A", "-", "c.30289C>T", "c.(30289-30291)Cat>Tat", "p.H10097Y"},
                new Object[]{"MUC16", 19, 9057747, 9057747, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057747C>T", "-", "c.29699G>A", "c.(29698-29700)gGa>gAa", "p.G9900E"},
                new Object[]{"MUC16", 19, 9058027, 9058027, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058027G>A", "-", "c.29419C>T", "c.(29419-29421)Cat>Tat", "p.H9807Y"},
                new Object[]{"MUC16", 19, 9058186, 9058186, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058186G>A", "-", "c.29260C>T", "c.(29260-29262)Cct>Tct", "p.P9754S"},
                new Object[]{"MUC16", 19, 9058245, 9058245, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058245G>A", "-", "c.29201C>T", "c.(29200-29202)cCt>cTt", "p.P9734L"},
                new Object[]{"MUC16", 19, 9060853, 9060853, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060853G>A", "-", "c.26593C>T", "c.(26593-26595)Cct>Tct", "p.P8865S"},
                new Object[]{"MUC16", 19, 9063558, 9063558, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063558G>A", "-", "c.23888C>T", "c.(23887-23889)cCc>cTc", "p.P7963L"},
                new Object[]{"MUC16", 19, 9066356, 9066356, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066356G>A", "-", "c.21090C>T", "c.(21088-21090)atC>atT", "p.I7030I"},
                new Object[]{"MUC16", 19, 9069052, 9069052, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069052C>T", "-", "c.18394G>A", "c.(18394-18396)Gac>Aac", "p.D6132N"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9071740, 9071740, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071740G>T", "-", "c.15706C>A", "c.(15706-15708)Cca>Aca", "p.P5236T"},
                new Object[]{"MUC16", 19, 9071831, 9071831, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071831C>A", "-", "c.15615G>T", "c.(15613-15615)acG>acT", "p.T5205T"},
                new Object[]{"MUC16", 19, 9072284, 9072284, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072284C>T", "-", "c.15162G>A", "c.(15160-15162)ctG>ctA", "p.L5054L"},
                new Object[]{"MUC16", 19, 9074244, 9074244, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074244G>A", "-", "c.13202C>T", "c.(13201-13203)cCa>cTa", "p.P4401L"},
                new Object[]{"MUC16", 19, 9076530, 9076530, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076530C>T", "-", "c.10916G>A", "c.(10915-10917)gGa>gAa", "p.G3639E"},
                new Object[]{"MUC16", 19, 9085684, 9085684, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9085684C>A", "-", "c.6131G>T", "c.(6130-6132)aGg>aTg", "p.R2044M"},
                new Object[]{"MUC16", 19, 9086617, 9086617, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086617G>A", "-", "c.5198C>T", "c.(5197-5199)tCc>tTc", "p.S1733F"},
                new Object[]{"MUC16", 19, 9088509, 9088509, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088509G>A", "-", "c.3306C>T", "c.(3304-3306)ttC>ttT", "p.F1102F"},
                new Object[]{"MUC16", 19, 9088886, 9088886, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088886C>A", "-", "c.2929G>T", "c.(2929-2931)Ggg>Tgg", "p.G977W"},
                new Object[]{"MUC16", 19, 9088984, 9088984, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088984C>A", "-", "c.2831G>T", "c.(2830-2832)gGg>gTg", "p.G944V"},
                new Object[]{"MUC16", 19, 9089342, 9089342, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9089342C>A", "-", "c.2473G>T", "c.(2473-2475)Ggg>Tgg", "p.G825W"},
                new Object[]{"MUC16", 19, 9000475, 9000475, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9000475C>T", "-", "c.40509G>A", "c.(40507-40509)aaG>aaA", "p.K13503K"},
                new Object[]{"MUC16", 19, 9047652, 9047652, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047652C>A", "-", "c.33979G>T", "c.(33979-33981)Ggg>Tgg", "p.G11327W"},
                new Object[]{"MUC16", 19, 9059670, 9059670, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9059670G>T", "-", "c.27776C>A", "c.(27775-27777)cCc>cAc", "p.P9259H"},
                new Object[]{"MUC16", 19, 9070823, 9070823, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9070823G>T", "-", "c.16623C>A", "c.(16621-16623)ccC>ccA", "p.P5541P"},
                new Object[]{"MUC16", 19, 9090729, 9090729, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090729C>T", "-", "c.1086G>A", "c.(1084-1086)gaG>gaA", "p.E362E"},
                new Object[]{"MUC16", 19, 9082508, 9082508, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082508C>T", "-", "c.9307G>A", "c.(9307-9309)Gaa>Aaa", "p.E3103K"},
                new Object[]{"MUC16", 19, 8976641, 8976641, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8976641G>A", "-", "c.42335C>T", "c.(42334-42336)cCc>cTc", "p.P14112L"},
                new Object[]{"MUC16", 19, 8996320, 8996320, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8996320C>A", "-", "c.e61-1G>T", "c.e61+1", null},
                new Object[]{"MUC16", 19, 9046168, 9046168, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9046168A>C", "-", "c.35463T>G", "c.(35461-35463)tcT>tcG", "p.S11821S"},
                new Object[]{"MUC16", 19, 9048344, 9048344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048344C>T", "-", "c.33287G>A", "c.(33286-33288)gGa>gAa", "p.G11096E"},
                new Object[]{"MUC16", 19, 9049397, 9049397, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049397C>A", "-", "c.32234G>T", "c.(32233-32235)gGg>gTg", "p.G10745V"},
                new Object[]{"MUC16", 19, 9049996, 9049996, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049996C>A", "-", "c.31635G>T", "c.(31633-31635)ctG>ctT", "p.L10545L"},
                new Object[]{"MUC16", 19, 9050128, 9050128, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050128G>T", "-", "c.31503C>A", "c.(31501-31503)ccC>ccA", "p.P10501P"},
                new Object[]{"MUC16", 19, 9059164, 9059164, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059164C>T", "-", "c.28282G>A", "c.(28282-28284)Gaa>Aaa", "p.E9428K"},
                new Object[]{"MUC16", 19, 9062912, 9062912, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9062912A>C", "-", "c.24534T>G", "c.(24532-24534)acT>acG", "p.T8178T"},
                new Object[]{"MUC16", 19, 9064631, 9064631, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9064631G>T", "-", "c.22815C>A", "c.(22813-22815)ccC>ccA", "p.P7605P"},
                new Object[]{"MUC16", 19, 9067341, 9067341, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067341G>A", "-", "c.20105C>T", "c.(20104-20106)cCa>cTa", "p.P6702L"},
                new Object[]{"MUC16", 19, 9068288, 9068288, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068288G>A", "-", "c.19158C>T", "c.(19156-19158)gtC>gtT", "p.V6386V"},
                new Object[]{"MUC16", 19, 9068704, 9068704, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068704G>A", "-", "c.18742C>T", "c.(18742-18744)Ctt>Ttt", "p.L6248F"},
                new Object[]{"MUC16", 19, 9071155, 9071155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071155C>A", "-", "c.16291G>T", "c.(16291-16293)Ggg>Tgg", "p.G5431W"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9071268, 9071268, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071268G>T", "-", "c.16178C>A", "c.(16177-16179)cCa>cAa", "p.P5393Q"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9072482, 9072482, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9072482A>T", "-", "c.14964T>A", "c.(14962-14964)acT>acA", "p.T4988T"},
                new Object[]{"MUC16", 19, 9074153, 9074153, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074153G>A", "-", "c.13293C>T", "c.(13291-13293)ctC>ctT", "p.L4431L"},
                new Object[]{"MUC16", 19, 9077737, 9077737, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077737G>A", "-", "c.9709C>T", "c.(9709-9711)Ccc>Tcc", "p.P3237S"},
                new Object[]{"MUC16", 19, 9085246, 9085246, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085246G>A", "-", "c.6569C>T", "c.(6568-6570)tCt>tTt", "p.S2190F"},
                new Object[]{"MUC16", 19, 9085456, 9085456, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085456G>A", "-", "c.6359C>T", "c.(6358-6360)aCt>aTt", "p.T2120I"},
                new Object[]{"MUC16", 19, 9086274, 9086274, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086274G>A", "-", "c.5541C>T", "c.(5539-5541)ctC>ctT", "p.L1847L"},
                new Object[]{"MUC16", 19, 9088061, 9088061, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088061G>T", "-", "c.3754C>A", "c.(3754-3756)Cac>Aac", "p.H1252N"},
                new Object[]{"MUC16", 19, 9091626, 9091626, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091626G>T", "-", "c.189C>A", "c.(187-189)acC>acA", "p.T63T"},
                new Object[]{"MUC16", 19, 8994510, 8994510, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8994510G>A", "-", "c.41382C>T", "c.(41380-41382)acC>acT", "p.T13794T"},
                new Object[]{"MUC16", 19, 9020006, 9020006, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:9020006T>G", "-", "c.37489A>C", "c.(37489-37491)Agg>Cgg", "p.R12497R"},
                new Object[]{"MUC16", 19, 9047708, 9047708, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047708G>A", "-", "c.33923C>T", "c.(33922-33924)tCa>tTa", "p.S11308L"},
                new Object[]{"MUC16", 19, 9061105, 9061105, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061105C>T", "-", "c.26341G>A", "c.(26341-26343)Gga>Aga", "p.G8781R"},
                new Object[]{"MUC16", 19, 9063611, 9063611, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063611C>T", "-", "c.23835G>A", "c.(23833-23835)caG>caA", "p.Q7945Q"},
                new Object[]{"MUC16", 19, 9065098, 9065098, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9065098T>C", "-", "c.22348A>G", "c.(22348-22350)Agt>Ggt", "p.S7450G"},
                new Object[]{"MUC16", 19, 9067599, 9067599, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067599G>A", "-", "c.19847C>T", "c.(19846-19848)cCa>cTa", "p.P6616L"},
                new Object[]{"MUC16", 19, 9067811, 9067811, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067811G>A", "-", "c.19635C>T", "c.(19633-19635)ccC>ccT", "p.P6545P"},
                new Object[]{"MUC16", 19, 9072587, 9072587, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072587G>A", "-", "c.14859C>T", "c.(14857-14859)tcC>tcT", "p.S4953S"},
                new Object[]{"MUC16", 19, 9075783, 9075783, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075783G>A", "-", "c.11663C>T", "c.(11662-11664)tCt>tTt", "p.S3888F"},
                new Object[]{"MUC16", 19, 9076568, 9076568, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076568G>A", "-", "c.10878C>T", "c.(10876-10878)gaC>gaT", "p.D3626D"},
                new Object[]{"MUC16", 19, 9089200, 9089200, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089200G>A", "-", "c.2615C>T", "c.(2614-2616)cCa>cTa", "p.P872L"},
                new Object[]{"MUC16", 19, 9061891, 9061891, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9061891A>C", "-", "c.25555T>G", "c.(25555-25557)Ttt>Gtt", "p.F8519V"},
                new Object[]{"MUC16", 19, 9064250, 9064250, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064250C>A", "-", "c.23196G>T", "c.(23194-23196)ttG>ttT", "p.L7732F"},
                new Object[]{"MUC16", 19, 9065698, 9065698, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065698C>T", "-", "c.21748G>A", "c.(21748-21750)Gag>Aag", "p.E7250K"},
                new Object[]{"MUC16", 19, 9067464, 9067464, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067464C>T", "-", "c.19982G>A", "c.(19981-19983)gGa>gAa", "p.G6661E"},
                new Object[]{"MUC16", 19, 9084946, 9084946, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084946G>A", "-", "c.6869C>T", "c.(6868-6870)cCt>cTt", "p.P2290L"},
                new Object[]{"MUC16", 19, 9090790, 9090790, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090790C>T", "-", "c.1025G>A", "c.(1024-1026)aGg>aAg", "p.R342K"},
                new Object[]{"MUC16", 19, 9000207, 9000207, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9000207G>A", "-", "c.40550C>T", "c.(40549-40551)cCt>cTt", "p.P13517L"},
                new Object[]{"MUC16", 19, 9048855, 9048855, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "G", "g.chr19:9048855C>G", "-", "c.32776G>C", "c.(32776-32778)Gtt>Ctt", "p.V10926L"},
                new Object[]{"MUC16", 19, 9050072, 9050072, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050072G>T", "-", "c.31559C>A", "c.(31558-31560)cCc>cAc", "p.P10520H"},
                new Object[]{"MUC16", 19, 9056855, 9056855, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056855C>T", "-", "c.30591G>A", "c.(30589-30591)caG>caA", "p.Q10197Q"},
                new Object[]{"MUC16", 19, 9060891, 9060891, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060891G>A", "-", "c.26555C>T", "c.(26554-26556)cCt>cTt", "p.P8852L"},
                new Object[]{"MUC16", 19, 9067222, 9067222, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067222G>A", "-", "c.20224C>T", "c.(20224-20226)Cct>Tct", "p.P6742S"},
                new Object[]{"MUC16", 19, 9085534, 9085534, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085534G>A", "-", "c.6281C>T", "c.(6280-6282)tCa>tTa", "p.S2094L"},
                new Object[]{"MUC16", 19, 9009683, 9009683, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9009683G>T", "-", "c.39043C>A", "c.(39043-39045)Ctc>Atc", "p.L13015I"},
                new Object[]{"MUC16", 19, 9025625, 9025625, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9025625G>A", "-", "c.36829C>T", "c.(36829-36831)Cct>Tct", "p.P12277S"},
                new Object[]{"MUC16", 19, 9059322, 9059322, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059322C>A", "-", "c.28124G>T", "c.(28123-28125)gGg>gTg", "p.G9375V"},
                new Object[]{"MUC16", 19, 9071069, 9071069, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071069C>A", "-", "c.16377G>T", "c.(16375-16377)ctG>ctT", "p.L5459L"},
                new Object[]{"MUC16", 19, 9071125, 9071125, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071125G>T", "-", "c.16321C>A", "c.(16321-16323)Cta>Ata", "p.L5441I"},
                new Object[]{"MUC16", 19, 9072162, 9072162, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072162G>T", "-", "c.15284C>A", "c.(15283-15285)cCa>cAa", "p.P5095Q"},
                new Object[]{"MUC16", 19, 9086925, 9086925, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9086925G>T", "-", "c.4890C>A", "c.(4888-4890)ccC>ccA", "p.P1630P"},
                new Object[]{"MUC16", 19, 9087026, 9087026, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087026C>A", "-", "c.4789G>T", "c.(4789-4791)Ggg>Tgg", "p.G1597W"},
                new Object[]{"MUC16", 19, 9088016, 9088016, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088016G>T", "-", "c.3799C>A", "c.(3799-3801)Ctt>Att", "p.L1267I"},
                new Object[]{"MUC16", 19, 9047238, 9047238, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9047238T>C", "-", "c.34393A>G", "c.(34393-34395)Atc>Gtc", "p.I11465V"},
                new Object[]{"MUC16", 19, 9058153, 9058153, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058153G>A", "-", "c.29293C>T", "c.(29293-29295)Ctg>Ttg", "p.L9765L"},
                new Object[]{"MUC16", 19, 9060828, 9060828, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060828G>A", "-", "c.26618C>T", "c.(26617-26619)tCt>tTt", "p.S8873F"},
                new Object[]{"MUC16", 19, 9067275, 9067275, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067275G>A", "-", "c.20171C>T", "c.(20170-20172)tCc>tTc", "p.S6724F"},
                new Object[]{"MUC16", 19, 9075800, 9075800, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075800G>A", "-", "c.11646C>T", "c.(11644-11646)atC>atT", "p.I3882I"},
                new Object[]{"MUC16", 19, 8969371, 8969371, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:8969371G>T", "-", "c.42973C>A", "c.(42973-42975)Ctg>Atg", "p.L14325M"},
                new Object[]{"MUC16", 19, 8976814, 8976814, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8976814G>A", "-", "c.42252C>T", "c.(42250-42252)tcC>tcT", "p.S14084S"},
                new Object[]{"MUC16", 19, 8999411, 8999411, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999411C>T", "-", "c.40764G>A", "c.(40762-40764)agG>agA", "p.R13588R"},
                new Object[]{"MUC16", 19, 9056350, 9056350, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056350C>A", "-", "c.31096G>T", "c.(31096-31098)Ggg>Tgg", "p.G10366W"},
                new Object[]{"MUC16", 19, 9058382, 9058382, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058382C>T", "-", "c.29064G>A", "c.(29062-29064)ggG>ggA", "p.G9688G"},
                new Object[]{"MUC16", 19, 9062761, 9062761, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9062761G>T", "-", "c.24685C>A", "c.(24685-24687)Cac>Aac", "p.H8229N"},
                new Object[]{"MUC16", 19, 9064481, 9064481, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064481C>A", "-", "c.22965G>T", "c.(22963-22965)caG>caT", "p.Q7655H"},
                new Object[]{"MUC16", 19, 9067233, 9067233, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067233C>T", "-", "c.20213G>A", "c.(20212-20214)cGa>cAa", "p.R6738Q"},
                new Object[]{"MUC16", 19, 9068878, 9068878, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068878C>T", "-", "c.18568G>A", "c.(18568-18570)Gat>Aat", "p.D6190N"},
                new Object[]{"MUC16", 19, 9083313, 9083313, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083313C>T", "-", "c.8502G>A", "c.(8500-8502)acG>acA", "p.T2834T"},
                new Object[]{"MUC16", 19, 9088160, 9088160, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088160G>A", "-", "c.3655C>T", "c.(3655-3657)Ccc>Tcc", "p.P1219S"},
                new Object[]{"MUC16", 19, 9091523, 9091523, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9091523C>A", "-", "c.292G>T", "c.(292-294)Gag>Tag", "p.E98*"},
                new Object[]{"MUC16", 19, 9048354, 9048354, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048354C>T", "-", "c.33277G>A", "c.(33277-33279)Ggg>Agg", "p.G11093R"},
                new Object[]{"MUC16", 19, 9061528, 9061528, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061528G>A", "-", "c.25918C>T", "c.(25918-25920)Cat>Tat", "p.H8640Y"},
                new Object[]{"MUC16", 19, 9070177, 9070177, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070177C>T", "-", "c.17269G>A", "c.(17269-17271)Gat>Aat", "p.D5757N"},
                new Object[]{"MUC16", 19, 9086891, 9086891, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086891C>T", "-", "c.4924G>A", "c.(4924-4926)Gga>Aga", "p.G1642R"},
                new Object[]{"MUC16", 19, 9090179, 9090179, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090179C>T", "-", "c.1636G>A", "c.(1636-1638)Gag>Aag", "p.E546K"},
                new Object[]{"MUC16", 19, 9077268, 9077268, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077268C>A", "-", "c.10178G>T", "c.(10177-10179)tGg>tTg", "p.W3393L"},
                new Object[]{"MUC16", 19, 9089293, 9089293, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9089293G>T", "-", "c.2522C>A", "c.(2521-2523)cCa>cAa", "p.P841Q"},
                new Object[]{"MUC16", 19, 9006648, 9006648, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006648C>A", "-", "c.39600G>T", "c.(39598-39600)caG>caT", "p.Q13200H"},
                new Object[]{"MUC16", 19, 9017365, 9017365, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9017365C>T", "-", "c.37959G>A", "c.(37957-37959)agG>agA", "p.R12653R"},
                new Object[]{"MUC16", 19, 9050203, 9050203, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050203G>T", "-", "c.31428C>A", "c.(31426-31428)acC>acA", "p.T10476T"},
                new Object[]{"MUC16", 19, 9066824, 9066824, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066824G>T", "-", "c.20622C>A", "c.(20620-20622)acC>acA", "p.T6874T"},
                new Object[]{"MUC16", 19, 9088885, 9088885, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088885C>A", "-", "c.2930G>T", "c.(2929-2931)gGg>gTg", "p.G977V"},
                new Object[]{"MUC16", 19, 9012794, 9012794, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9012794C>T", "-", "c.38650G>A", "c.(38650-38652)Gag>Aag", "p.E12884K"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9068061, 9068061, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9068061C>A", "-", "c.19385G>T", "c.(19384-19386)tGg>tTg", "p.W6462L"},
                new Object[]{"MUC16", 19, 9070360, 9070360, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070360C>T", "-", "c.17086G>A", "c.(17086-17088)Gag>Aag", "p.E5696K"},
                new Object[]{"MUC16", 19, 9070678, 9070678, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9070678G>T", "-", "c.16768C>A", "c.(16768-16770)Cag>Aag", "p.Q5590K"},
                new Object[]{"MUC16", 19, 9063451, 9063451, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063451G>A", "-", "c.23995C>T", "c.(23995-23997)Ctt>Ttt", "p.L7999F"},
                new Object[]{"MUC16", 19, 9083258, 9083258, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9083258T>C", "-", "c.8557A>G", "c.(8557-8559)Acc>Gcc", "p.T2853A"},
                new Object[]{"MUC16", 19, 9049457, 9049457, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049457G>A", "-", "c.32174C>T", "c.(32173-32175)cCa>cTa", "p.P10725L"},
                new Object[]{"MUC16", 19, 9057986, 9057986, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057986G>A", "-", "c.29460C>T", "c.(29458-29460)tcC>tcT", "p.S9820S"},
                new Object[]{"MUC16", 19, 9062265, 9062265, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062265G>A", "-", "c.25181C>T", "c.(25180-25182)tCc>tTc", "p.S8394F"},
                new Object[]{"MUC16", 19, 9063262, 9063262, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9063262C>A", "-", "c.24184G>T", "c.(24184-24186)Ggg>Tgg", "p.G8062W"},
                new Object[]{"MUC16", 19, 9065135, 9065135, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065135C>A", "-", "c.22311G>T", "c.(22309-22311)ttG>ttT", "p.L7437F"},
                new Object[]{"MUC16", 19, 9065268, 9065268, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065268G>A", "-", "c.22178C>T", "c.(22177-22179)tCt>tTt", "p.S7393F"},
                new Object[]{"MUC16", 19, 9066502, 9066502, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9066502C>T", "-", "c.20944G>A", "c.(20944-20946)Gag>Aag", "p.E6982K"},
                new Object[]{"MUC16", 19, 9070884, 9070884, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070884C>T", "-", "c.16562G>A", "c.(16561-16563)aGa>aAa", "p.R5521K"},
                new Object[]{"MUC16", 19, 9074523, 9074523, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9074523C>A", "-", "c.12923G>T", "c.(12922-12924)gGa>gTa", "p.G4308V"},
                new Object[]{"MUC16", 19, 9074994, 9074994, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074994G>A", "-", "c.12452C>T", "c.(12451-12453)cCc>cTc", "p.P4151L"},
                new Object[]{"MUC16", 19, 9077717, 9077717, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9077717T>C", "-", "c.9729A>G", "c.(9727-9729)gaA>gaG", "p.E3243E"},
                new Object[]{"MUC16", 19, 9085475, 9085475, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085475G>A", "-", "c.6340C>T", "c.(6340-6342)Cag>Tag", "p.Q2114*"},
                new Object[]{"MUC16", 19, 9017374, 9017374, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9017374G>T", "-", "c.37950C>A", "c.(37948-37950)acC>acA", "p.T12650T"},
                new Object[]{"MUC16", 19, 9060089, 9060089, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060089C>T", "-", "c.27357G>A", "c.(27355-27357)atG>atA", "p.M9119I"},
                new Object[]{"MUC16", 19, 9085016, 9085016, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085016G>A", "-", "c.6799C>T", "c.(6799-6801)Cca>Tca", "p.P2267S"},
                new Object[]{"MUC16", 19, 9090344, 9090344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9090344C>A", "-", "c.1471G>T", "c.(1471-1473)Ggg>Tgg", "p.G491W"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9059418, 9059418, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059418G>A", "-", "c.28028C>T", "c.(28027-28029)tCa>tTa", "p.S9343L"},
                new Object[]{"MUC16", 19, 9062966, 9062966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062966G>A", "-", "c.24480C>T", "c.(24478-24480)tcC>tcT", "p.S8160S"},
                new Object[]{"MUC16", 19, 9068026, 9068026, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9068026G>T", "-", "c.19420C>A", "c.(19420-19422)Cac>Aac", "p.H6474N"},
                new Object[]{"MUC16", 19, 9007535, 9007535, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "G", "g.chr19:9007535C>G", "-", "c.39433G>C", "c.(39433-39435)Gtt>Ctt", "p.V13145L"},
                new Object[]{"MUC16", 19, 9061785, 9061785, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061785G>A", "-", "c.25661C>T", "c.(25660-25662)tCt>tTt", "p.S8554F"},
                new Object[]{"MUC16", 19, 9076829, 9076829, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076829G>A", "-", "c.10617C>T", "c.(10615-10617)tcC>tcT", "p.S3539S"},
                new Object[]{"MUC16", 19, 9085565, 9085565, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9085565T>C", "-", "c.6250A>G", "c.(6250-6252)Agt>Ggt", "p.S2084G"},
                new Object[]{"MUC16", 19, 9086535, 9086535, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086535C>T", "-", "c.5280G>A", "c.(5278-5280)gtG>gtA", "p.V1760V"},
                new Object[]{"MUC16", 19, 8993443, 8993443, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8993443C>T", "-", "c.41646G>A", "c.(41644-41646)ctG>ctA", "p.L13882L"},
                new Object[]{"MUC16", 19, 9024193, 9024193, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9024193C>T", "-", "c.37079G>A", "c.(37078-37080)gGg>gAg", "p.G12360E"},
                new Object[]{"MUC16", 19, 9027222, 9027222, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9027222G>A", "-", "c.36664C>T", "c.(36664-36666)Ccc>Tcc", "p.P12222S"},
                new Object[]{"MUC16", 19, 9046853, 9046853, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046853G>A", "-", "c.34778C>T", "c.(34777-34779)cCc>cTc", "p.P11593L"},
                new Object[]{"MUC16", 19, 9048058, 9048058, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048058C>T", "-", "c.33573G>A", "c.(33571-33573)atG>atA", "p.M11191I"},
                new Object[]{"MUC16", 19, 9048675, 9048675, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048675C>T", "-", "c.32956G>A", "c.(32956-32958)Gga>Aga", "p.G10986R"},
                new Object[]{"MUC16", 19, 9048764, 9048764, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9048764A>G", "-", "c.32867T>C", "c.(32866-32868)cTt>cCt", "p.L10956P"},
                new Object[]{"MUC16", 19, 9048771, 9048771, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9048771A>G", "-", "c.32860T>C", "c.(32860-32862)Ttt>Ctt", "p.F10954L"},
                new Object[]{"MUC16", 19, 9057605, 9057605, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057605C>T", "-", "c.29841G>A", "c.(29839-29841)atG>atA", "p.M9947I"},
                new Object[]{"MUC16", 19, 9061493, 9061493, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061493C>T", "-", "c.25953G>A", "c.(25951-25953)ggG>ggA", "p.G8651G"},
                new Object[]{"MUC16", 19, 9061789, 9061789, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061789G>A", "-", "c.25657C>T", "c.(25657-25659)Ccc>Tcc", "p.P8553S"},
                new Object[]{"MUC16", 19, 9066175, 9066175, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9066175C>T", "-", "c.21271G>A", "c.(21271-21273)Gaa>Aaa", "p.E7091K"},
                new Object[]{"MUC16", 19, 9068160, 9068160, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068160G>A", "-", "c.19286C>T", "c.(19285-19287)aCc>aTc", "p.T6429I"},
                new Object[]{"MUC16", 19, 9071105, 9071105, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9071105C>T", "-", "c.16341G>A", "c.(16339-16341)tcG>tcA", "p.S5447S"},
                new Object[]{"MUC16", 19, 9071673, 9071673, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071673G>A", "-", "c.15773C>T", "c.(15772-15774)tCc>tTc", "p.S5258F"},
                new Object[]{"MUC16", 19, 9073701, 9073701, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073701G>A", "-", "c.13745C>T", "c.(13744-13746)tCa>tTa", "p.S4582L"},
                new Object[]{"MUC16", 19, 9074883, 9074883, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074883G>A", "-", "c.12563C>T", "c.(12562-12564)cCt>cTt", "p.P4188L"},
                new Object[]{"MUC16", 19, 9076887, 9076887, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076887G>A", "-", "c.10559C>T", "c.(10558-10560)tCa>tTa", "p.S3520L"},
                new Object[]{"MUC16", 19, 9088356, 9088356, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088356G>A", "-", "c.3459C>T", "c.(3457-3459)atC>atT", "p.I1153I"},
                new Object[]{"MUC16", 19, 9012861, 9012861, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9012861G>A", "-", "c.38583C>T", "c.(38581-38583)ttC>ttT", "p.F12861F"},
                new Object[]{"MUC16", 19, 9063534, 9063534, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063534G>A", "-", "c.23912C>T", "c.(23911-23913)tCc>tTc", "p.S7971F"},
                new Object[]{"MUC16", 19, 9047542, 9047542, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047542C>T", "-", "c.34089G>A", "c.(34087-34089)agG>agA", "p.R11363R"},
                new Object[]{"MUC16", 19, 9061524, 9061524, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9061524G>T", "-", "c.25922C>A", "c.(25921-25923)cCc>cAc", "p.P8641H"},
                new Object[]{"MUC16", 19, 9084753, 9084753, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084753G>A", "-", "c.7062C>T", "c.(7060-7062)atC>atT", "p.I2354I"},
                new Object[]{"MUC16", 19, 9087200, 9087200, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087200G>T", "-", "c.4615C>A", "c.(4615-4617)Cca>Aca", "p.P1539T"},
                new Object[]{"MUC16", 19, 9090527, 9090527, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090527C>T", "-", "c.1288G>A", "c.(1288-1290)Gaa>Aaa", "p.E430K"},
                new Object[]{"MUC16", 19, 9056721, 9056721, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056721C>A", "-", "c.30725G>T", "c.(30724-30726)gGg>gTg", "p.G10242V"},
                new Object[]{"MUC16", 19, 9059445, 9059445, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9059445G>T", "-", "c.28001C>A", "c.(28000-28002)cCa>cAa", "p.P9334Q"},
                new Object[]{"MUC16", 19, 9065737, 9065737, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065737G>A", "-", "c.21709C>T", "c.(21709-21711)Cag>Tag", "p.Q7237*"},
                new Object[]{"MUC16", 19, 9070839, 9070839, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9070839C>A", "-", "c.16607G>T", "c.(16606-16608)cGg>cTg", "p.R5536L"},
                new Object[]{"MUC16", 19, 9077420, 9077420, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077420C>T", "-", "c.10026G>A", "c.(10024-10026)atG>atA", "p.M3342I"},
                new Object[]{"MUC16", 19, 9086816, 9086816, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086816C>T", "-", "c.4999G>A", "c.(4999-5001)Gaa>Aaa", "p.E1667K"},
                new Object[]{"MUC16", 19, 8994429, 8994429, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8994429G>A", "-", "c.41463C>T", "c.(41461-41463)gtC>gtT", "p.V13821V"},
                new Object[]{"MUC16", 19, 8997151, 8997151, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8997151G>A", "-", "c.41045C>T", "c.(41044-41046)cCt>cTt", "p.P13682L"},
                new Object[]{"MUC16", 19, 9046048, 9046048, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046048C>T", "-", "c.35583G>A", "c.(35581-35583)atG>atA", "p.M11861I"},
                new Object[]{"MUC16", 19, 9046526, 9046526, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046526G>A", "-", "c.35105C>T", "c.(35104-35106)tCc>tTc", "p.S11702F"},
                new Object[]{"MUC16", 19, 9048749, 9048749, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048749G>A", "-", "c.32882C>T", "c.(32881-32883)aCc>aTc", "p.T10961I"},
                new Object[]{"MUC16", 19, 9067634, 9067634, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067634C>T", "-", "c.19812G>A", "c.(19810-19812)aaG>aaA", "p.K6604K"},
                new Object[]{"MUC16", 19, 9069682, 9069682, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069682C>T", "-", "c.17764G>A", "c.(17764-17766)Gaa>Aaa", "p.E5922K"},
                new Object[]{"MUC16", 19, 9074913, 9074913, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074913G>A", "-", "c.12533C>T", "c.(12532-12534)tCa>tTa", "p.S4178L"},
                new Object[]{"MUC16", 19, 9077780, 9077780, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077780G>T", "-", "c.9666C>A", "c.(9664-9666)tcC>tcA", "p.S3222S"},
                new Object[]{"MUC16", 19, 9082925, 9082925, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082925C>T", "-", "c.8890G>A", "c.(8890-8892)Gga>Aga", "p.G2964R"},
                new Object[]{"MUC16", 19, 9088751, 9088751, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088751G>A", "-", "c.3064C>T", "c.(3064-3066)Ctc>Ttc", "p.L1022F"},
                new Object[]{"MUC16", 19, 9090523, 9090523, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090523C>T", "-", "c.1292G>A", "c.(1291-1293)gGa>gAa", "p.G431E"},
                new Object[]{"MUC16", 19, 9046526, 9046526, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046526G>A", "-", "c.35105C>T", "c.(35104-35106)tCc>tTc", "p.S11702F"},
                new Object[]{"MUC16", 19, 9057584, 9057584, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057584C>T", "-", "c.29862G>A", "c.(29860-29862)atG>atA", "p.M9954I"},
                new Object[]{"MUC16", 19, 9063943, 9063943, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063943C>T", "-", "c.23503G>A", "c.(23503-23505)Gag>Aag", "p.E7835K"},
                new Object[]{"MUC16", 19, 9064386, 9064386, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064386G>A", "-", "c.23060C>T", "c.(23059-23061)cCa>cTa", "p.P7687L"},
                new Object[]{"MUC16", 19, 9065317, 9065317, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065317C>T", "-", "c.22129G>A", "c.(22129-22131)Gat>Aat", "p.D7377N"},
                new Object[]{"MUC16", 19, 9085985, 9085985, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085985C>T", "-", "c.5830G>A", "c.(5830-5832)Gaa>Aaa", "p.E1944K"},
                new Object[]{"MUC16", 19, 9089865, 9089865, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089865G>A", "-", "c.1950C>T", "c.(1948-1950)tcC>tcT", "p.S650S"},
                new Object[]{"MUC16", 19, 9090467, 9090467, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090467C>T", "-", "c.1348G>A", "c.(1348-1350)Gaa>Aaa", "p.E450K"},
                new Object[]{"MUC16", 19, 9063015, 9063015, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063015C>T", "-", "c.24431G>A", "c.(24430-24432)gGa>gAa", "p.G8144E"},
                new Object[]{"MUC16", 19, 9073638, 9073638, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9073638C>T", "-", "c.13808G>A", "c.(13807-13809)cGa>cAa", "p.R4603Q"},
                new Object[]{"MUC16", 19, 9087174, 9087174, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087174C>T", "-", "c.4641G>A", "c.(4639-4641)gtG>gtA", "p.V1547V"},
                new Object[]{"MUC16", 19, 9088962, 9088962, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088962G>A", "-", "c.2853C>T", "c.(2851-2853)acC>acT", "p.T951T"},
                new Object[]{"MUC16", 19, 9069185, 9069185, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069185C>T", "-", "c.18261G>A", "c.(18259-18261)atG>atA", "p.M6087I"},
                new Object[]{"MUC16", 19, 9074964, 9074964, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074964G>A", "-", "c.12482C>T", "c.(12481-12483)tCc>tTc", "p.S4161F"},
                new Object[]{"MUC16", 19, 9077248, 9077248, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077248G>A", "-", "c.10198C>T", "c.(10198-10200)Ccc>Tcc", "p.P3400S"},
                new Object[]{"MUC16", 19, 9077155, 9077155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077155C>T", "-", "c.10291G>A", "c.(10291-10293)Gat>Aat", "p.D3431N"},
                new Object[]{"MUC16", 19, 8997424, 8997424, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8997424G>A", "-", "c.40998C>T", "c.(40996-40998)gtC>gtT", "p.V13666V"},
                new Object[]{"MUC16", 19, 9010671, 9010671, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9010671G>A", "-", "c.38990C>T", "c.(38989-38991)cCa>cTa", "p.P12997L"},
                new Object[]{"MUC16", 19, 9020067, 9020067, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9020067C>A", "-", "c.37428G>T", "c.(37426-37428)ctG>ctT", "p.L12476L"},
                new Object[]{"MUC16", 19, 9047882, 9047882, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9047882A>G", "-", "c.33749T>C", "c.(33748-33750)gTt>gCt", "p.V11250A"},
                new Object[]{"MUC16", 19, 9059000, 9059000, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059000C>T", "-", "c.28446G>A", "c.(28444-28446)ttG>ttA", "p.L9482L"},
                new Object[]{"MUC16", 19, 9066420, 9066420, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066420G>A", "-", "c.21026C>T", "c.(21025-21027)tCc>tTc", "p.S7009F"},
                new Object[]{"MUC16", 19, 9077424, 9077424, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077424C>T", "-", "c.10022G>A", "c.(10021-10023)gGa>gAa", "p.G3341E"},
                new Object[]{"MUC16", 19, 9077700, 9077700, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077700G>A", "-", "c.9746C>T", "c.(9745-9747)tCc>tTc", "p.S3249F"},
                new Object[]{"MUC16", 19, 9082792, 9082792, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082792G>A", "-", "c.9023C>T", "c.(9022-9024)tCt>tTt", "p.S3008F"},
                new Object[]{"MUC16", 19, 9089551, 9089551, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9089551C>A", "-", "c.2264G>T", "c.(2263-2265)gGg>gTg", "p.G755V"},
                new Object[]{"MUC16", 19, 9091402, 9091402, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091402C>T", "-", "c.413G>A", "c.(412-414)gGa>gAa", "p.G138E"},
                new Object[]{"MUC16", 19, 9020060, 9020060, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9020060C>T", "-", "c.37435G>A", "c.(37435-37437)Gag>Aag", "p.E12479K"},
                new Object[]{"MUC16", 19, 9045944, 9045944, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045944G>A", "-", "c.35687C>T", "c.(35686-35688)tCc>tTc", "p.S11896F"},
                new Object[]{"MUC16", 19, 9050170, 9050170, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9050170C>T", "-", "c.31461G>A", "c.(31459-31461)aaG>aaA", "p.K10487K"},
                new Object[]{"MUC16", 19, 9089011, 9089011, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089011G>A", "-", "c.2804C>T", "c.(2803-2805)gCt>gTt", "p.A935V"},
                new Object[]{"MUC16", 19, 8976277, 8976277, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:8976277T>C", "-", "c.42551A>G", "c.(42550-42552)gAt>gGt", "p.D14184G"},
                new Object[]{"MUC16", 19, 9028394, 9028394, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9028394G>A", "-", "c.36398C>T", "c.(36397-36399)cCa>cTa", "p.P12133L"},
                new Object[]{"MUC16", 19, 9056722, 9056722, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056722C>T", "-", "c.30724G>A", "c.(30724-30726)Ggg>Agg", "p.G10242R"},
                new Object[]{"MUC16", 19, 9059214, 9059214, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9059214G>T", "-", "c.28232C>A", "c.(28231-28233)cCt>cAt", "p.P9411H"},
                new Object[]{"MUC16", 19, 9069094, 9069094, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069094G>A", "-", "c.18352C>T", "c.(18352-18354)Cct>Tct", "p.P6118S"},
                new Object[]{"MUC16", 19, 9070548, 9070548, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070548G>A", "-", "c.16898C>T", "c.(16897-16899)tCc>tTc", "p.S5633F"},
                new Object[]{"MUC16", 19, 9083510, 9083510, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083510C>T", "-", "c.8305G>A", "c.(8305-8307)Gag>Aag", "p.E2769K"},
                new Object[]{"MUC16", 19, 9085683, 9085683, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085683C>T", "-", "c.6132G>A", "c.(6130-6132)agG>agA", "p.R2044R"},
                new Object[]{"MUC16", 19, 9063144, 9063144, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063144G>A", "-", "c.24302C>T", "c.(24301-24303)tCa>tTa", "p.S8101L"},
                new Object[]{"MUC16", 19, 9006663, 9006663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006663C>A", "-", "c.39585G>T", "c.(39583-39585)acG>acT", "p.T13195T"},
                new Object[]{"MUC16", 19, 9059806, 9059806, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9059806T>C", "-", "c.27640A>G", "c.(27640-27642)Act>Gct", "p.T9214A"},
                new Object[]{"MUC16", 19, 9060801, 9060801, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9060801C>A", "-", "c.26645G>T", "c.(26644-26646)cGg>cTg", "p.R8882L"},
                new Object[]{"MUC16", 19, 9066158, 9066158, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066158G>A", "-", "c.21288C>T", "c.(21286-21288)ctC>ctT", "p.L7096L"},
                new Object[]{"MUC16", 19, 9066699, 9066699, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066699G>T", "-", "c.20747C>A", "c.(20746-20748)cCa>cAa", "p.P6916Q"},
                new Object[]{"MUC16", 19, 9074234, 9074234, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9074234C>A", "-", "c.13212G>T", "c.(13210-13212)ttG>ttT", "p.L4404F"},
                new Object[]{"MUC16", 19, 9091402, 9091402, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091402C>T", "-", "c.413G>A", "c.(412-414)gGa>gAa", "p.G138E"},
                new Object[]{"MUC16", 19, 8976783, 8976783, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8976783C>T", "-", "c.42283G>A", "c.(42283-42285)Ggc>Agc", "p.G14095S"},
                new Object[]{"MUC16", 19, 8993392, 8993392, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8993392C>T", "-", "c.41697G>A", "c.(41695-41697)agG>agA", "p.R13899R"},
                new Object[]{"MUC16", 19, 8999468, 8999468, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999468C>T", "-", "c.40707G>A", "c.(40705-40707)tgG>tgA", "p.W13569*"},
                new Object[]{"MUC16", 19, 9005651, 9005651, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9005651C>T", "-", "c.39755G>A", "c.(39754-39756)aGa>aAa", "p.R13252K"},
                new Object[]{"MUC16", 19, 9059777, 9059777, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059777C>T", "-", "c.27669G>A", "c.(27667-27669)ctG>ctA", "p.L9223L"},
                new Object[]{"MUC16", 19, 9064452, 9064452, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064452G>A", "-", "c.22994C>T", "c.(22993-22995)tCc>tTc", "p.S7665F"},
                new Object[]{"MUC16", 19, 9070263, 9070263, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070263G>A", "-", "c.17183C>T", "c.(17182-17184)tCt>tTt", "p.S5728F"},
                new Object[]{"MUC16", 19, 9083416, 9083416, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083416C>T", "-", "c.8399G>A", "c.(8398-8400)gGa>gAa", "p.G2800E"},
                new Object[]{"MUC16", 19, 9083906, 9083906, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083906C>T", "-", "c.7909G>A", "c.(7909-7911)Gga>Aga", "p.G2637R"},
                new Object[]{"MUC16", 19, 9084779, 9084779, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084779C>T", "-", "c.7036G>A", "c.(7036-7038)Gaa>Aaa", "p.E2346K"},
                // Had to change gt transcript change
                new Object[]{"MUC16", 19, 9009333, 9009333, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9009333A>G", "-", "c.39140T>C", "c.(39139-39141)cTt>cCt", "p.L13047P"},
                new Object[]{"MUC16", 19, 9045834, 9045834, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9045834C>T", "-", "c.35797G>A", "c.(35797-35799)Gaa>Aaa", "p.E11933K"},
                new Object[]{"MUC16", 19, 9056448, 9056448, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056448G>A", "-", "c.30998C>T", "c.(30997-30999)tCc>tTc", "p.S10333F"},
                new Object[]{"MUC16", 19, 9057356, 9057356, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057356C>T", "-", "c.30090G>A", "c.(30088-30090)acG>acA", "p.T10030T"},
                new Object[]{"MUC16", 19, 9057556, 9057556, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057556C>T", "-", "c.29890G>A", "c.(29890-29892)Ggg>Agg", "p.G9964R"},
                new Object[]{"MUC16", 19, 9061857, 9061857, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061857C>T", "-", "c.25589G>A", "c.(25588-25590)gGa>gAa", "p.G8530E"},
                new Object[]{"MUC16", 19, 9063622, 9063622, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9063622A>C", "-", "c.23824T>G", "c.(23824-23826)Tca>Gca", "p.S7942A"},
                new Object[]{"MUC16", 19, 9071269, 9071269, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071269G>A", "-", "c.16177C>T", "c.(16177-16179)Cca>Tca", "p.P5393S"},
                new Object[]{"MUC16", 19, 9074894, 9074894, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074894G>A", "-", "c.12552C>T", "c.(12550-12552)tcC>tcT", "p.S4184S"},
                new Object[]{"MUC16", 19, 9077502, 9077502, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077502G>A", "-", "c.9944C>T", "c.(9943-9945)tCc>tTc", "p.S3315F"},
                new Object[]{"MUC16", 19, 9082654, 9082654, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082654G>A", "-", "c.9161C>T", "c.(9160-9162)tCa>tTa", "p.S3054L"}
        );
    }
    static List<Object[]> provideMnpDataForMuc16_3() {
        return Arrays.asList(
                new Object[]{"MUC16", 19, 9083542, 9083542, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083542G>A", "-", "c.8273C>T", "c.(8272-8274)tCc>tTc", "p.S2758F"},
                new Object[]{"MUC16", 19, 9088564, 9088564, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088564G>A", "-", "c.3251C>T", "c.(3250-3252)cCa>cTa", "p.P1084L"},
                new Object[]{"MUC16", 19, 9089213, 9089213, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089213C>T", "-", "c.2602G>A", "c.(2602-2604)Gaa>Aaa", "p.E868K"},
                new Object[]{"MUC16", 19, 9047336, 9047336, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "C", "g.chr19:9047336G>C", "-", "c.34295C>G", "c.(34294-34296)aCa>aGa", "p.T11432R"},
                new Object[]{"MUC16", 19, 9056795, 9056795, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056795G>A", "-", "c.30651C>T", "c.(30649-30651)gcC>gcT", "p.A10217A"},
                new Object[]{"MUC16", 19, 9062444, 9062444, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062444G>A", "-", "c.25002C>T", "c.(25000-25002)acC>acT", "p.T8334T"},
                new Object[]{"MUC16", 19, 9069683, 9069683, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069683C>T", "-", "c.17763G>A", "c.(17761-17763)gtG>gtA", "p.V5921V"},
                new Object[]{"MUC16", 19, 9072540, 9072540, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072540G>A", "-", "c.14906C>T", "c.(14905-14907)tCt>tTt", "p.S4969F"},
                new Object[]{"MUC16", 19, 9075414, 9075414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075414G>A", "-", "c.12032C>T", "c.(12031-12033)tCc>tTc", "p.S4011F"},
                new Object[]{"MUC16", 19, 9077007, 9077007, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077007C>T", "-", "c.10439G>A", "c.(10438-10440)gGa>gAa", "p.G3480E"},
                new Object[]{"MUC16", 19, 9083474, 9083474, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083474C>T", "-", "c.8341G>A", "c.(8341-8343)Gag>Aag", "p.E2781K"},
                new Object[]{"MUC16", 19, 9020815, 9020815, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9020815C>A", "-", "c.37287G>T", "c.(37285-37287)aaG>aaT", "p.K12429N"},
                new Object[]{"MUC16", 19, 9080467, 9080467, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9080467C>A", "-", "c.9564G>T", "c.(9562-9564)acG>acT", "p.T3188T"},
                new Object[]{"MUC16", 19, 9085579, 9085579, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9085579C>A", "-", "c.6236G>T", "c.(6235-6237)gGg>gTg", "p.G2079V"},
                new Object[]{"MUC16", 19, 9026197, 9026197, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9026197C>A", "-", "c.36789G>T", "c.(36787-36789)caG>caT", "p.Q12263H"},
                new Object[]{"MUC16", 19, 9059369, 9059369, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059369C>T", "-", "c.28077G>A", "c.(28075-28077)agG>agA", "p.R9359R"},
                new Object[]{"MUC16", 19, 9060440, 9060440, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9060440G>T", "-", "c.27006C>A", "c.(27004-27006)ccC>ccA", "p.P9002P"},
                new Object[]{"MUC16", 19, 9069820, 9069820, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9069820G>T", "-", "c.17626C>A", "c.(17626-17628)Ctt>Att", "p.L5876I"},
                new Object[]{"MUC16", 19, 9071164, 9071164, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071164C>A", "-", "c.16282G>T", "c.(16282-16284)Ggg>Tgg", "p.G5428W"},
                new Object[]{"MUC16", 19, 9073396, 9073396, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9073396C>A", "-", "c.14050G>T", "c.(14050-14052)Ggg>Tgg", "p.G4684W"},
                new Object[]{"MUC16", 19, 9010677, 9010677, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9010677C>T", "-", "c.38984G>A", "c.(38983-38985)gGg>gAg", "p.G12995E"},
                new Object[]{"MUC16", 19, 9058282, 9058282, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058282C>T", "-", "c.29164G>A", "c.(29164-29166)Gaa>Aaa", "p.E9722K"},
                new Object[]{"MUC16", 19, 9060313, 9060313, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060313C>T", "-", "c.27133G>A", "c.(27133-27135)Gga>Aga", "p.G9045R"},
                new Object[]{"MUC16", 19, 9065879, 9065879, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065879G>A", "-", "c.21567C>T", "c.(21565-21567)ccC>ccT", "p.P7189P"},
                new Object[]{"MUC16", 19, 9082421, 9082421, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082421C>T", "-", "c.9394G>A", "c.(9394-9396)Gaa>Aaa", "p.E3132K"},
                new Object[]{"MUC16", 19, 9082689, 9082689, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082689G>A", "-", "c.9126C>T", "c.(9124-9126)ttC>ttT", "p.F3042F"},
                new Object[]{"MUC16", 19, 9006663, 9006663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006663C>A", "-", "c.39585G>T", "c.(39583-39585)acG>acT", "p.T13195T"},
                new Object[]{"MUC16", 19, 9046066, 9046066, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046066C>T", "-", "c.35565G>A", "c.(35563-35565)ggG>ggA", "p.G11855G"},
                new Object[]{"MUC16", 19, 9049996, 9049996, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049996C>A", "-", "c.31635G>T", "c.(31633-31635)ctG>ctT", "p.L10545L"},
                new Object[]{"MUC16", 19, 9050128, 9050128, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050128G>T", "-", "c.31503C>A", "c.(31501-31503)ccC>ccA", "p.P10501P"},
                new Object[]{"MUC16", 19, 9056224, 9056224, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9056224C>A", "-", "c.31222G>T", "c.(31222-31224)Gga>Tga", "p.G10408*"},
                new Object[]{"MUC16", 19, 9057465, 9057465, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9057465G>T", "-", "c.29981C>A", "c.(29980-29982)tCa>tAa", "p.S9994*"},
                new Object[]{"MUC16", 19, 9058976, 9058976, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9058976G>T", "-", "c.28470C>A", "c.(28468-28470)ccC>ccA", "p.P9490P"},
                new Object[]{"MUC16", 19, 9061272, 9061272, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061272C>T", "-", "c.26174G>A", "c.(26173-26175)aGa>aAa", "p.R8725K"},
                new Object[]{"MUC16", 19, 9063888, 9063888, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063888G>A", "-", "c.23558C>T", "c.(23557-23559)tCt>tTt", "p.S7853F"},
                new Object[]{"MUC16", 19, 9065348, 9065348, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065348C>T", "-", "c.22098G>A", "c.(22096-22098)gaG>gaA", "p.E7366E"},
                new Object[]{"MUC16", 19, 9067129, 9067129, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067129G>A", "-", "c.20317C>T", "c.(20317-20319)Cca>Tca", "p.P6773S"},
                new Object[]{"MUC16", 19, 9068032, 9068032, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068032C>T", "-", "c.19414G>A", "c.(19414-19416)Ggg>Agg", "p.G6472R"},
                new Object[]{"MUC16", 19, 9071155, 9071155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071155C>A", "-", "c.16291G>T", "c.(16291-16293)Ggg>Tgg", "p.G5431W"},
                new Object[]{"MUC16", 19, 9073481, 9073481, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073481G>A", "-", "c.13965C>T", "c.(13963-13965)ttC>ttT", "p.F4655F"},
                new Object[]{"MUC16", 19, 9074039, 9074039, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9074039G>T", "-", "c.13407C>A", "c.(13405-13407)tcC>tcA", "p.S4469S"},
                new Object[]{"MUC16", 19, 9075932, 9075932, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075932C>T", "-", "c.11514G>A", "c.(11512-11514)gtG>gtA", "p.V3838V"},
                new Object[]{"MUC16", 19, 9077246, 9077246, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077246G>T", "-", "c.10200C>A", "c.(10198-10200)ccC>ccA", "p.P3400P"},
                new Object[]{"MUC16", 19, 9077276, 9077276, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077276G>A", "-", "c.10170C>T", "c.(10168-10170)acC>acT", "p.T3390T"},
                new Object[]{"MUC16", 19, 9087822, 9087822, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087822C>T", "-", "c.3993G>A", "c.(3991-3993)aaG>aaA", "p.K1331K"},
                new Object[]{"MUC16", 19, 9088636, 9088636, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088636C>T", "-", "c.3179G>A", "c.(3178-3180)gGa>gAa", "p.G1060E"},
                new Object[]{"MUC16", 19, 9090360, 9090360, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090360G>T", "-", "c.1455C>A", "c.(1453-1455)acC>acA", "p.T485T"},
                new Object[]{"MUC16", 19, 9065699, 9065699, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065699C>A", "-", "c.21747G>T", "c.(21745-21747)agG>agT", "p.R7249S"},
                new Object[]{"MUC16", 19, 9001894, 9001894, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9001894G>A", "-", "c.40354C>T", "c.(40354-40356)Cct>Tct", "p.P13452S"},
                new Object[]{"MUC16", 19, 9057582, 9057582, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057582G>A", "-", "c.29864C>T", "c.(29863-29865)aCc>aTc", "p.T9955I"},
                new Object[]{"MUC16", 19, 9072036, 9072036, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072036G>A", "-", "c.15410C>T", "c.(15409-15411)tCc>tTc", "p.S5137F"},
                new Object[]{"MUC16", 19, 9075374, 9075374, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075374C>T", "-", "c.12072G>A", "c.(12070-12072)atG>atA", "p.M4024I"},
                new Object[]{"MUC16", 19, 9076820, 9076820, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076820G>A", "-", "c.10626C>T", "c.(10624-10626)atC>atT", "p.I3542I"},
                new Object[]{"MUC16", 19, 9076887, 9076887, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076887G>A", "-", "c.10559C>T", "c.(10558-10560)tCa>tTa", "p.S3520L"},
                new Object[]{"MUC16", 19, 9047523, 9047523, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9047523G>T", "-", "c.34108C>A", "c.(34108-34110)Cat>Aat", "p.H11370N"},
                new Object[]{"MUC16", 19, 9049482, 9049482, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049482C>A", "-", "c.32149G>T", "c.(32149-32151)Ggg>Tgg", "p.G10717W"},
                new Object[]{"MUC16", 19, 9063269, 9063269, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9063269G>T", "-", "c.24177C>A", "c.(24175-24177)acC>acA", "p.T8059T"},
                new Object[]{"MUC16", 19, 9067202, 9067202, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067202C>A", "-", "c.20244G>T", "c.(20242-20244)caG>caT", "p.Q6748H"},
                new Object[]{"MUC16", 19, 9067377, 9067377, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067377C>A", "-", "c.20069G>T", "c.(20068-20070)aGg>aTg", "p.R6690M"},
                new Object[]{"MUC16", 19, 9069338, 9069338, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9069338G>T", "-", "c.18108C>A", "c.(18106-18108)tcC>tcA", "p.S6036S"},
                new Object[]{"MUC16", 19, 9069789, 9069789, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9069789C>A", "-", "c.17657G>T", "c.(17656-17658)tGg>tTg", "p.W5886L"},
                new Object[]{"MUC16", 19, 9069841, 9069841, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9069841C>A", "-", "c.17605G>T", "c.(17605-17607)Ggg>Tgg", "p.G5869W"},
                new Object[]{"MUC16", 19, 9070701, 9070701, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9070701C>A", "-", "c.16745G>T", "c.(16744-16746)tGg>tTg", "p.W5582L"},
                new Object[]{"MUC16", 19, 9071155, 9071155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071155C>A", "-", "c.16291G>T", "c.(16291-16293)Ggg>Tgg", "p.G5431W"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9071306, 9071306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071306C>A", "-", "c.16140G>T", "c.(16138-16140)ttG>ttT", "p.L5380F"},
                new Object[]{"MUC16", 19, 9076057, 9076057, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9076057C>A", "-", "c.11389G>T", "c.(11389-11391)Gga>Tga", "p.G3797*"},
                new Object[]{"MUC16", 19, 9085769, 9085769, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085769G>A", "-", "c.6046C>T", "c.(6046-6048)Cat>Tat", "p.H2016Y"},
                new Object[]{"MUC16", 19, 9087533, 9087533, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087533C>A", "-", "c.4282G>T", "c.(4282-4284)Gga>Tga", "p.G1428*"},
                new Object[]{"MUC16", 19, 9074606, 9074606, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074606G>A", "-", "c.12840C>T", "c.(12838-12840)atC>atT", "p.I4280I"},
                new Object[]{"MUC16", 19, 9090533, 9090533, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090533C>T", "-", "c.1282G>A", "c.(1282-1284)Gaa>Aaa", "p.E428K"},
                new Object[]{"MUC16", 19, 9005617, 9005617, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9005617G>A", "-", "c.39789C>T", "c.(39787-39789)acC>acT", "p.T13263T"},
                new Object[]{"MUC16", 19, 9012794, 9012794, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9012794C>T", "-", "c.38650G>A", "c.(38650-38652)Gag>Aag", "p.E12884K"},
                new Object[]{"MUC16", 19, 9061224, 9061224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061224G>A", "-", "c.26222C>T", "c.(26221-26223)tCc>tTc", "p.S8741F"},
                new Object[]{"MUC16", 19, 9063963, 9063963, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063963G>A", "-", "c.23483C>T", "c.(23482-23484)tCc>tTc", "p.S7828F"},
                new Object[]{"MUC16", 19, 9072184, 9072184, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072184C>T", "-", "c.15262G>A", "c.(15262-15264)Gaa>Aaa", "p.E5088K"},
                new Object[]{"MUC16", 19, 9074844, 9074844, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074844C>T", "-", "c.12602G>A", "c.(12601-12603)gGg>gAg", "p.G4201E"},
                new Object[]{"MUC16", 19, 9086150, 9086150, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086150C>T", "-", "c.5665G>A", "c.(5665-5667)Gga>Aga", "p.G1889R"},
                new Object[]{"MUC16", 19, 9088781, 9088781, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9088781T>C", "-", "c.3034A>G", "c.(3034-3036)Act>Gct", "p.T1012A"},
                new Object[]{"MUC16", 19, 9057542, 9057542, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057542C>T", "-", "c.29904G>A", "c.(29902-29904)caG>caA", "p.Q9968Q"},
                new Object[]{"MUC16", 19, 9060102, 9060102, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060102G>A", "-", "c.27344C>T", "c.(27343-27345)tCa>tTa", "p.S9115L"},
                new Object[]{"MUC16", 19, 9065577, 9065577, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065577G>A", "-", "c.21869C>T", "c.(21868-21870)tCc>tTc", "p.S7290F"},
                new Object[]{"MUC16", 19, 9066477, 9066477, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066477G>A", "-", "c.20969C>T", "c.(20968-20970)tCc>tTc", "p.S6990F"},
                new Object[]{"MUC16", 19, 9072101, 9072101, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072101C>T", "-", "c.15345G>A", "c.(15343-15345)aaG>aaA", "p.K5115K"},
                new Object[]{"MUC16", 19, 9083586, 9083586, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083586C>T", "-", "c.8229G>A", "c.(8227-8229)tcG>tcA", "p.S2743S"},
                new Object[]{"MUC16", 19, 9084607, 9084607, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084607G>A", "-", "c.7208C>T", "c.(7207-7209)tCc>tTc", "p.S2403F"},
                new Object[]{"MUC16", 19, 9088521, 9088521, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088521C>T", "-", "c.3294G>A", "c.(3292-3294)agG>agA", "p.R1098R"},
                new Object[]{"MUC16", 19, 9014552, 9014552, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014552C>T", "-", "c.38423G>A", "c.(38422-38424)aGa>aAa", "p.R12808K"},
                new Object[]{"MUC16", 19, 9046211, 9046211, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046211C>T", "-", "c.35420G>A", "c.(35419-35421)gGt>gAt", "p.G11807D"},
                new Object[]{"MUC16", 19, 9065700, 9065700, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065700C>A", "-", "c.21746G>T", "c.(21745-21747)aGg>aTg", "p.R7249M"},
                new Object[]{"MUC16", 19, 9068621, 9068621, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9068621T>A", "-", "c.18825A>T", "c.(18823-18825)tcA>tcT", "p.S6275S"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 9014698, 9014698, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014698C>T", "-", "c.38277G>A", "c.(38275-38277)gaG>gaA", "p.E12759E"},
                new Object[]{"MUC16", 19, 9049043, 9049043, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049043G>A", "-", "c.32588C>T", "c.(32587-32589)tCa>tTa", "p.S10863L"},
                new Object[]{"MUC16", 19, 9049196, 9049196, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9049196G>T", "-", "c.32435C>A", "c.(32434-32436)aCa>aAa", "p.T10812K"},
                new Object[]{"MUC16", 19, 9050048, 9050048, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050048G>T", "-", "c.31583C>A", "c.(31582-31584)cCa>cAa", "p.P10528Q"},
                new Object[]{"MUC16", 19, 9089405, 9089405, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9089405C>A", "-", "c.2410G>T", "c.(2410-2412)Ggg>Tgg", "p.G804W"},
                new Object[]{"MUC16", 19, 9061038, 9061038, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061038G>A", "-", "c.26408C>T", "c.(26407-26409)aCc>aTc", "p.T8803I"},
                new Object[]{"MUC16", 19, 9088636, 9088636, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9088636C>T", "-", "c.3179G>A", "c.(3178-3180)gGa>gAa", "p.G1060E"},
                new Object[]{"MUC16", 19, 9062546, 9062546, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062546G>A", "-", "c.24900C>T", "c.(24898-24900)ctC>ctT", "p.L8300L"},
                new Object[]{"MUC16", 19, 9012468, 9012468, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9012468C>A", "-", "c.38738G>T", "c.(38737-38739)aGg>aTg", "p.R12913M"},
                new Object[]{"MUC16", 19, 9060576, 9060576, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060576G>A", "-", "c.26870C>T", "c.(26869-26871)cCa>cTa", "p.P8957L"},
                new Object[]{"MUC16", 19, 9027227, 9027227, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9027227G>T", "-", "c.36659C>A", "c.(36658-36660)cCc>cAc", "p.P12220H"},
                new Object[]{"MUC16", 19, 9046631, 9046631, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046631C>T", "-", "c.35000G>A", "c.(34999-35001)gGg>gAg", "p.G11667E"},
                new Object[]{"MUC16", 19, 9046756, 9046756, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9046756G>T", "-", "c.34875C>A", "c.(34873-34875)ccC>ccA", "p.P11625P"},
                new Object[]{"MUC16", 19, 9057805, 9057805, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057805C>T", "-", "c.29641G>A", "c.(29641-29643)Gag>Aag", "p.E9881K"},
                new Object[]{"MUC16", 19, 8979244, 8979244, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8979244C>T", "-", "c.42127G>A", "c.(42127-42129)Gaa>Aaa", "p.E14043K"},
                new Object[]{"MUC16", 19, 8994157, 8994157, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8994157C>T", "-", "c.41528G>A", "c.(41527-41529)aGg>aAg", "p.R13843K"},
                new Object[]{"MUC16", 19, 8999555, 8999555, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999555C>T", "-", "c.40620G>A", "c.(40618-40620)aaG>aaA", "p.K13540K"},
                new Object[]{"MUC16", 19, 9005594, 9005594, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9005594G>A", "-", "c.39812C>T", "c.(39811-39813)cCc>cTc", "p.P13271L"},
                new Object[]{"MUC16", 19, 9009651, 9009651, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9009651C>T", "-", "c.39075G>A", "c.(39073-39075)ggG>ggA", "p.G13025G"},
                new Object[]{"MUC16", 19, 9020092, 9020092, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9020092C>T", "-", "c.37403G>A", "c.(37402-37404)aGc>aAc", "p.S12468N"},
                new Object[]{"MUC16", 19, 9026256, 9026256, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9026256C>T", "-", "c.36730G>A", "c.(36730-36732)Gag>Aag", "p.E12244K"},
                new Object[]{"MUC16", 19, 9045903, 9045903, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9045903C>T", "-", "c.35728G>A", "c.(35728-35730)Gat>Aat", "p.D11910N"},
                new Object[]{"MUC16", 19, 9046592, 9046592, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046592G>A", "-", "c.35039C>T", "c.(35038-35040)cCc>cTc", "p.P11680L"},
                new Object[]{"MUC16", 19, 9047995, 9047995, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047995G>A", "-", "c.33636C>T", "c.(33634-33636)gtC>gtT", "p.V11212V"},
                new Object[]{"MUC16", 19, 9048589, 9048589, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048589C>T", "-", "c.33042G>A", "c.(33040-33042)gaG>gaA", "p.E11014E"},
                new Object[]{"MUC16", 19, 9056230, 9056230, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056230C>T", "-", "c.31216G>A", "c.(31216-31218)Gag>Aag", "p.E10406K"},
                new Object[]{"MUC16", 19, 9056445, 9056445, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056445G>A", "-", "c.31001C>T", "c.(31000-31002)tCt>tTt", "p.S10334F"},
                new Object[]{"MUC16", 19, 9060710, 9060710, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060710C>T", "-", "c.26736G>A", "c.(26734-26736)atG>atA", "p.M8912I"},
                new Object[]{"MUC16", 19, 9063773, 9063773, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063773G>A", "-", "c.23673C>T", "c.(23671-23673)ttC>ttT", "p.F7891F"},
                new Object[]{"MUC16", 19, 9064755, 9064755, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064755G>A", "-", "c.22691C>T", "c.(22690-22692)tCt>tTt", "p.S7564F"},
                new Object[]{"MUC16", 19, 9065029, 9065029, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065029G>A", "-", "c.22417C>T", "c.(22417-22419)Cct>Tct", "p.P7473S"},
                new Object[]{"MUC16", 19, 9065824, 9065824, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065824C>T", "-", "c.21622G>A", "c.(21622-21624)Gcc>Acc", "p.A7208T"},
                new Object[]{"MUC16", 19, 9066073, 9066073, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066073G>A", "-", "c.21373C>T", "c.(21373-21375)Cct>Tct", "p.P7125S"},
                new Object[]{"MUC16", 19, 9068506, 9068506, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068506C>T", "-", "c.18940G>A", "c.(18940-18942)Gaa>Aaa", "p.E6314K"},
                new Object[]{"MUC16", 19, 9069981, 9069981, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069981G>A", "-", "c.17465C>T", "c.(17464-17466)tCc>tTc", "p.S5822F"},
                new Object[]{"MUC16", 19, 9070567, 9070567, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070567C>T", "-", "c.16879G>A", "c.(16879-16881)Gaa>Aaa", "p.E5627K"},
                new Object[]{"MUC16", 19, 9071744, 9071744, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071744G>A", "-", "c.15702C>T", "c.(15700-15702)tcC>tcT", "p.S5234S"},
                new Object[]{"MUC16", 19, 9075298, 9075298, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075298C>T", "-", "c.12148G>A", "c.(12148-12150)Gaa>Aaa", "p.E4050K"},
                new Object[]{"MUC16", 19, 9075336, 9075336, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075336G>A", "-", "c.12110C>T", "c.(12109-12111)tCc>tTc", "p.S4037F"},
                new Object[]{"MUC16", 19, 9077304, 9077304, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077304G>A", "-", "c.10142C>T", "c.(10141-10143)tCa>tTa", "p.S3381L"},
                new Object[]{"MUC16", 19, 9080501, 9080501, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9080501C>T", "-", "c.9530G>A", "c.(9529-9531)gGa>gAa", "p.G3177E"},
                new Object[]{"MUC16", 19, 9082904, 9082904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082904C>T", "-", "c.8911G>A", "c.(8911-8913)Gca>Aca", "p.A2971T"},
                new Object[]{"MUC16", 19, 9085999, 9085999, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085999G>A", "-", "c.5816C>T", "c.(5815-5817)tCa>tTa", "p.S1939L"},
                new Object[]{"MUC16", 19, 9089417, 9089417, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089417C>T", "-", "c.2398G>A", "c.(2398-2400)Gaa>Aaa", "p.E800K"},
                new Object[]{"MUC16", 19, 9089741, 9089741, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089741C>T", "-", "c.2074G>A", "c.(2074-2076)Gaa>Aaa", "p.E692K"},
                new Object[]{"MUC16", 19, 9089878, 9089878, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089878C>T", "-", "c.1937G>A", "c.(1936-1938)gGt>gAt", "p.G646D"},
                new Object[]{"MUC16", 19, 9091236, 9091236, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091236C>T", "-", "c.579G>A", "c.(577-579)atG>atA", "p.M193I"},
                new Object[]{"MUC16", 19, 9091517, 9091517, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9091517T>C", "-", "c.298A>G", "c.(298-300)Aga>Gga", "p.R100G"},
                new Object[]{"MUC16", 19, 8995964, 8995964, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8995964G>A", "-", "c.41277C>T", "c.(41275-41277)tcC>tcT", "p.S13759S"},
                new Object[]{"MUC16", 19, 9006663, 9006663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006663C>A", "-", "c.39585G>T", "c.(39583-39585)acG>acT", "p.T13195T"},
                new Object[]{"MUC16", 19, 9012527, 9012527, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9012527G>T", "-", "c.38679C>A", "c.(38677-38679)ccC>ccA", "p.P12893P"},
                new Object[]{"MUC16", 19, 9020020, 9020020, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9020020G>T", "-", "c.37475C>A", "c.(37474-37476)cCc>cAc", "p.P12492H"},
                new Object[]{"MUC16", 19, 9048748, 9048748, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048748G>A", "-", "c.32883C>T", "c.(32881-32883)acC>acT", "p.T10961T"},
                new Object[]{"MUC16", 19, 9049655, 9049655, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049655G>A", "-", "c.31976C>T", "c.(31975-31977)tCg>tTg", "p.S10659L"},
                new Object[]{"MUC16", 19, 9056574, 9056574, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056574G>A", "-", "c.30872C>T", "c.(30871-30873)aCc>aTc", "p.T10291I"},
                new Object[]{"MUC16", 19, 9064631, 9064631, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064631G>A", "-", "c.22815C>T", "c.(22813-22815)ccC>ccT", "p.P7605P"},
                new Object[]{"MUC16", 19, 9069548, 9069548, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069548C>T", "-", "c.17898G>A", "c.(17896-17898)agG>agA", "p.R5966R"},
                new Object[]{"MUC16", 19, 9070500, 9070500, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070500G>A", "-", "c.16946C>T", "c.(16945-16947)tCa>tTa", "p.S5649L"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 9074217, 9074217, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074217G>A", "-", "c.13229C>T", "c.(13228-13230)cCt>cTt", "p.P4410L"},
                new Object[]{"MUC16", 19, 9075687, 9075687, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075687G>A", "-", "c.11759C>T", "c.(11758-11760)tCa>tTa", "p.S3920L"},
                new Object[]{"MUC16", 19, 9076809, 9076809, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076809C>T", "-", "c.10637G>A", "c.(10636-10638)gGa>gAa", "p.G3546E"},
                new Object[]{"MUC16", 19, 9076840, 9076840, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076840G>A", "-", "c.10606C>T", "c.(10606-10608)Cca>Tca", "p.P3536S"},
                new Object[]{"MUC16", 19, 9080501, 9080501, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9080501C>T", "-", "c.9530G>A", "c.(9529-9531)gGa>gAa", "p.G3177E"},
                new Object[]{"MUC16", 19, 9085046, 9085046, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085046C>T", "-", "c.6769G>A", "c.(6769-6771)Gat>Aat", "p.D2257N"},
                new Object[]{"MUC16", 19, 9089642, 9089642, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089642G>A", "-", "c.2173C>T", "c.(2173-2175)Cct>Tct", "p.P725S"},
                new Object[]{"MUC16", 19, 9074696, 9074696, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074696C>T", "-", "c.12750G>A", "c.(12748-12750)acG>acA", "p.T4250T"},
                new Object[]{"MUC16", 19, 8982296, 8982296, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8982296G>A", "-", "c.41979C>T", "c.(41977-41979)gaC>gaT", "p.D13993D"},
                new Object[]{"MUC16", 19, 8999484, 8999484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999484C>T", "-", "c.40691G>A", "c.(40690-40692)aGa>aAa", "p.R13564K"},
                new Object[]{"MUC16", 19, 9048281, 9048281, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9048281G>T", "-", "c.33350C>A", "c.(33349-33351)aCt>aAt", "p.T11117N"},
                new Object[]{"MUC16", 19, 9049835, 9049835, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049835C>A", "-", "c.31796G>T", "c.(31795-31797)tGg>tTg", "p.W10599L"},
                new Object[]{"MUC16", 19, 9057123, 9057123, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057123C>T", "-", "c.30323G>A", "c.(30322-30324)gGa>gAa", "p.G10108E"},
                new Object[]{"MUC16", 19, 9060263, 9060263, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060263C>T", "-", "c.27183G>A", "c.(27181-27183)gtG>gtA", "p.V9061V"},
                new Object[]{"MUC16", 19, 9062517, 9062517, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062517C>T", "-", "c.24929G>A", "c.(24928-24930)aGg>aAg", "p.R8310K"},
                new Object[]{"MUC16", 19, 9065720, 9065720, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065720G>A", "-", "c.21726C>T", "c.(21724-21726)tcC>tcT", "p.S7242S"},
                new Object[]{"MUC16", 19, 9067238, 9067238, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067238G>A", "-", "c.20208C>T", "c.(20206-20208)atC>atT", "p.I6736I"},
                new Object[]{"MUC16", 19, 9067716, 9067716, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067716G>A", "-", "c.19730C>T", "c.(19729-19731)tCa>tTa", "p.S6577L"},
                new Object[]{"MUC16", 19, 9067725, 9067725, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067725G>T", "-", "c.19721C>A", "c.(19720-19722)cCg>cAg", "p.P6574Q"},
                new Object[]{"MUC16", 19, 9068223, 9068223, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068223C>T", "-", "c.19223G>A", "c.(19222-19224)aGa>aAa", "p.R6408K"},
                new Object[]{"MUC16", 19, 9068484, 9068484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068484G>A", "-", "c.18962C>T", "c.(18961-18963)cCt>cTt", "p.P6321L"},
                new Object[]{"MUC16", 19, 9071952, 9071952, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071952G>T", "-", "c.15494C>A", "c.(15493-15495)cCt>cAt", "p.P5165H"},
                new Object[]{"MUC16", 19, 9073155, 9073155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9073155G>T", "-", "c.14291C>A", "c.(14290-14292)cCg>cAg", "p.P4764Q"},
                new Object[]{"MUC16", 19, 9074140, 9074140, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074140G>A", "-", "c.13306C>T", "c.(13306-13308)Ccc>Tcc", "p.P4436S"},
                new Object[]{"MUC16", 19, 9074822, 9074822, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074822C>T", "-", "c.12624G>A", "c.(12622-12624)agG>agA", "p.R4208R"},
                new Object[]{"MUC16", 19, 9075310, 9075310, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9075310C>A", "-", "c.12136G>T", "c.(12136-12138)Ggg>Tgg", "p.G4046W"},
                new Object[]{"MUC16", 19, 9088834, 9088834, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088834G>A", "-", "c.2981C>T", "c.(2980-2982)gCt>gTt", "p.A994V"},
                new Object[]{"MUC16", 19, 9046787, 9046787, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "G", "g.chr19:9046787C>G", "-", "c.34844G>C", "c.(34843-34845)aGg>aCg", "p.R11615T"},
                new Object[]{"MUC16", 19, 9086883, 9086883, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086883G>A", "-", "c.4932C>T", "c.(4930-4932)acC>acT", "p.T1644T"},
                new Object[]{"MUC16", 19, 9048603, 9048603, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048603G>A", "-", "c.33028C>T", "c.(33028-33030)Cct>Tct", "p.P11010S"},
                new Object[]{"MUC16", 19, 9064305, 9064305, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064305G>A", "-", "c.23141C>T", "c.(23140-23142)cCc>cTc", "p.P7714L"},
                new Object[]{"MUC16", 19, 9069660, 9069660, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069660G>A", "-", "c.17786C>T", "c.(17785-17787)tCc>tTc", "p.S5929F"},
                new Object[]{"MUC16", 19, 9077379, 9077379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077379C>A", "-", "c.10067G>T", "c.(10066-10068)gGg>gTg", "p.G3356V"},
                new Object[]{"MUC16", 19, 9077737, 9077737, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077737G>A", "-", "c.9709C>T", "c.(9709-9711)Ccc>Tcc", "p.P3237S"},
                new Object[]{"MUC16", 19, 9082867, 9082867, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9082867C>A", "-", "c.8948G>T", "c.(8947-8949)gGg>gTg", "p.G2983V"},
                new Object[]{"MUC16", 19, 9083313, 9083313, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083313C>T", "-", "c.8502G>A", "c.(8500-8502)acG>acA", "p.T2834T"},
                new Object[]{"MUC16", 19, 9084257, 9084257, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9084257G>A", "-", "c.7558C>T", "c.(7558-7560)Ctc>Ttc", "p.L2520F"},
                new Object[]{"MUC16", 19, 9087450, 9087450, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087450G>T", "-", "c.4365C>A", "c.(4363-4365)ctC>ctA", "p.L1455L"},
                new Object[]{"MUC16", 19, 9090722, 9090722, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090722G>A", "-", "c.1093C>T", "c.(1093-1095)Ctt>Ttt", "p.L365F"},
                new Object[]{"MUC16", 19, 9090772, 9090772, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090772G>A", "-", "c.1043C>T", "c.(1042-1044)tCc>tTc", "p.S348F"},
                new Object[]{"MUC16", 19, 9077160, 9077160, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077160C>A", "-", "c.10286G>T", "c.(10285-10287)tGg>tTg", "p.W3429L"},
                new Object[]{"MUC16", 19, 9085008, 9085008, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085008C>T", "-", "c.6807G>A", "c.(6805-6807)aaG>aaA", "p.K2269K"},
                new Object[]{"MUC16", 19, 9088249, 9088249, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088249C>A", "-", "c.3566G>T", "c.(3565-3567)cGg>cTg", "p.R1189L"},
                new Object[]{"MUC16", 19, 9090445, 9090445, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090445G>T", "-", "c.1370C>A", "c.(1369-1371)cCc>cAc", "p.P457H"},
                new Object[]{"MUC16", 19, 9061313, 9061313, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061313C>T", "-", "c.26133G>A", "c.(26131-26133)agG>agA", "p.R8711R"},
                new Object[]{"MUC16", 19, 9065080, 9065080, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065080C>T", "-", "c.22366G>A", "c.(22366-22368)Gtt>Att", "p.V7456I"},
                new Object[]{"MUC16", 19, 9069690, 9069690, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069690G>A", "-", "c.17756C>T", "c.(17755-17757)cCc>cTc", "p.P5919L"},
                new Object[]{"MUC16", 19, 9071467, 9071467, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071467G>A", "-", "c.15979C>T", "c.(15979-15981)Ccc>Tcc", "p.P5327S"},
                new Object[]{"MUC16", 19, 9072472, 9072472, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072472C>T", "-", "c.14974G>A", "c.(14974-14976)Gac>Aac", "p.D4992N"},
                new Object[]{"MUC16", 19, 9072844, 9072844, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072844C>T", "-", "c.14602G>A", "c.(14602-14604)Gaa>Aaa", "p.E4868K"},
                new Object[]{"MUC16", 19, 9076384, 9076384, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076384G>A", "-", "c.11062C>T", "c.(11062-11064)Cct>Tct", "p.P3688S"},
                new Object[]{"MUC16", 19, 9086722, 9086722, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086722C>T", "-", "c.5093G>A", "c.(5092-5094)gGa>gAa", "p.G1698E"},
                new Object[]{"MUC16", 19, 9088812, 9088812, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088812G>A", "-", "c.3003C>T", "c.(3001-3003)ttC>ttT", "p.F1001F"},
                new Object[]{"MUC16", 19, 9088841, 9088841, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "C", "g.chr19:9088841G>C", "-", "c.2974C>G", "c.(2974-2976)Ctc>Gtc", "p.L992V"},
                new Object[]{"MUC16", 19, 9054252, 9054252, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9054252G>A", "-", "c.31370C>T", "c.(31369-31371)tCg>tTg", "p.S10457L"},
                new Object[]{"MUC16", 19, 9056299, 9056299, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056299C>T", "-", "c.31147G>A", "c.(31147-31149)Gac>Aac", "p.D10383N"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 8982202, 8982202, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:8982202G>T", "-", "c.42073C>A", "c.(42073-42075)Cgg>Agg", "p.R14025R"},
                new Object[]{"MUC16", 19, 9003572, 9003572, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9003572C>A", "-", "c.40068G>T", "c.(40066-40068)caG>caT", "p.Q13356H"},
                new Object[]{"MUC16", 19, 9008208, 9008208, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9008208G>A", "-", "c.39344C>T", "c.(39343-39345)cCc>cTc", "p.P13115L"},
                new Object[]{"MUC16", 19, 9015627, 9015627, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9015627C>T", "-", "c.38196G>A", "c.(38194-38196)caG>caA", "p.Q12732Q"},
                new Object[]{"MUC16", 19, 9048013, 9048013, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048013C>T", "-", "c.33618G>A", "c.(33616-33618)ggG>ggA", "p.G11206G"},
                new Object[]{"MUC16", 19, 9050215, 9050215, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050215C>A", "-", "c.31416G>T", "c.(31414-31416)atG>atT", "p.M10472I"},
                new Object[]{"MUC16", 19, 9056795, 9056795, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056795G>A", "-", "c.30651C>T", "c.(30649-30651)gcC>gcT", "p.A10217A"},
                new Object[]{"MUC16", 19, 9057678, 9057678, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9057678G>T", "-", "c.29768C>A", "c.(29767-29769)cCt>cAt", "p.P9923H"},
                new Object[]{"MUC16", 19, 9062384, 9062384, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9062384G>T", "-", "c.25062C>A", "c.(25060-25062)acC>acA", "p.T8354T"},
                new Object[]{"MUC16", 19, 9062444, 9062444, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9062444G>T", "-", "c.25002C>A", "c.(25000-25002)acC>acA", "p.T8334T"},
                new Object[]{"MUC16", 19, 9066457, 9066457, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066457G>A", "-", "c.20989C>T", "c.(20989-20991)Cct>Tct", "p.P6997S"},
                new Object[]{"MUC16", 19, 9068232, 9068232, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068232G>A", "-", "c.19214C>T", "c.(19213-19215)tCc>tTc", "p.S6405F"},
                new Object[]{"MUC16", 19, 9069614, 9069614, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069614G>A", "-", "c.17832C>T", "c.(17830-17832)tcC>tcT", "p.S5944S"},
                new Object[]{"MUC16", 19, 9070567, 9070567, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070567C>T", "-", "c.16879G>A", "c.(16879-16881)Gaa>Aaa", "p.E5627K"},
                new Object[]{"MUC16", 19, 9072421, 9072421, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072421C>T", "-", "c.15025G>A", "c.(15025-15027)Gga>Aga", "p.G5009R"},
                new Object[]{"MUC16", 19, 9075994, 9075994, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075994G>A", "-", "c.11452C>T", "c.(11452-11454)Ccc>Tcc", "p.P3818S"},
                new Object[]{"MUC16", 19, 9076487, 9076487, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076487C>T", "-", "c.10959G>A", "c.(10957-10959)aaG>aaA", "p.K3653K"},
                new Object[]{"MUC16", 19, 9083540, 9083540, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9083540G>T", "-", "c.8275C>A", "c.(8275-8277)Ctt>Att", "p.L2759I"},
                new Object[]{"MUC16", 19, 9086175, 9086175, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9086175A>T", "-", "c.5640T>A", "c.(5638-5640)gaT>gaA", "p.D1880E"},
                new Object[]{"MUC16", 19, 9086177, 9086177, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086177C>T", "-", "c.5638G>A", "c.(5638-5640)Gat>Aat", "p.D1880N"},
                new Object[]{"MUC16", 19, 9088106, 9088106, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088106G>A", "-", "c.3709C>T", "c.(3709-3711)Cca>Tca", "p.P1237S"},
                new Object[]{"MUC16", 19, 9089251, 9089251, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089251G>A", "-", "c.2564C>T", "c.(2563-2565)cCt>cTt", "p.P855L"},
                new Object[]{"MUC16", 19, 9090497, 9090497, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090497G>A", "-", "c.1318C>T", "c.(1318-1320)Ctt>Ttt", "p.L440F"},
                new Object[]{"MUC16", 19, 9026203, 9026203, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9026203G>A", "-", "c.36783C>T", "c.(36781-36783)gtC>gtT", "p.V12261V"},
                new Object[]{"MUC16", 19, 9061470, 9061470, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061470G>A", "-", "c.25976C>T", "c.(25975-25977)tCc>tTc", "p.S8659F"},
                new Object[]{"MUC16", 19, 9064411, 9064411, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064411G>A", "-", "c.23035C>T", "c.(23035-23037)Ccc>Tcc", "p.P7679S"},
                new Object[]{"MUC16", 19, 8994513, 8994513, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8994513G>A", "-", "c.41379C>T", "c.(41377-41379)ttC>ttT", "p.F13793F"},
                new Object[]{"MUC16", 19, 9049034, 9049034, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049034G>A", "-", "c.32597C>T", "c.(32596-32598)cCa>cTa", "p.P10866L"},
                new Object[]{"MUC16", 19, 9056568, 9056568, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056568C>T", "-", "c.30878G>A", "c.(30877-30879)gGa>gAa", "p.G10293E"},
                new Object[]{"MUC16", 19, 9057400, 9057400, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057400C>T", "-", "c.30046G>A", "c.(30046-30048)Gaa>Aaa", "p.E10016K"},
                new Object[]{"MUC16", 19, 9064771, 9064771, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064771C>A", "-", "c.22675G>T", "c.(22675-22677)Gca>Tca", "p.A7559S"},
                new Object[]{"MUC16", 19, 9088103, 9088103, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9088103T>C", "-", "c.3712A>G", "c.(3712-3714)Acc>Gcc", "p.T1238A"},
                new Object[]{"MUC16", 19, 9013857, 9013857, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9013857G>A", "-", "c.38533C>T", "c.(38533-38535)Ccc>Tcc", "p.P12845S"},
                new Object[]{"MUC16", 19, 9015342, 9015342, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9015342G>A", "-", "c.38246C>T", "c.(38245-38247)tCt>tTt", "p.S12749F"},
                new Object[]{"MUC16", 19, 9057032, 9057032, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057032G>A", "-", "c.30414C>T", "c.(30412-30414)tcC>tcT", "p.S10138S"},
                new Object[]{"MUC16", 19, 9058672, 9058672, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9058672G>T", "-", "c.28774C>A", "c.(28774-28776)Cag>Aag", "p.Q9592K"},
                new Object[]{"MUC16", 19, 9059493, 9059493, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059493G>A", "-", "c.27953C>T", "c.(27952-27954)aCt>aTt", "p.T9318I"},
                new Object[]{"MUC16", 19, 9063255, 9063255, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063255G>A", "-", "c.24191C>T", "c.(24190-24192)tCc>tTc", "p.S8064F"},
                new Object[]{"MUC16", 19, 9065398, 9065398, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9065398A>T", "-", "c.22048T>A", "c.(22048-22050)Tcc>Acc", "p.S7350T"},
                new Object[]{"MUC16", 19, 9066340, 9066340, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066340G>A", "-", "c.21106C>T", "c.(21106-21108)Cct>Tct", "p.P7036S"},
                new Object[]{"MUC16", 19, 9082600, 9082600, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9082600T>C", "-", "c.9215A>G", "c.(9214-9216)cAg>cGg", "p.Q3072R"},
                new Object[]{"MUC16", 19, 9090133, 9090133, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090133G>A", "-", "c.1682C>T", "c.(1681-1683)tCt>tTt", "p.S561F"},
                new Object[]{"MUC16", 19, 9091052, 9091052, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091052C>T", "-", "c.763G>A", "c.(763-765)Gaa>Aaa", "p.E255K"},
                new Object[]{"MUC16", 19, 9091598, 9091598, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091598C>T", "-", "c.217G>A", "c.(217-219)Gga>Aga", "p.G73R"},
                new Object[]{"MUC16", 19, 9070067, 9070067, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070067G>A", "-", "c.17379C>T", "c.(17377-17379)atC>atT", "p.I5793I"},
                new Object[]{"MUC16", 19, 9085504, 9085504, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085504C>T", "-", "c.6311G>A", "c.(6310-6312)aGa>aAa", "p.R2104K"},
                new Object[]{"MUC16", 19, 9085830, 9085830, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9085830A>T", "-", "c.5985T>A", "c.(5983-5985)gtT>gtA", "p.V1995V"},
                new Object[]{"MUC16", 19, 8982210, 8982210, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8982210C>A", "-", "c.42065G>T", "c.(42064-42066)gGc>gTc", "p.G14022V"},
                new Object[]{"MUC16", 19, 9018509, 9018509, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9018509C>T", "-", "c.37665G>A", "c.(37663-37665)ctG>ctA", "p.L12555L"},
                new Object[]{"MUC16", 19, 9024197, 9024197, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9024197G>A", "-", "c.37075C>T", "c.(37075-37077)Cct>Tct", "p.P12359S"},
                new Object[]{"MUC16", 19, 9046079, 9046079, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046079G>A", "-", "c.35552C>T", "c.(35551-35553)tCc>tTc", "p.S11851F"},
                new Object[]{"MUC16", 19, 9049915, 9049915, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049915G>A", "-", "c.31716C>T", "c.(31714-31716)gtC>gtT", "p.V10572V"},
                new Object[]{"MUC16", 19, 9076735, 9076735, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076735C>T", "-", "c.10711G>A", "c.(10711-10713)Gag>Aag", "p.E3571K"},
                new Object[]{"MUC16", 19, 9080501, 9080501, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9080501C>T", "-", "c.9530G>A", "c.(9529-9531)gGa>gAa", "p.G3177E"},
                new Object[]{"MUC16", 19, 9083864, 9083864, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083864G>A", "-", "c.7951C>T", "c.(7951-7953)Cct>Tct", "p.P2651S"},
                new Object[]{"MUC16", 19, 9090078, 9090078, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090078C>T", "-", "c.1737G>A", "c.(1735-1737)ggG>ggA", "p.G579G"},
                new Object[]{"MUC16", 19, 9045834, 9045834, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9045834C>T", "-", "c.35797G>A", "c.(35797-35799)Gaa>Aaa", "p.E11933K"},
                new Object[]{"MUC16", 19, 9061310, 9061310, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061310C>T", "-", "c.26136G>A", "c.(26134-26136)gaG>gaA", "p.E8712E"},
                new Object[]{"MUC16", 19, 8976784, 8976784, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8976784C>T", "-", "c.42282G>A", "c.(42280-42282)aaG>aaA", "p.K14094K"},
                new Object[]{"MUC16", 19, 9012850, 9012850, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9012850T>C", "-", "c.38594A>G", "c.(38593-38595)aAc>aGc", "p.N12865S"},
                new Object[]{"MUC16", 19, 9018545, 9018545, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9018545C>T", "-", "c.37629G>A", "c.(37627-37629)ctG>ctA", "p.L12543L"},
                new Object[]{"MUC16", 19, 9045750, 9045750, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9045750C>T", "-", "c.35881G>A", "c.(35881-35883)Gga>Aga", "p.G11961R"},
                new Object[]{"MUC16", 19, 9048086, 9048086, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048086G>A", "-", "c.33545C>T", "c.(33544-33546)tCa>tTa", "p.S11182L"},
                new Object[]{"MUC16", 19, 9049005, 9049005, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049005C>T", "-", "c.32626G>A", "c.(32626-32628)Gga>Aga", "p.G10876R"},
                new Object[]{"MUC16", 19, 9049163, 9049163, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049163G>A", "-", "c.32468C>T", "c.(32467-32469)tCa>tTa", "p.S10823L"},
                new Object[]{"MUC16", 19, 9060158, 9060158, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060158C>T", "-", "c.27288G>A", "c.(27286-27288)ttG>ttA", "p.L9096L"},
                new Object[]{"MUC16", 19, 9060189, 9060189, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060189G>A", "-", "c.27257C>T", "c.(27256-27258)cCt>cTt", "p.P9086L"},
                new Object[]{"MUC16", 19, 9060859, 9060859, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9060859T>C", "-", "c.26587A>G", "c.(26587-26589)Acc>Gcc", "p.T8863A"},
                new Object[]{"MUC16", 19, 9061169, 9061169, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061169G>A", "-", "c.26277C>T", "c.(26275-26277)tcC>tcT", "p.S8759S"},
                new Object[]{"MUC16", 19, 9064199, 9064199, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064199G>A", "-", "c.23247C>T", "c.(23245-23247)acC>acT", "p.T7749T"},
                new Object[]{"MUC16", 19, 9065032, 9065032, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065032G>A", "-", "c.22414C>T", "c.(22414-22416)Cat>Tat", "p.H7472Y"},
                new Object[]{"MUC16", 19, 9065737, 9065737, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065737G>A", "-", "c.21709C>T", "c.(21709-21711)Cag>Tag", "p.Q7237*"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 9074058, 9074058, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074058G>A", "-", "c.13388C>T", "c.(13387-13389)aCc>aTc", "p.T4463I"},
                new Object[]{"MUC16", 19, 9074907, 9074907, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074907C>T", "-", "c.12539G>A", "c.(12538-12540)gGg>gAg", "p.G4180E"},
                new Object[]{"MUC16", 19, 9075542, 9075542, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075542G>A", "-", "c.11904C>T", "c.(11902-11904)atC>atT", "p.I3968I"},
                new Object[]{"MUC16", 19, 9076530, 9076530, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076530C>T", "-", "c.10916G>A", "c.(10915-10917)gGa>gAa", "p.G3639E"},
                new Object[]{"MUC16", 19, 9077304, 9077304, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077304G>A", "-", "c.10142C>T", "c.(10141-10143)tCa>tTa", "p.S3381L"},
                new Object[]{"MUC16", 19, 9085544, 9085544, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085544G>A", "-", "c.6271C>T", "c.(6271-6273)Cca>Tca", "p.P2091S"},
                new Object[]{"MUC16", 19, 9089940, 9089940, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089940G>A", "-", "c.1875C>T", "c.(1873-1875)caC>caT", "p.H625H"},
                new Object[]{"MUC16", 19, 9056625, 9056625, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056625G>A", "-", "c.30821C>T", "c.(30820-30822)tCc>tTc", "p.S10274F"},
                new Object[]{"MUC16", 19, 8974052, 8974052, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8974052G>A", "-", "c.42619C>T", "c.(42619-42621)Cac>Tac", "p.H14207Y"},
                // Had to change GT for the protein change, since this is an intron splice site.
                new Object[]{"MUC16", 19, 9000146, 9000146, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9000146C>T", "-", "c.e55-1G>A", "c.e55+1", null},
                new Object[]{"MUC16", 19, 9049484, 9049484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049484G>A", "-", "c.32147C>T", "c.(32146-32148)cCt>cTt", "p.P10716L"},
                new Object[]{"MUC16", 19, 9058095, 9058095, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058095G>A", "-", "c.29351C>T", "c.(29350-29352)cCa>cTa", "p.P9784L"},
                new Object[]{"MUC16", 19, 9060904, 9060904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060904C>T", "-", "c.26542G>A", "c.(26542-26544)Gaa>Aaa", "p.E8848K"},
                new Object[]{"MUC16", 19, 9063559, 9063559, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063559G>A", "-", "c.23887C>T", "c.(23887-23889)Ccc>Tcc", "p.P7963S"},
                new Object[]{"MUC16", 19, 9067908, 9067908, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067908G>A", "-", "c.19538C>T", "c.(19537-19539)tCc>tTc", "p.S6513F"},
                new Object[]{"MUC16", 19, 9077809, 9077809, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077809C>T", "-", "c.9637G>A", "c.(9637-9639)Gaa>Aaa", "p.E3213K"},
                new Object[]{"MUC16", 19, 9083035, 9083035, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083035G>A", "-", "c.8780C>T", "c.(8779-8781)tCc>tTc", "p.S2927F"},
                new Object[]{"MUC16", 19, 8973575, 8973575, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8973575G>A", "-", "c.42741C>T", "c.(42739-42741)ttC>ttT", "p.F14247F"},
                new Object[]{"MUC16", 19, 8996489, 8996489, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8996489C>T", "-", "c.41083G>A", "c.(41083-41085)Gaa>Aaa", "p.E13695K"},
                new Object[]{"MUC16", 19, 9003586, 9003586, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9003586C>T", "-", "c.40054G>A", "c.(40054-40056)Gag>Aag", "p.E13352K"},
                new Object[]{"MUC16", 19, 9046503, 9046503, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9046503G>T", "-", "c.35128C>A", "c.(35128-35130)Cat>Aat", "p.H11710N"},
                new Object[]{"MUC16", 19, 9049121, 9049121, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049121C>T", "-", "c.32510G>A", "c.(32509-32511)tGg>tAg", "p.W10837*"},
                new Object[]{"MUC16", 19, 9054339, 9054339, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9054339C>T", "-", "c.31283G>A", "c.(31282-31284)gGc>gAc", "p.G10428D"},
                new Object[]{"MUC16", 19, 9057040, 9057040, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057040G>A", "-", "c.30406C>T", "c.(30406-30408)Ccc>Tcc", "p.P10136S"},
                new Object[]{"MUC16", 19, 9058908, 9058908, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:9058908T>G", "-", "c.28538A>C", "c.(28537-28539)cAc>cCc", "p.H9513P"},
                new Object[]{"MUC16", 19, 9060306, 9060306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060306C>T", "-", "c.27140G>A", "c.(27139-27141)aGc>aAc", "p.S9047N"},
                new Object[]{"MUC16", 19, 9062673, 9062673, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062673G>A", "-", "c.24773C>T", "c.(24772-24774)tCc>tTc", "p.S8258F"},
                new Object[]{"MUC16", 19, 9064721, 9064721, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064721G>A", "-", "c.22725C>T", "c.(22723-22725)tcC>tcT", "p.S7575S"},
                new Object[]{"MUC16", 19, 9065788, 9065788, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065788C>T", "-", "c.21658G>A", "c.(21658-21660)Gat>Aat", "p.D7220N"},
                new Object[]{"MUC16", 19, 9068117, 9068117, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068117C>T", "-", "c.19329G>A", "c.(19327-19329)agG>agA", "p.R6443R"},
                new Object[]{"MUC16", 19, 9070704, 9070704, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070704G>A", "-", "c.16742C>T", "c.(16741-16743)cCc>cTc", "p.P5581L"},
                new Object[]{"MUC16", 19, 9072185, 9072185, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072185C>A", "-", "c.15261G>T", "c.(15259-15261)ttG>ttT", "p.L5087F"},
                new Object[]{"MUC16", 19, 9074177, 9074177, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9074177A>T", "-", "c.13269T>A", "c.(13267-13269)ttT>ttA", "p.F4423L"},
                new Object[]{"MUC16", 19, 9074179, 9074179, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9074179A>T", "-", "c.13267T>A", "c.(13267-13269)Ttt>Att", "p.F4423I"},
                new Object[]{"MUC16", 19, 9076497, 9076497, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076497G>A", "-", "c.10949C>T", "c.(10948-10950)tCa>tTa", "p.S3650L"},
                new Object[]{"MUC16", 19, 9082363, 9082363, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082363G>A", "-", "c.9452C>T", "c.(9451-9453)cCt>cTt", "p.P3151L"},
                new Object[]{"MUC16", 19, 9010664, 9010664, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9010664G>A", "-", "c.38997C>T", "c.(38995-38997)tcC>tcT", "p.S12999S"},
                new Object[]{"MUC16", 19, 9057220, 9057220, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057220G>A", "-", "c.30226C>T", "c.(30226-30228)Ctg>Ttg", "p.L10076L"},
                new Object[]{"MUC16", 19, 9058301, 9058301, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058301C>T", "-", "c.29145G>A", "c.(29143-29145)tgG>tgA", "p.W9715*"},
                new Object[]{"MUC16", 19, 9065535, 9065535, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065535G>A", "-", "c.21911C>T", "c.(21910-21912)tCc>tTc", "p.S7304F"},
                new Object[]{"MUC16", 19, 9066247, 9066247, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066247G>A", "-", "c.21199C>T", "c.(21199-21201)Cca>Tca", "p.P7067S"},
                new Object[]{"MUC16", 19, 9068965, 9068965, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068965G>A", "-", "c.18481C>T", "c.(18481-18483)Cct>Tct", "p.P6161S"},
                new Object[]{"MUC16", 19, 9077142, 9077142, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077142C>T", "-", "c.10304G>A", "c.(10303-10305)gGg>gAg", "p.G3435E"},
                new Object[]{"MUC16", 19, 9082369, 9082369, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082369G>A", "-", "c.9446C>T", "c.(9445-9447)tCa>tTa", "p.S3149L"},
                new Object[]{"MUC16", 19, 9084542, 9084542, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084542C>T", "-", "c.7273G>A", "c.(7273-7275)Gcc>Acc", "p.A2425T"},
                new Object[]{"MUC16", 19, 9050106, 9050106, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050106G>T", "-", "c.31525C>A", "c.(31525-31527)Ctc>Atc", "p.L10509I"},
                new Object[]{"MUC16", 19, 9060012, 9060012, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060012G>A", "-", "c.27434C>T", "c.(27433-27435)tCt>tTt", "p.S9145F"},
                new Object[]{"MUC16", 19, 9072891, 9072891, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072891G>T", "-", "c.14555C>A", "c.(14554-14556)cCa>cAa", "p.P4852Q"},
                new Object[]{"MUC16", 19, 9087950, 9087950, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087950G>T", "-", "c.3865C>A", "c.(3865-3867)Cac>Aac", "p.H1289N"},
                new Object[]{"MUC16", 19, 9058555, 9058555, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058555G>A", "-", "c.28891C>T", "c.(28891-28893)Cct>Tct", "p.P9631S"},
                new Object[]{"MUC16", 19, 9064386, 9064386, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064386G>A", "-", "c.23060C>T", "c.(23059-23061)cCa>cTa", "p.P7687L"},
                new Object[]{"MUC16", 19, 9065716, 9065716, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9065716G>T", "-", "c.21730C>A", "c.(21730-21732)Ctg>Atg", "p.L7244M"},
                new Object[]{"MUC16", 19, 9018453, 9018453, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9018453C>T", "-", "c.37721G>A", "c.(37720-37722)aGg>aAg", "p.R12574K"},
                new Object[]{"MUC16", 19, 9026227, 9026227, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9026227C>T", "-", "c.36759G>A", "c.(36757-36759)agG>agA", "p.R12253R"},
                new Object[]{"MUC16", 19, 9068069, 9068069, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068069G>A", "-", "c.19377C>T", "c.(19375-19377)acC>acT", "p.T6459T"},
                new Object[]{"MUC16", 19, 9087697, 9087697, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087697G>A", "-", "c.4118C>T", "c.(4117-4119)tCa>tTa", "p.S1373L"},
                new Object[]{"MUC16", 19, 9090172, 9090172, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090172G>A", "-", "c.1643C>T", "c.(1642-1644)cCc>cTc", "p.P548L"},
                new Object[]{"MUC16", 19, 9049259, 9049259, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049259C>A", "-", "c.32372G>T", "c.(32371-32373)cGg>cTg", "p.R10791L"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9086891, 9086891, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9086891C>A", "-", "c.4924G>T", "c.(4924-4926)Gga>Tga", "p.G1642*"},
                new Object[]{"MUC16", 19, 9088957, 9088957, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088957C>A", "-", "c.2858G>T", "c.(2857-2859)aGa>aTa", "p.R953I"},
                new Object[]{"MUC16", 19, 9045691, 9045691, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9045691G>T", "-", "c.35940C>A", "c.(35938-35940)acC>acA", "p.T11980T"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9059581, 9059581, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059581C>A", "-", "c.27865G>T", "c.(27865-27867)Ggg>Tgg", "p.G9289W"},
                new Object[]{"MUC16", 19, 9061187, 9061187, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9061187G>T", "-", "c.26259C>A", "c.(26257-26259)acC>acA", "p.T8753T"},
                new Object[]{"MUC16", 19, 9067092, 9067092, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067092G>T", "-", "c.20354C>A", "c.(20353-20355)cCt>cAt", "p.P6785H"},
                new Object[]{"MUC16", 19, 9088667, 9088667, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088667C>A", "-", "c.3148G>T", "c.(3148-3150)Gga>Tga", "p.G1050*"},
                new Object[]{"MUC16", 19, 9090379, 9090379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090379G>T", "-", "c.1436C>A", "c.(1435-1437)cCa>cAa", "p.P479Q"},
                new Object[]{"MUC16", 19, 9063486, 9063486, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063486G>A", "-", "c.23960C>T", "c.(23959-23961)tCc>tTc", "p.S7987F"},
                new Object[]{"MUC16", 19, 9064399, 9064399, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064399C>T", "-", "c.23047G>A", "c.(23047-23049)Gaa>Aaa", "p.E7683K"},
                new Object[]{"MUC16", 19, 9072101, 9072101, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072101C>A", "-", "c.15345G>T", "c.(15343-15345)aaG>aaT", "p.K5115N"},
                new Object[]{"MUC16", 19, 9077425, 9077425, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077425C>A", "-", "c.10021G>T", "c.(10021-10023)Gga>Tga", "p.G3341*"},
                new Object[]{"MUC16", 19, 9067149, 9067149, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067149G>A", "-", "c.20297C>T", "c.(20296-20298)tCg>tTg", "p.S6766L"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 9084604, 9084604, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9084604G>T", "-", "c.7211C>A", "c.(7210-7212)tCc>tAc", "p.S2404Y"},
                new Object[]{"MUC16", 19, 9085435, 9085435, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9085435G>T", "-", "c.6380C>A", "c.(6379-6381)tCg>tAg", "p.S2127*"},
                new Object[]{"MUC16", 19, 9088960, 9088960, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9088960T>C", "-", "c.2855A>G", "c.(2854-2856)aAt>aGt", "p.N952S"},
                new Object[]{"MUC16", 19, 9048458, 9048458, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048458G>A", "-", "c.33173C>T", "c.(33172-33174)cCa>cTa", "p.P11058L"},
                new Object[]{"MUC16", 19, 9062685, 9062685, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062685C>T", "-", "c.24761G>A", "c.(24760-24762)tGg>tAg", "p.W8254*"},
                new Object[]{"MUC16", 19, 9066568, 9066568, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9066568G>T", "-", "c.20878C>A", "c.(20878-20880)Caa>Aaa", "p.Q6960K"},
                new Object[]{"MUC16", 19, 9066772, 9066772, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9066772C>T", "-", "c.20674G>A", "c.(20674-20676)Gaa>Aaa", "p.E6892K"},
                new Object[]{"MUC16", 19, 9063374, 9063374, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9063374G>T", "-", "c.24072C>A", "c.(24070-24072)acC>acA", "p.T8024T"},
                new Object[]{"MUC16", 19, 9074625, 9074625, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074625G>A", "-", "c.12821C>T", "c.(12820-12822)cCa>cTa", "p.P4274L"},
                new Object[]{"MUC16", 19, 9070154, 9070154, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9070154A>C", "-", "c.17292T>G", "c.(17290-17292)acT>acG", "p.T5764T"},
                new Object[]{"MUC16", 19, 9083554, 9083554, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083554C>T", "-", "c.8261G>A", "c.(8260-8262)gGa>gAa", "p.G2754E"},
                new Object[]{"MUC16", 19, 9085264, 9085264, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085264G>A", "-", "c.6551C>T", "c.(6550-6552)tCc>tTc", "p.S2184F"},
                new Object[]{"MUC16", 19, 9089115, 9089115, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089115G>A", "-", "c.2700C>T", "c.(2698-2700)acC>acT", "p.T900T"},
                new Object[]{"MUC16", 19, 9063190, 9063190, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063190G>A", "-", "c.24256C>T", "c.(24256-24258)Cca>Tca", "p.P8086S"},
                new Object[]{"MUC16", 19, 9077652, 9077652, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077652C>T", "-", "c.9794G>A", "c.(9793-9795)gGa>gAa", "p.G3265E"},
                new Object[]{"MUC16", 19, 9086450, 9086450, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086450C>T", "-", "c.5365G>A", "c.(5365-5367)Gag>Aag", "p.E1789K"},
                new Object[]{"MUC16", 19, 9000512, 9000512, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9000512C>A", "-", "c.40472G>T", "c.(40471-40473)cGg>cTg", "p.R13491L"},
                new Object[]{"MUC16", 19, 9049612, 9049612, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049612G>A", "-", "c.32019C>T", "c.(32017-32019)tcC>tcT", "p.S10673S"},
                new Object[]{"MUC16", 19, 9059581, 9059581, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059581C>A", "-", "c.27865G>T", "c.(27865-27867)Ggg>Tgg", "p.G9289W"},
                new Object[]{"MUC16", 19, 9061495, 9061495, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9061495C>A", "-", "c.25951G>T", "c.(25951-25953)Ggg>Tgg", "p.G8651W"},
                new Object[]{"MUC16", 19, 9061972, 9061972, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061972C>T", "-", "c.25474G>A", "c.(25474-25476)Gaa>Aaa", "p.E8492K"},
                new Object[]{"MUC16", 19, 9062585, 9062585, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062585C>T", "-", "c.24861G>A", "c.(24859-24861)gaG>gaA", "p.E8287E"},
                new Object[]{"MUC16", 19, 9082989, 9082989, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9082989C>A", "-", "c.8826G>T", "c.(8824-8826)atG>atT", "p.M2942I"},
                new Object[]{"MUC16", 19, 9088886, 9088886, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088886C>A", "-", "c.2929G>T", "c.(2929-2931)Ggg>Tgg", "p.G977W"},
                new Object[]{"MUC16", 19, 9088980, 9088980, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088980C>A", "-", "c.2835G>T", "c.(2833-2835)acG>acT", "p.T945T"},
                new Object[]{"MUC16", 19, 9085550, 9085550, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085550C>T", "-", "c.6265G>A", "c.(6265-6267)Gaa>Aaa", "p.E2089K"},
                new Object[]{"MUC16", 19, 8976756, 8976756, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8976756C>T", "-", "c.42310G>A", "c.(42310-42312)Ggg>Agg", "p.G14104R"},
                new Object[]{"MUC16", 19, 9012505, 9012505, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9012505C>A", "-", "c.38701G>T", "c.(38701-38703)Ggc>Tgc", "p.G12901C"},
                new Object[]{"MUC16", 19, 9017373, 9017373, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9017373G>T", "-", "c.37951C>A", "c.(37951-37953)Ctg>Atg", "p.L12651M"},
                new Object[]{"MUC16", 19, 9056375, 9056375, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9056375G>T", "-", "c.31071C>A", "c.(31069-31071)acC>acA", "p.T10357T"},
                new Object[]{"MUC16", 19, 9062025, 9062025, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9062025G>T", "-", "c.25421C>A", "c.(25420-25422)tCt>tAt", "p.S8474Y"},
                new Object[]{"MUC16", 19, 9063558, 9063558, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9063558G>T", "-", "c.23888C>A", "c.(23887-23889)cCc>cAc", "p.P7963H"},
                new Object[]{"MUC16", 19, 9071920, 9071920, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071920C>A", "-", "c.15526G>T", "c.(15526-15528)Gag>Tag", "p.E5176*"},
                new Object[]{"MUC16", 19, 9072185, 9072185, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072185C>A", "-", "c.15261G>T", "c.(15259-15261)ttG>ttT", "p.L5087F"},
                new Object[]{"MUC16", 19, 9072790, 9072790, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072790C>A", "-", "c.14656G>T", "c.(14656-14658)Gag>Tag", "p.E4886*"},
                new Object[]{"MUC16", 19, 9076225, 9076225, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9076225C>A", "-", "c.11221G>T", "c.(11221-11223)Ggg>Tgg", "p.G3741W"},
                new Object[]{"MUC16", 19, 9076829, 9076829, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076829G>A", "-", "c.10617C>T", "c.(10615-10617)tcC>tcT", "p.S3539S"},
                new Object[]{"MUC16", 19, 9086779, 9086779, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9086779C>A", "-", "c.5036G>T", "c.(5035-5037)gGg>gTg", "p.G1679V"},
                new Object[]{"MUC16", 19, 9087719, 9087719, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087719C>A", "-", "c.4096G>T", "c.(4096-4098)Gga>Tga", "p.G1366*"},
                new Object[]{"MUC16", 19, 9089342, 9089342, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9089342C>A", "-", "c.2473G>T", "c.(2473-2475)Ggg>Tgg", "p.G825W"},
                new Object[]{"MUC16", 19, 9091124, 9091124, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9091124C>A", "-", "c.691G>T", "c.(691-693)Ggg>Tgg", "p.G231W"},
                new Object[]{"MUC16", 19, 9076839, 9076839, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076839G>A", "-", "c.10607C>T", "c.(10606-10608)cCa>cTa", "p.P3536L"},
                new Object[]{"MUC16", 19, 9020013, 9020013, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9020013G>T", "-", "c.37482C>A", "c.(37480-37482)acC>acA", "p.T12494T"},
                new Object[]{"MUC16", 19, 9072940, 9072940, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072940C>A", "-", "c.14506G>T", "c.(14506-14508)Ggg>Tgg", "p.G4836W"},
                new Object[]{"MUC16", 19, 9082454, 9082454, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9082454G>T", "-", "c.9361C>A", "c.(9361-9363)Cca>Aca", "p.P3121T"},
                new Object[]{"MUC16", 19, 9050107, 9050107, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050107G>T", "-", "c.31524C>A", "c.(31522-31524)ccC>ccA", "p.P10508P"},
                new Object[]{"MUC16", 19, 9082453, 9082453, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9082453G>T", "-", "c.9362C>A", "c.(9361-9363)cCa>cAa", "p.P3121Q"},
                new Object[]{"MUC16", 19, 9059164, 9059164, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059164C>T", "-", "c.28282G>A", "c.(28282-28284)Gaa>Aaa", "p.E9428K"},
                new Object[]{"MUC16", 19, 9066044, 9066044, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066044C>A", "-", "c.21402G>T", "c.(21400-21402)ccG>ccT", "p.P7134P"},
                new Object[]{"MUC16", 19, 9067557, 9067557, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067557C>A", "-", "c.19889G>T", "c.(19888-19890)aGg>aTg", "p.R6630M"},
                new Object[]{"MUC16", 19, 9073819, 9073819, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9073819C>A", "-", "c.13627G>T", "c.(13627-13629)Ggg>Tgg", "p.G4543W"},
                new Object[]{"MUC16", 19, 9085554, 9085554, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9085554C>A", "-", "c.6261G>T", "c.(6259-6261)acG>acT", "p.T2087T"},
                new Object[]{"MUC16", 19, 9060196, 9060196, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060196C>T", "-", "c.27250G>A", "c.(27250-27252)Ggt>Agt", "p.G9084S"},
                new Object[]{"MUC16", 19, 9072100, 9072100, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072100C>T", "-", "c.15346G>A", "c.(15346-15348)Gaa>Aaa", "p.E5116K"},
                new Object[]{"MUC16", 19, 9089213, 9089213, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089213C>T", "-", "c.2602G>A", "c.(2602-2604)Gaa>Aaa", "p.E868K"},
                new Object[]{"MUC16", 19, 9028320, 9028320, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9028320C>T", "-", "c.36472G>A", "c.(36472-36474)Gac>Aac", "p.D12158N"},
                new Object[]{"MUC16", 19, 9067049, 9067049, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067049G>T", "-", "c.20397C>A", "c.(20395-20397)acC>acA", "p.T6799T"},
                new Object[]{"MUC16", 19, 9069926, 9069926, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069926G>A", "-", "c.17520C>T", "c.(17518-17520)tcC>tcT", "p.S5840S"},
                new Object[]{"MUC16", 19, 9045922, 9045922, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045922G>A", "-", "c.35709C>T", "c.(35707-35709)tcC>tcT", "p.S11903S"},
                new Object[]{"MUC16", 19, 9054252, 9054252, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9054252G>A", "-", "c.31370C>T", "c.(31369-31371)tCg>tTg", "p.S10457L"},
                new Object[]{"MUC16", 19, 9057895, 9057895, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057895C>T", "-", "c.29551G>A", "c.(29551-29553)Gat>Aat", "p.D9851N"},
                new Object[]{"MUC16", 19, 9058191, 9058191, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058191G>A", "-", "c.29255C>T", "c.(29254-29256)tCc>tTc", "p.S9752F"},
                new Object[]{"MUC16", 19, 9063438, 9063438, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063438G>A", "-", "c.24008C>T", "c.(24007-24009)tCa>tTa", "p.S8003L"},
                new Object[]{"MUC16", 19, 9065406, 9065406, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065406G>A", "-", "c.22040C>T", "c.(22039-22041)aCc>aTc", "p.T7347I"},
                new Object[]{"MUC16", 19, 9090379, 9090379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090379G>T", "-", "c.1436C>A", "c.(1435-1437)cCa>cAa", "p.P479Q"},
                new Object[]{"MUC16", 19, 9010979, 9010979, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9010979G>A", "-", "c.38939C>T", "c.(38938-38940)cCc>cTc", "p.P12980L"},
                new Object[]{"MUC16", 19, 9014191, 9014191, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014191C>T", "-", "c.38457G>A", "c.(38455-38457)caG>caA", "p.Q12819Q"},
                new Object[]{"MUC16", 19, 9058180, 9058180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058180G>A", "-", "c.29266C>T", "c.(29266-29268)Cct>Tct", "p.P9756S"},
                new Object[]{"MUC16", 19, 9059574, 9059574, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9059574A>C", "-", "c.27872T>G", "c.(27871-27873)aTg>aGg", "p.M9291R"},
                new Object[]{"MUC16", 19, 9060272, 9060272, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060272G>A", "-", "c.27174C>T", "c.(27172-27174)tcC>tcT", "p.S9058S"},
                new Object[]{"MUC16", 19, 9064480, 9064480, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064480C>T", "-", "c.22966G>A", "c.(22966-22968)Gga>Aga", "p.G7656R"},
                new Object[]{"MUC16", 19, 9072321, 9072321, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072321G>A", "-", "c.15125C>T", "c.(15124-15126)tCc>tTc", "p.S5042F"},
                new Object[]{"MUC16", 19, 9083313, 9083313, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083313C>T", "-", "c.8502G>A", "c.(8500-8502)acG>acA", "p.T2834T"},
                new Object[]{"MUC16", 19, 8966751, 8966751, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8966751C>T", "-", "c.43202G>A", "c.(43201-43203)aGa>aAa", "p.R14401K"},
                new Object[]{"MUC16", 19, 9065265, 9065265, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065265G>A", "-", "c.22181C>T", "c.(22180-22182)tCc>tTc", "p.S7394F"},
                new Object[]{"MUC16", 19, 9066116, 9066116, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066116G>A", "-", "c.21330C>T", "c.(21328-21330)ccC>ccT", "p.P7110P"},
                new Object[]{"MUC16", 19, 9071280, 9071280, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071280G>A", "-", "c.16166C>T", "c.(16165-16167)aCc>aTc", "p.T5389I"},
                new Object[]{"MUC16", 19, 9074222, 9074222, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074222G>A", "-", "c.13224C>T", "c.(13222-13224)acC>acT", "p.T4408T"},
                new Object[]{"MUC16", 19, 9062037, 9062037, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062037G>A", "-", "c.25409C>T", "c.(25408-25410)tCa>tTa", "p.S8470L"},
                new Object[]{"MUC16", 19, 9062445, 9062445, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062445G>A", "-", "c.25001C>T", "c.(25000-25002)aCc>aTc", "p.T8334I"},
                new Object[]{"MUC16", 19, 9068203, 9068203, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068203C>T", "-", "c.19243G>A", "c.(19243-19245)Gaa>Aaa", "p.E6415K"},
                new Object[]{"MUC16", 19, 9075684, 9075684, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075684G>A", "-", "c.11762C>T", "c.(11761-11763)tCc>tTc", "p.S3921F"},
                new Object[]{"MUC16", 19, 9088237, 9088237, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088237G>A", "-", "c.3578C>T", "c.(3577-3579)cCc>cTc", "p.P1193L"},
                new Object[]{"MUC16", 19, 9046600, 9046600, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046600C>T", "-", "c.35031G>A", "c.(35029-35031)cgG>cgA", "p.R11677R"},
                new Object[]{"MUC16", 19, 9011382, 9011382, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9011382T>A", "-", "c.38851A>T", "c.(38851-38853)Acc>Tcc", "p.T12951S"},
                new Object[]{"MUC16", 19, 9056805, 9056805, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056805C>T", "-", "c.30641G>A", "c.(30640-30642)tGg>tAg", "p.W10214*"},
                new Object[]{"MUC16", 19, 9057632, 9057632, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057632C>T", "-", "c.29814G>A", "c.(29812-29814)gtG>gtA", "p.V9938V"},
                new Object[]{"MUC16", 19, 9066570, 9066570, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066570G>A", "-", "c.20876C>T", "c.(20875-20877)tCc>tTc", "p.S6959F"},
                new Object[]{"MUC16", 19, 8993398, 8993398, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8993398C>T", "-", "c.41691G>A", "c.(41689-41691)ctG>ctA", "p.L13897L"},
                new Object[]{"MUC16", 19, 9083555, 9083555, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9083555C>A", "-", "c.8260G>T", "c.(8260-8262)Gga>Tga", "p.G2754*"},
                new Object[]{"MUC16", 19, 8969339, 8969339, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8969339G>A", "-", "c.43005C>T", "c.(43003-43005)tcC>tcT", "p.S14335S"},
                new Object[]{"MUC16", 19, 9019291, 9019291, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9019291G>A", "-", "c.37596C>T", "c.(37594-37596)tcC>tcT", "p.S12532S"},
                new Object[]{"MUC16", 19, 9048053, 9048053, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048053G>A", "-", "c.33578C>T", "c.(33577-33579)tCa>tTa", "p.S11193L"},
                new Object[]{"MUC16", 19, 9070674, 9070674, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070674C>T", "-", "c.16772G>A", "c.(16771-16773)gGa>gAa", "p.G5591E"},
                new Object[]{"MUC16", 19, 8994484, 8994484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8994484C>A", "-", "c.41408G>T", "c.(41407-41409)cGg>cTg", "p.R13803L"},
                new Object[]{"MUC16", 19, 9050122, 9050122, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050122C>A", "-", "c.31509G>T", "c.(31507-31509)ttG>ttT", "p.L10503F"},
                new Object[]{"MUC16", 19, 9063573, 9063573, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063573G>A", "-", "c.23873C>T", "c.(23872-23874)tCa>tTa", "p.S7958L"},
                new Object[]{"MUC16", 19, 9068063, 9068063, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9068063G>T", "-", "c.19383C>A", "c.(19381-19383)acC>acA", "p.T6461T"},
                new Object[]{"MUC16", 19, 9071306, 9071306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071306C>A", "-", "c.16140G>T", "c.(16138-16140)ttG>ttT", "p.L5380F"},
                new Object[]{"MUC16", 19, 9072407, 9072407, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9072407C>A", "-", "c.15039G>T", "c.(15037-15039)ttG>ttT", "p.L5013F"},
                new Object[]{"MUC16", 19, 9086595, 9086595, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9086595A>G", "-", "c.5220T>C", "c.(5218-5220)gcT>gcC", "p.A1740A"},
                new Object[]{"MUC16", 19, 9087369, 9087369, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087369G>T", "-", "c.4446C>A", "c.(4444-4446)ccC>ccA", "p.P1482P"},
                new Object[]{"MUC16", 19, 9065405, 9065405, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065405G>A", "-", "c.22041C>T", "c.(22039-22041)acC>acT", "p.T7347T"},
                new Object[]{"MUC16", 19, 9066554, 9066554, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9066554A>T", "-", "c.20892T>A", "c.(20890-20892)ttT>ttA", "p.F6964L"},
                new Object[]{"MUC16", 19, 9074082, 9074082, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074082G>A", "-", "c.13364C>T", "c.(13363-13365)tCc>tTc", "p.S4455F"},
                new Object[]{"MUC16", 19, 9047481, 9047481, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9047481C>A", "-", "c.34150G>T", "c.(34150-34152)Ggg>Tgg", "p.G11384W"},
                new Object[]{"MUC16", 19, 9058065, 9058065, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9058065G>T", "-", "c.29381C>A", "c.(29380-29382)cCg>cAg", "p.P9794Q"},
                new Object[]{"MUC16", 19, 9058976, 9058976, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9058976G>T", "-", "c.28470C>A", "c.(28468-28470)ccC>ccA", "p.P9490P"},
                new Object[]{"MUC16", 19, 9067725, 9067725, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067725G>T", "-", "c.19721C>A", "c.(19720-19722)cCg>cAg", "p.P6574Q"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9072517, 9072517, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072517G>T", "-", "c.14929C>A", "c.(14929-14931)Caa>Aaa", "p.Q4977K"},
                new Object[]{"MUC16", 19, 9077247, 9077247, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077247G>T", "-", "c.10199C>A", "c.(10198-10200)cCc>cAc", "p.P3400H"},
                new Object[]{"MUC16", 19, 9085484, 9085484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9085484G>T", "-", "c.6331C>A", "c.(6331-6333)Cat>Aat", "p.H2111N"},
                new Object[]{"MUC16", 19, 9086908, 9086908, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9086908G>T", "-", "c.4907C>A", "c.(4906-4908)aCa>aAa", "p.T1636K"},
                new Object[]{"MUC16", 19, 9087062, 9087062, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087062G>T", "-", "c.4753C>A", "c.(4753-4755)Cat>Aat", "p.H1585N"},
                new Object[]{"MUC16", 19, 9090445, 9090445, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090445G>T", "-", "c.1370C>A", "c.(1369-1371)cCc>cAc", "p.P457H"},
                new Object[]{"MUC16", 19, 9091196, 9091196, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091196G>T", "-", "c.619C>A", "c.(619-621)Cca>Aca", "p.P207T"},
                new Object[]{"MUC16", 19, 9082412, 9082412, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082412C>T", "-", "c.9403G>A", "c.(9403-9405)Gcc>Acc", "p.A3135T"},
                new Object[]{"MUC16", 19, 9088132, 9088132, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088132G>A", "-", "c.3683C>T", "c.(3682-3684)tCa>tTa", "p.S1228L"},
                new Object[]{"MUC16", 19, 9090539, 9090539, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090539C>T", "-", "c.1276G>A", "c.(1276-1278)Gga>Aga", "p.G426R"},
                new Object[]{"MUC16", 19, 9046525, 9046525, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9046525G>T", "-", "c.35106C>A", "c.(35104-35106)tcC>tcA", "p.S11702S"},
                new Object[]{"MUC16", 19, 9048722, 9048722, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048722C>T", "-", "c.32909G>A", "c.(32908-32910)gGg>gAg", "p.G10970E"},
                new Object[]{"MUC16", 19, 9049710, 9049710, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049710G>A", "-", "c.31921C>T", "c.(31921-31923)Cca>Tca", "p.P10641S"},
                new Object[]{"MUC16", 19, 9049823, 9049823, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049823G>A", "-", "c.31808C>T", "c.(31807-31809)cCt>cTt", "p.P10603L"},
                new Object[]{"MUC16", 19, 9064313, 9064313, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064313G>A", "-", "c.23133C>T", "c.(23131-23133)ccC>ccT", "p.P7711P"},
                new Object[]{"MUC16", 19, 9067834, 9067834, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067834G>A", "-", "c.19612C>T", "c.(19612-19614)Cct>Tct", "p.P6538S"},
                new Object[]{"MUC16", 19, 9071324, 9071324, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9071324C>T", "-", "c.16122G>A", "c.(16120-16122)gtG>gtA", "p.V5374V"},
                new Object[]{"MUC16", 19, 9072352, 9072352, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072352G>A", "-", "c.15094C>T", "c.(15094-15096)Ccc>Tcc", "p.P5032S"},
                new Object[]{"MUC16", 19, 9073021, 9073021, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9073021C>T", "-", "c.14425G>A", "c.(14425-14427)Gat>Aat", "p.D4809N"},
                new Object[]{"MUC16", 19, 9074696, 9074696, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074696C>T", "-", "c.12750G>A", "c.(12748-12750)acG>acA", "p.T4250T"},
                new Object[]{"MUC16", 19, 9049996, 9049996, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049996C>A", "-", "c.31635G>T", "c.(31633-31635)ctG>ctT", "p.L10545L"}
                );
    }
    static List<Object[]> provideMnpDataForMuc16_4() {
        return Arrays.asList(
                new Object[]{"MUC16", 19, 9063158, 9063158, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9063158C>A", "-", "c.24288G>T", "c.(24286-24288)acG>acT", "p.T8096T"},
                new Object[]{"MUC16", 19, 9071180, 9071180, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071180G>T", "-", "c.16266C>A", "c.(16264-16266)acC>acA", "p.T5422T"},
                new Object[]{"MUC16", 19, 9077392, 9077392, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077392C>A", "-", "c.10054G>T", "c.(10054-10056)Gga>Tga", "p.G3352*"},
                new Object[]{"MUC16", 19, 9077726, 9077726, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077726G>A", "-", "c.9720C>T", "c.(9718-9720)acC>acT", "p.T3240T"},
                new Object[]{"MUC16", 19, 9086950, 9086950, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9086950G>T", "-", "c.4865C>A", "c.(4864-4866)cCa>cAa", "p.P1622Q"},
                new Object[]{"MUC16", 19, 9087199, 9087199, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9087199G>T", "-", "c.4616C>A", "c.(4615-4617)cCa>cAa", "p.P1539Q"},
                new Object[]{"MUC16", 19, 9091107, 9091107, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9091107G>T", "-", "c.708C>A", "c.(706-708)tcC>tcA", "p.S236S"},
                new Object[]{"MUC16", 19, 9006363, 9006363, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:9006363A>G", "-", "c.39655T>C", "c.(39655-39657)Tgc>Cgc", "p.C13219R"},
                new Object[]{"MUC16", 19, 9049904, 9049904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049904C>A", "-", "c.31727G>T", "c.(31726-31728)gGg>gTg", "p.G10576V"},
                new Object[]{"MUC16", 19, 9060067, 9060067, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060067G>A", "-", "c.27379C>T", "c.(27379-27381)Cct>Tct", "p.P9127S"},
                new Object[]{"MUC16", 19, 9060965, 9060965, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060965C>T", "-", "c.26481G>A", "c.(26479-26481)ggG>ggA", "p.G8827G"},
                new Object[]{"MUC16", 19, 9066420, 9066420, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066420G>A", "-", "c.21026C>T", "c.(21025-21027)tCc>tTc", "p.S7009F"},
                new Object[]{"MUC16", 19, 9071068, 9071068, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071068C>A", "-", "c.16378G>T", "c.(16378-16380)Ggg>Tgg", "p.G5460W"},
                new Object[]{"MUC16", 19, 9075484, 9075484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075484C>T", "-", "c.11962G>A", "c.(11962-11964)Gaa>Aaa", "p.E3988K"},
                new Object[]{"MUC16", 19, 9088939, 9088939, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088939G>A", "-", "c.2876C>T", "c.(2875-2877)tCt>tTt", "p.S959F"},
                new Object[]{"MUC16", 19, 9065752, 9065752, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065752C>A", "-", "c.21694G>T", "c.(21694-21696)Gag>Tag", "p.E7232*"},
                new Object[]{"MUC16", 19, 9088147, 9088147, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088147G>T", "-", "c.3668C>A", "c.(3667-3669)cCa>cAa", "p.P1223Q"},
                new Object[]{"MUC16", 19, 9071371, 9071371, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071371G>T", "-", "c.16075C>A", "c.(16075-16077)Ccc>Acc", "p.P5359T"},
                new Object[]{"MUC16", 19, 9063923, 9063923, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063923C>T", "-", "c.23523G>A", "c.(23521-23523)ggG>ggA", "p.G7841G"},
                new Object[]{"MUC16", 19, 9069895, 9069895, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069895G>A", "-", "c.17551C>T", "c.(17551-17553)Cct>Tct", "p.P5851S"},
                new Object[]{"MUC16", 19, 9059294, 9059294, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059294C>A", "-", "c.28152G>T", "c.(28150-28152)ttG>ttT", "p.L9384F"},
                new Object[]{"MUC16", 19, 9077341, 9077341, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077341G>T", "-", "c.10105C>A", "c.(10105-10107)Ctt>Att", "p.L3369I"},
                new Object[]{"MUC16", 19, 9028301, 9028301, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9028301C>A", "-", "c.36491G>T", "c.(36490-36492)tGg>tTg", "p.W12164L"},
                new Object[]{"MUC16", 19, 9049048, 9049048, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9049048G>T", "-", "c.32583C>A", "c.(32581-32583)tcC>tcA", "p.S10861S"},
                new Object[]{"MUC16", 19, 9057555, 9057555, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9057555C>A", "-", "c.29891G>T", "c.(29890-29892)gGg>gTg", "p.G9964V"},
                new Object[]{"MUC16", 19, 9059581, 9059581, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059581C>A", "-", "c.27865G>T", "c.(27865-27867)Ggg>Tgg", "p.G9289W"},
                new Object[]{"MUC16", 19, 9062458, 9062458, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9062458G>T", "-", "c.24988C>A", "c.(24988-24990)Cat>Aat", "p.H8330N"},
                new Object[]{"MUC16", 19, 9065700, 9065700, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065700C>A", "-", "c.21746G>T", "c.(21745-21747)aGg>aTg", "p.R7249M"},
                new Object[]{"MUC16", 19, 9066751, 9066751, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066751C>A", "-", "c.20695G>T", "c.(20695-20697)Ggg>Tgg", "p.G6899W"},
                new Object[]{"MUC16", 19, 9071155, 9071155, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071155C>A", "-", "c.16291G>T", "c.(16291-16293)Ggg>Tgg", "p.G5431W"},
                new Object[]{"MUC16", 19, 9071171, 9071171, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9071171G>T", "-", "c.16275C>A", "c.(16273-16275)acC>acA", "p.T5425T"},
                new Object[]{"MUC16", 19, 9090379, 9090379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090379G>T", "-", "c.1436C>A", "c.(1435-1437)cCa>cAa", "p.P479Q"},
                new Object[]{"MUC16", 19, 9049258, 9049258, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049258C>T", "-", "c.32373G>A", "c.(32371-32373)cgG>cgA", "p.R10791R"},
                new Object[]{"MUC16", 19, 9059045, 9059045, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059045G>A", "-", "c.28401C>T", "c.(28399-28401)ttC>ttT", "p.F9467F"},
                new Object[]{"MUC16", 19, 9060492, 9060492, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060492G>A", "-", "c.26954C>T", "c.(26953-26955)gCt>gTt", "p.A8985V"},
                new Object[]{"MUC16", 19, 9060867, 9060867, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060867G>A", "-", "c.26579C>T", "c.(26578-26580)tCt>tTt", "p.S8860F"},
                new Object[]{"MUC16", 19, 9061543, 9061543, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061543C>T", "-", "c.25903G>A", "c.(25903-25905)Gat>Aat", "p.D8635N"},
                new Object[]{"MUC16", 19, 9062833, 9062833, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062833C>T", "-", "c.24613G>A", "c.(24613-24615)Gat>Aat", "p.D8205N"},
                new Object[]{"MUC16", 19, 9066587, 9066587, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9066587C>T", "-", "c.20859G>A", "c.(20857-20859)ctG>ctA", "p.L6953L"},
                new Object[]{"MUC16", 19, 9068506, 9068506, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068506C>T", "-", "c.18940G>A", "c.(18940-18942)Gaa>Aaa", "p.E6314K"},
                new Object[]{"MUC16", 19, 9077116, 9077116, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077116G>A", "-", "c.10330C>T", "c.(10330-10332)Cct>Tct", "p.P3444S"},
                new Object[]{"MUC16", 19, 9077817, 9077817, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077817C>T", "-", "c.9629G>A", "c.(9628-9630)aGc>aAc", "p.S3210N"},
                new Object[]{"MUC16", 19, 9082689, 9082689, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082689G>A", "-", "c.9126C>T", "c.(9124-9126)ttC>ttT", "p.F3042F"},
                new Object[]{"MUC16", 19, 9083324, 9083324, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9083324C>T", "-", "c.8491G>A", "c.(8491-8493)Gaa>Aaa", "p.E2831K"},
                new Object[]{"MUC16", 19, 9086712, 9086712, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086712G>A", "-", "c.5103C>T", "c.(5101-5103)tcC>tcT", "p.S1701S"},
                new Object[]{"MUC16", 19, 9090331, 9090331, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090331G>A", "-", "c.1484C>T", "c.(1483-1485)tCc>tTc", "p.S495F"},
                new Object[]{"MUC16", 19, 8997412, 8997412, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8997412C>A", "-", "c.41010G>T", "c.(41008-41010)ctG>ctT", "p.L13670L"},
                new Object[]{"MUC16", 19, 9061904, 9061904, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9061904G>T", "-", "c.25542C>A", "c.(25540-25542)acC>acA", "p.T8514T"},
                new Object[]{"MUC16", 19, 9065795, 9065795, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9065795G>T", "-", "c.21651C>A", "c.(21649-21651)acC>acA", "p.T7217T"},
                new Object[]{"MUC16", 19, 9085057, 9085057, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085057G>A", "-", "c.6758C>T", "c.(6757-6759)tCc>tTc", "p.S2253F"},
                new Object[]{"MUC16", 19, 8997482, 8997482, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8997482C>A", "-", "c.40940G>T", "c.(40939-40941)cGg>cTg", "p.R13647L"},
                new Object[]{"MUC16", 19, 9017423, 9017423, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9017423C>A", "-", "c.37901G>T", "c.(37900-37902)tGg>tTg", "p.W12634L"},
                new Object[]{"MUC16", 19, 9047545, 9047545, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9047545G>T", "-", "c.34086C>A", "c.(34084-34086)ccC>ccA", "p.P11362P"},
                new Object[]{"MUC16", 19, 9049996, 9049996, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049996C>A", "-", "c.31635G>T", "c.(31633-31635)ctG>ctT", "p.L10545L"},
                new Object[]{"MUC16", 19, 9065721, 9065721, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065721G>A", "-", "c.21725C>T", "c.(21724-21726)tCc>tTc", "p.S7242F"},
                new Object[]{"MUC16", 19, 9066676, 9066676, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9066676C>A", "-", "c.20770G>T", "c.(20770-20772)Ggg>Tgg", "p.G6924W"},
                new Object[]{"MUC16", 19, 9068061, 9068061, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9068061C>A", "-", "c.19385G>T", "c.(19384-19386)tGg>tTg", "p.W6462L"},
                new Object[]{"MUC16", 19, 9074237, 9074237, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9074237G>T", "-", "c.13209C>A", "c.(13207-13209)ctC>ctA", "p.L4403L"},
                new Object[]{"MUC16", 19, 9082503, 9082503, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9082503C>A", "-", "c.9312G>T", "c.(9310-9312)gaG>gaT", "p.E3104D"},
                new Object[]{"MUC16", 19, 9088055, 9088055, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088055C>A", "-", "c.3760G>T", "c.(3760-3762)Gga>Tga", "p.G1254*"},
                new Object[]{"MUC16", 19, 9089282, 9089282, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9089282C>A", "-", "c.2533G>T", "c.(2533-2535)Gga>Tga", "p.G845*"},
                new Object[]{"MUC16", 19, 9050137, 9050137, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9050137G>A", "-", "c.31494C>T", "c.(31492-31494)gtC>gtT", "p.V10498V"},
                new Object[]{"MUC16", 19, 9062601, 9062601, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062601G>A", "-", "c.24845C>T", "c.(24844-24846)tCc>tTc", "p.S8282F"},
                new Object[]{"MUC16", 19, 9064916, 9064916, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9064916G>T", "-", "c.22530C>A", "c.(22528-22530)acC>acA", "p.T7510T"},
                new Object[]{"MUC16", 19, 9069570, 9069570, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069570G>A", "-", "c.17876C>T", "c.(17875-17877)tCc>tTc", "p.S5959F"},
                new Object[]{"MUC16", 19, 9070578, 9070578, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070578G>A", "-", "c.16868C>T", "c.(16867-16869)cCc>cTc", "p.P5623L"},
                new Object[]{"MUC16", 19, 9085435, 9085435, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085435G>A", "-", "c.6380C>T", "c.(6379-6381)tCg>tTg", "p.S2127L"},
                new Object[]{"MUC16", 19, 9061109, 9061109, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061109C>T", "-", "c.26337G>A", "c.(26335-26337)acG>acA", "p.T8779T"},
                new Object[]{"MUC16", 19, 9069754, 9069754, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069754G>A", "-", "c.17692C>T", "c.(17692-17694)Cca>Tca", "p.P5898S"},
                new Object[]{"MUC16", 19, 9072816, 9072816, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9072816G>T", "-", "c.14630C>A", "c.(14629-14631)cCt>cAt", "p.P4877H"},
                new Object[]{"MUC16", 19, 9076887, 9076887, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076887G>A", "-", "c.10559C>T", "c.(10558-10560)tCa>tTa", "p.S3520L"},
                new Object[]{"MUC16", 19, 9087026, 9087026, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087026C>A", "-", "c.4789G>T", "c.(4789-4791)Ggg>Tgg", "p.G1597W"},
                new Object[]{"MUC16", 19, 9091259, 9091259, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091259G>A", "-", "c.556C>T", "c.(556-558)Cct>Tct", "p.P186S"},
                new Object[]{"MUC16", 19, 9017459, 9017459, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9017459G>T", "-", "c.37865C>A", "c.(37864-37866)cCc>cAc", "p.P12622H"},
                new Object[]{"MUC16", 19, 9060617, 9060617, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9060617C>A", "-", "c.26829G>T", "c.(26827-26829)atG>atT", "p.M8943I"},
                new Object[]{"MUC16", 19, 9077276, 9077276, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077276G>T", "-", "c.10170C>A", "c.(10168-10170)acC>acA", "p.T3390T"},
                new Object[]{"MUC16", 19, 9089934, 9089934, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089934G>A", "-", "c.1881C>T", "c.(1879-1881)ctC>ctT", "p.L627L"},
                new Object[]{"MUC16", 19, 9047181, 9047181, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047181C>T", "-", "c.34450G>A", "c.(34450-34452)Gaa>Aaa", "p.E11484K"},
                new Object[]{"MUC16", 19, 9071825, 9071825, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:9071825T>G", "-", "c.15621A>C", "c.(15619-15621)acA>acC", "p.T5207T"},
                new Object[]{"MUC16", 19, 9088068, 9088068, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088068G>T", "-", "c.3747C>A", "c.(3745-3747)ccC>ccA", "p.P1249P"},
                new Object[]{"MUC16", 19, 9075414, 9075414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075414G>A", "-", "c.12032C>T", "c.(12031-12033)tCc>tTc", "p.S4011F"},
                new Object[]{"MUC16", 19, 9048071, 9048071, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048071G>A", "-", "c.33560C>T", "c.(33559-33561)tCt>tTt", "p.S11187F"},
                new Object[]{"MUC16", 19, 9049971, 9049971, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049971G>A", "-", "c.31660C>T", "c.(31660-31662)Ccc>Tcc", "p.P10554S"},
                new Object[]{"MUC16", 19, 9070705, 9070705, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070705G>A", "-", "c.16741C>T", "c.(16741-16743)Ccc>Tcc", "p.P5581S"},
                new Object[]{"MUC16", 19, 9065042, 9065042, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065042C>A", "-", "c.22404G>T", "c.(22402-22404)acG>acT", "p.T7468T"},
                new Object[]{"MUC16", 19, 9047536, 9047536, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047536G>A", "-", "c.34095C>T", "c.(34093-34095)acC>acT", "p.T11365T"},
                new Object[]{"MUC16", 19, 9065829, 9065829, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065829G>A", "-", "c.21617C>T", "c.(21616-21618)tCc>tTc", "p.S7206F"},
                new Object[]{"MUC16", 19, 9069395, 9069395, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069395C>T", "-", "c.18051G>A", "c.(18049-18051)ggG>ggA", "p.G6017G"},
                new Object[]{"MUC16", 19, 9076958, 9076958, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076958C>T", "-", "c.10488G>A", "c.(10486-10488)gaG>gaA", "p.E3496E"},
                new Object[]{"MUC16", 19, 9091108, 9091108, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091108G>A", "-", "c.707C>T", "c.(706-708)tCc>tTc", "p.S236F"},
                new Object[]{"MUC16", 19, 9077822, 9077822, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077822G>A", "-", "c.9624C>T", "c.(9622-9624)atC>atT", "p.I3208I"},
                new Object[]{"MUC16", 19, 9059510, 9059510, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "G", "g.chr19:9059510C>G", "-", "c.27936G>C", "c.(27934-27936)gtG>gtC", "p.V9312V"},
                new Object[]{"MUC16", 19, 9048215, 9048215, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048215G>A", "-", "c.33416C>T", "c.(33415-33417)tCa>tTa", "p.S11139L"},
                new Object[]{"MUC16", 19, 9049492, 9049492, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049492G>A", "-", "c.32139C>T", "c.(32137-32139)gcC>gcT", "p.A10713A"},
                new Object[]{"MUC16", 19, 9057898, 9057898, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057898C>T", "-", "c.29548G>A", "c.(29548-29550)Gac>Aac", "p.D9850N"},
                new Object[]{"MUC16", 19, 9059273, 9059273, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059273G>A", "-", "c.28173C>T", "c.(28171-28173)tcC>tcT", "p.S9391S"},
                new Object[]{"MUC16", 19, 9060392, 9060392, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060392C>T", "-", "c.27054G>A", "c.(27052-27054)aaG>aaA", "p.K9018K"},
                new Object[]{"MUC16", 19, 9075252, 9075252, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075252G>A", "-", "c.12194C>T", "c.(12193-12195)tCt>tTt", "p.S4065F"},
                new Object[]{"MUC16", 19, 9069874, 9069874, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069874C>T", "-", "c.17572G>A", "c.(17572-17574)Gaa>Aaa", "p.E5858K"},
                new Object[]{"MUC16", 19, 9058952, 9058952, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058952C>T", "-", "c.28494G>A", "c.(28492-28494)gaG>gaA", "p.E9498E"},
                new Object[]{"MUC16", 19, 9074280, 9074280, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074280G>A", "-", "c.13166C>T", "c.(13165-13167)aCc>aTc", "p.T4389I"},
                new Object[]{"MUC16", 19, 9077007, 9077007, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077007C>T", "-", "c.10439G>A", "c.(10438-10440)gGa>gAa", "p.G3480E"},
                new Object[]{"MUC16", 19, 9012839, 9012839, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9012839C>T", "-", "c.38605G>A", "c.(38605-38607)Gag>Aag", "p.E12869K"},
                new Object[]{"MUC16", 19, 9060020, 9060020, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060020G>A", "-", "c.27426C>T", "c.(27424-27426)agC>agT", "p.S9142S"},
                new Object[]{"MUC16", 19, 9062392, 9062392, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062392C>T", "-", "c.25054G>A", "c.(25054-25056)Gca>Aca", "p.A8352T"},
                new Object[]{"MUC16", 19, 9068217, 9068217, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068217G>A", "-", "c.19229C>T", "c.(19228-19230)tCc>tTc", "p.S6410F"},
                new Object[]{"MUC16", 19, 9076139, 9076139, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076139G>A", "-", "c.11307C>T", "c.(11305-11307)atC>atT", "p.I3769I"},
                new Object[]{"MUC16", 19, 9087373, 9087373, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087373G>A", "-", "c.4442C>T", "c.(4441-4443)tCa>tTa", "p.S1481L"},
                new Object[]{"MUC16", 19, 9056625, 9056625, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056625G>A", "-", "c.30821C>T", "c.(30820-30822)tCc>tTc", "p.S10274F"},
                new Object[]{"MUC16", 19, 9060785, 9060785, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060785G>A", "-", "c.26661C>T", "c.(26659-26661)ttC>ttT", "p.F8887F"},
                new Object[]{"MUC16", 19, 9069045, 9069045, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069045G>A", "-", "c.18401C>T", "c.(18400-18402)tCa>tTa", "p.S6134L"},
                // Had to change gt transcript change
                new Object[]{"MUC16", 19, 8971824, 8971824, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8971824C>T", "-", "c.42768G>A", "c.(42766-42768)acG>acA", "p.T14256T"},
                new Object[]{"MUC16", 19, 8976750, 8976750, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8976750G>A", "-", "c.42316C>T", "c.(42316-42318)Ctt>Ttt", "p.L14106F"},
                new Object[]{"MUC16", 19, 8987264, 8987264, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8987264C>T", "-", "c.41823G>A", "c.(41821-41823)atG>atA", "p.M13941I"},
                new Object[]{"MUC16", 19, 8993436, 8993436, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8993436G>A", "-", "c.41653C>T", "c.(41653-41655)Ctg>Ttg", "p.L13885L"},
                new Object[]{"MUC16", 19, 8997177, 8997177, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8997177G>A", "-", "c.41019C>T", "c.(41017-41019)tcC>tcT", "p.S13673S"},
                new Object[]{"MUC16", 19, 8999551, 8999551, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999551C>T", "-", "c.40624G>A", "c.(40624-40626)Ggg>Agg", "p.G13542R"},
                new Object[]{"MUC16", 19, 9000453, 9000453, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9000453G>A", "-", "c.40531C>T", "c.(40531-40533)Ctt>Ttt", "p.L13511F"},
                new Object[]{"MUC16", 19, 9009273, 9009273, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9009273G>A", "-", "c.39200C>T", "c.(39199-39201)tCt>tTt", "p.S13067F"},
                new Object[]{"MUC16", 19, 9009648, 9009648, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9009648C>T", "-", "c.39078G>A", "c.(39076-39078)gaG>gaA", "p.E13026E"},
                new Object[]{"MUC16", 19, 9009703, 9009703, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9009703G>A", "-", "c.39023C>T", "c.(39022-39024)cCt>cTt", "p.P13008L"},
                new Object[]{"MUC16", 19, 9014585, 9014585, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014585C>T", "-", "c.38390G>A", "c.(38389-38391)gGc>gAc", "p.G12797D"},
                new Object[]{"MUC16", 19, 9014622, 9014622, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014622C>T", "-", "c.38353G>A", "c.(38353-38355)Gag>Aag", "p.E12785K"},
                new Object[]{"MUC16", 19, 9014636, 9014636, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9014636G>A", "-", "c.38339C>T", "c.(38338-38340)cCt>cTt", "p.P12780L"},
                new Object[]{"MUC16", 19, 9017436, 9017436, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9017436C>T", "-", "c.37888G>A", "c.(37888-37890)Gag>Aag", "p.E12630K"},
                new Object[]{"MUC16", 19, 9017450, 9017450, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9017450G>A", "-", "c.37874C>T", "c.(37873-37875)cCt>cTt", "p.P12625L"},
                new Object[]{"MUC16", 19, 9018484, 9018484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9018484G>A", "-", "c.37690C>T", "c.(37690-37692)Cct>Tct", "p.P12564S"},
                new Object[]{"MUC16", 19, 9021059, 9021059, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9021059C>T", "-", "c.37264G>A", "c.(37264-37266)Ggt>Agt", "p.G12422S"},
                new Object[]{"MUC16", 19, 9028347, 9028347, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9028347G>A", "-", "c.36445C>T", "c.(36445-36447)Cgc>Tgc", "p.R12149C"},
                new Object[]{"MUC16", 19, 9038103, 9038103, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9038103G>A", "-", "c.36173C>T", "c.(36172-36174)tCc>tTc", "p.S12058F"},
                new Object[]{"MUC16", 19, 9045590, 9045590, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045590G>A", "-", "c.36041C>T", "c.(36040-36042)gCc>gTc", "p.A12014V"},
                new Object[]{"MUC16", 19, 9046410, 9046410, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046410C>T", "-", "c.35221G>A", "c.(35221-35223)Gag>Aag", "p.E11741K"},
                new Object[]{"MUC16", 19, 9046907, 9046907, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046907G>A", "-", "c.34724C>T", "c.(34723-34725)gCc>gTc", "p.A11575V"},
                new Object[]{"MUC16", 19, 9047750, 9047750, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047750G>A", "-", "c.33881C>T", "c.(33880-33882)tCt>tTt", "p.S11294F"},
                new Object[]{"MUC16", 19, 9047864, 9047864, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047864G>A", "-", "c.33767C>T", "c.(33766-33768)tCc>tTc", "p.S11256F"},
                new Object[]{"MUC16", 19, 9048259, 9048259, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048259C>T", "-", "c.33372G>A", "c.(33370-33372)gaG>gaA", "p.E11124E"},
                new Object[]{"MUC16", 19, 9048826, 9048826, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048826G>A", "-", "c.32805C>T", "c.(32803-32805)acC>acT", "p.T10935T"},
                new Object[]{"MUC16", 19, 9049049, 9049049, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049049G>A", "-", "c.32582C>T", "c.(32581-32583)tCc>tTc", "p.S10861F"},
                new Object[]{"MUC16", 19, 9049182, 9049182, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049182C>T", "-", "c.32449G>A", "c.(32449-32451)Gaa>Aaa", "p.E10817K"},
                new Object[]{"MUC16", 19, 9049518, 9049518, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049518C>T", "-", "c.32113G>A", "c.(32113-32115)Gaa>Aaa", "p.E10705K"},
                new Object[]{"MUC16", 19, 9049948, 9049948, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049948G>A", "-", "c.31683C>T", "c.(31681-31683)ttC>ttT", "p.F10561F"},
                new Object[]{"MUC16", 19, 9056223, 9056223, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056223C>T", "-", "c.31223G>A", "c.(31222-31224)gGa>gAa", "p.G10408E"},
                new Object[]{"MUC16", 19, 9056224, 9056224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056224C>T", "-", "c.31222G>A", "c.(31222-31224)Gga>Aga", "p.G10408R"},
                new Object[]{"MUC16", 19, 9056435, 9056435, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056435G>A", "-", "c.31011C>T", "c.(31009-31011)ttC>ttT", "p.F10337F"},
                new Object[]{"MUC16", 19, 9056563, 9056563, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056563G>A", "-", "c.30883C>T", "c.(30883-30885)Cca>Tca", "p.P10295S"},
                new Object[]{"MUC16", 19, 9057615, 9057615, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057615G>A", "-", "c.29831C>T", "c.(29830-29832)tCc>tTc", "p.S9944F"},
                new Object[]{"MUC16", 19, 9057713, 9057713, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057713C>T", "-", "c.29733G>A", "c.(29731-29733)atG>atA", "p.M9911I"},
                new Object[]{"MUC16", 19, 9057754, 9057754, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057754G>A", "-", "c.29692C>T", "c.(29692-29694)Ctt>Ttt", "p.L9898F"},
                new Object[]{"MUC16", 19, 9057787, 9057787, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057787C>T", "-", "c.29659G>A", "c.(29659-29661)Gag>Aag", "p.E9887K"},
                new Object[]{"MUC16", 19, 9057962, 9057962, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057962G>A", "-", "c.29484C>T", "c.(29482-29484)tcC>tcT", "p.S9828S"},
                new Object[]{"MUC16", 19, 9058360, 9058360, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058360C>T", "-", "c.29086G>A", "c.(29086-29088)Gga>Aga", "p.G9696R"},
                new Object[]{"MUC16", 19, 9058581, 9058581, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058581G>A", "-", "c.28865C>T", "c.(28864-28866)cCc>cTc", "p.P9622L"},
                new Object[]{"MUC16", 19, 9058656, 9058656, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058656G>A", "-", "c.28790C>T", "c.(28789-28791)tCc>tTc", "p.S9597F"},
                new Object[]{"MUC16", 19, 9059450, 9059450, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059450G>A", "-", "c.27996C>T", "c.(27994-27996)tcC>tcT", "p.S9332S"},
                new Object[]{"MUC16", 19, 9059860, 9059860, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059860C>T", "-", "c.27586G>A", "c.(27586-27588)Gaa>Aaa", "p.E9196K"},
                new Object[]{"MUC16", 19, 9060569, 9060569, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060569G>A", "-", "c.26877C>T", "c.(26875-26877)ctC>ctT", "p.L8959L"},
                new Object[]{"MUC16", 19, 9060664, 9060664, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060664C>T", "-", "c.26782G>A", "c.(26782-26784)Gag>Aag", "p.E8928K"},
                new Object[]{"MUC16", 19, 9060837, 9060837, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060837G>A", "-", "c.26609C>T", "c.(26608-26610)tCc>tTc", "p.S8870F"},
                new Object[]{"MUC16", 19, 9061005, 9061005, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061005C>T", "-", "c.26441G>A", "c.(26440-26442)gGa>gAa", "p.G8814E"},
                new Object[]{"MUC16", 19, 9061161, 9061161, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061161G>A", "-", "c.26285C>T", "c.(26284-26286)tCa>tTa", "p.S8762L"},
                new Object[]{"MUC16", 19, 9061180, 9061180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061180G>A", "-", "c.26266C>T", "c.(26266-26268)Cct>Tct", "p.P8756S"},
                new Object[]{"MUC16", 19, 9061487, 9061487, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061487C>T", "-", "c.25959G>A", "c.(25957-25959)gtG>gtA", "p.V8653V"},
                new Object[]{"MUC16", 19, 9061525, 9061525, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061525G>A", "-", "c.25921C>T", "c.(25921-25923)Ccc>Tcc", "p.P8641S"},
                new Object[]{"MUC16", 19, 9062045, 9062045, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062045G>A", "-", "c.25401C>T", "c.(25399-25401)ttC>ttT", "p.F8467F"},
                new Object[]{"MUC16", 19, 9062075, 9062075, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062075C>T", "-", "c.25371G>A", "c.(25369-25371)agG>agA", "p.R8457R"},
                new Object[]{"MUC16", 19, 9062169, 9062169, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062169C>T", "-", "c.25277G>A", "c.(25276-25278)aGg>aAg", "p.R8426K"},
                new Object[]{"MUC16", 19, 9062500, 9062500, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062500C>T", "-", "c.24946G>A", "c.(24946-24948)Gaa>Aaa", "p.E8316K"},
                new Object[]{"MUC16", 19, 9063345, 9063345, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063345G>A", "-", "c.24101C>T", "c.(24100-24102)tCa>tTa", "p.S8034L"},
                new Object[]{"MUC16", 19, 9063593, 9063593, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063593C>T", "-", "c.23853G>A", "c.(23851-23853)agG>agA", "p.R7951R"},
                new Object[]{"MUC16", 19, 9063965, 9063965, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063965G>A", "-", "c.23481C>T", "c.(23479-23481)tcC>tcT", "p.S7827S"},
                new Object[]{"MUC16", 19, 9064290, 9064290, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064290G>A", "-", "c.23156C>T", "c.(23155-23157)tCa>tTa", "p.S7719L"},
                new Object[]{"MUC16", 19, 9064299, 9064299, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064299G>A", "-", "c.23147C>T", "c.(23146-23148)cCt>cTt", "p.P7716L"},
                new Object[]{"MUC16", 19, 9064305, 9064305, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064305G>A", "-", "c.23141C>T", "c.(23140-23142)cCc>cTc", "p.P7714L"},
                new Object[]{"MUC16", 19, 9064619, 9064619, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064619G>A", "-", "c.22827C>T", "c.(22825-22827)gcC>gcT", "p.A7609A"},
                new Object[]{"MUC16", 19, 9064667, 9064667, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064667G>A", "-", "c.22779C>T", "c.(22777-22779)tcC>tcT", "p.S7593S"},
                new Object[]{"MUC16", 19, 9064856, 9064856, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064856C>T", "-", "c.22590G>A", "c.(22588-22590)agG>agA", "p.R7530R"},
                new Object[]{"MUC16", 19, 9065396, 9065396, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065396G>A", "-", "c.22050C>T", "c.(22048-22050)tcC>tcT", "p.S7350S"},
                new Object[]{"MUC16", 19, 9065888, 9065888, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065888C>T", "-", "c.21558G>A", "c.(21556-21558)gtG>gtA", "p.V7186V"},
                new Object[]{"MUC16", 19, 9066331, 9066331, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9066331A>T", "-", "c.21115T>A", "c.(21115-21117)Tct>Act", "p.S7039T"},
                new Object[]{"MUC16", 19, 9066520, 9066520, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066520G>A", "-", "c.20926C>T", "c.(20926-20928)Ccc>Tcc", "p.P6976S"},
                new Object[]{"MUC16", 19, 9067224, 9067224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067224G>A", "-", "c.20222C>T", "c.(20221-20223)cCt>cTt", "p.P6741L"},
                new Object[]{"MUC16", 19, 9067464, 9067464, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067464C>T", "-", "c.19982G>A", "c.(19981-19983)gGa>gAa", "p.G6661E"},
                new Object[]{"MUC16", 19, 9067484, 9067484, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067484G>A", "-", "c.19962C>T", "c.(19960-19962)tcC>tcT", "p.S6654S"},
                new Object[]{"MUC16", 19, 9067623, 9067623, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067623G>A", "-", "c.19823C>T", "c.(19822-19824)tCg>tTg", "p.S6608L"},
                new Object[]{"MUC16", 19, 9067679, 9067679, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067679G>A", "-", "c.19767C>T", "c.(19765-19767)tcC>tcT", "p.S6589S"},
                new Object[]{"MUC16", 19, 9068061, 9068061, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068061C>T", "-", "c.19385G>A", "c.(19384-19386)tGg>tAg", "p.W6462*"},
                new Object[]{"MUC16", 19, 9069180, 9069180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069180G>A", "-", "c.18266C>T", "c.(18265-18267)tCa>tTa", "p.S6089L"},
                new Object[]{"MUC16", 19, 9069366, 9069366, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069366G>A", "-", "c.18080C>T", "c.(18079-18081)tCc>tTc", "p.S6027F"},
                new Object[]{"MUC16", 19, 9069622, 9069622, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069622G>A", "-", "c.17824C>T", "c.(17824-17826)Ctt>Ttt", "p.L5942F"},
                new Object[]{"MUC16", 19, 9069754, 9069754, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069754G>A", "-", "c.17692C>T", "c.(17692-17694)Cca>Tca", "p.P5898S"},
                new Object[]{"MUC16", 19, 9069821, 9069821, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069821G>A", "-", "c.17625C>T", "c.(17623-17625)acC>acT", "p.T5875T"},
                new Object[]{"MUC16", 19, 9070255, 9070255, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070255C>T", "-", "c.17191G>A", "c.(17191-17193)Gaa>Aaa", "p.E5731K"},
                new Object[]{"MUC16", 19, 9070360, 9070360, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070360C>T", "-", "c.17086G>A", "c.(17086-17088)Gag>Aag", "p.E5696K"},
                new Object[]{"MUC16", 19, 9070509, 9070509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070509G>A", "-", "c.16937C>T", "c.(16936-16938)tCc>tTc", "p.S5646F"},
                new Object[]{"MUC16", 19, 9070533, 9070533, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070533G>A", "-", "c.16913C>T", "c.(16912-16914)tCc>tTc", "p.S5638F"},
                new Object[]{"MUC16", 19, 9071252, 9071252, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071252G>A", "-", "c.16194C>T", "c.(16192-16194)atC>atT", "p.I5398I"},
                new Object[]{"MUC16", 19, 9071513, 9071513, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071513G>A", "-", "c.15933C>T", "c.(15931-15933)acC>acT", "p.T5311T"},
                new Object[]{"MUC16", 19, 9071765, 9071765, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071765G>A", "-", "c.15681C>T", "c.(15679-15681)gtC>gtT", "p.V5227V"},
                new Object[]{"MUC16", 19, 9071953, 9071953, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071953G>A", "-", "c.15493C>T", "c.(15493-15495)Cct>Tct", "p.P5165S"},
                new Object[]{"MUC16", 19, 9072087, 9072087, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072087G>A", "-", "c.15359C>T", "c.(15358-15360)tCt>tTt", "p.S5120F"},
                new Object[]{"MUC16", 19, 9072128, 9072128, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072128G>A", "-", "c.15318C>T", "c.(15316-15318)gcC>gcT", "p.A5106A"},
                new Object[]{"MUC16", 19, 9072407, 9072407, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072407C>T", "-", "c.15039G>A", "c.(15037-15039)ttG>ttA", "p.L5013L"},
                new Object[]{"MUC16", 19, 9072414, 9072414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072414G>A", "-", "c.15032C>T", "c.(15031-15033)tCa>tTa", "p.S5011L"},
                new Object[]{"MUC16", 19, 9073656, 9073656, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073656G>A", "-", "c.13790C>T", "c.(13789-13791)tCc>tTc", "p.S4597F"},
                new Object[]{"MUC16", 19, 9073721, 9073721, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9073721C>T", "-", "c.13725G>A", "c.(13723-13725)ggG>ggA", "p.G4575G"},
                new Object[]{"MUC16", 19, 9074222, 9074222, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074222G>A", "-", "c.13224C>T", "c.(13222-13224)acC>acT", "p.T4408T"},
                new Object[]{"MUC16", 19, 9074263, 9074263, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074263C>T", "-", "c.13183G>A", "c.(13183-13185)Gga>Aga", "p.G4395R"},
                new Object[]{"MUC16", 19, 9074867, 9074867, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074867G>A", "-", "c.12579C>T", "c.(12577-12579)ttC>ttT", "p.F4193F"},
                new Object[]{"MUC16", 19, 9074991, 9074991, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074991G>A", "-", "c.12455C>T", "c.(12454-12456)tCt>tTt", "p.S4152F"},
                new Object[]{"MUC16", 19, 9075173, 9075173, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075173C>T", "-", "c.12273G>A", "c.(12271-12273)atG>atA", "p.M4091I"},
                new Object[]{"MUC16", 19, 9075287, 9075287, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075287G>A", "-", "c.12159C>T", "c.(12157-12159)tcC>tcT", "p.S4053S"},
                new Object[]{"MUC16", 19, 9075383, 9075383, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075383G>A", "-", "c.12063C>T", "c.(12061-12063)agC>agT", "p.S4021S"},
                new Object[]{"MUC16", 19, 9075484, 9075484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075484C>T", "-", "c.11962G>A", "c.(11962-11964)Gaa>Aaa", "p.E3988K"},
                new Object[]{"MUC16", 19, 9076695, 9076695, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076695G>A", "-", "c.10751C>T", "c.(10750-10752)tCt>tTt", "p.S3584F"},
                new Object[]{"MUC16", 19, 9077159, 9077159, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077159C>T", "-", "c.10287G>A", "c.(10285-10287)tgG>tgA", "p.W3429*"},
                new Object[]{"MUC16", 19, 9077764, 9077764, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077764G>A", "-", "c.9682C>T", "c.(9682-9684)Cct>Tct", "p.P3228S"},
                new Object[]{"MUC16", 19, 9082364, 9082364, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082364G>A", "-", "c.9451C>T", "c.(9451-9453)Cct>Tct", "p.P3151S"},
                new Object[]{"MUC16", 19, 9082505, 9082505, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082505C>T", "-", "c.9310G>A", "c.(9310-9312)Gag>Aag", "p.E3104K"},
                new Object[]{"MUC16", 19, 9082626, 9082626, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082626C>T", "-", "c.9189G>A", "c.(9187-9189)agG>agA", "p.R3063R"},
                new Object[]{"MUC16", 19, 9082977, 9082977, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082977C>T", "-", "c.8838G>A", "c.(8836-8838)aaG>aaA", "p.K2946K"},
                new Object[]{"MUC16", 19, 9083067, 9083067, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083067G>A", "-", "c.8748C>T", "c.(8746-8748)acC>acT", "p.T2916T"},
                new Object[]{"MUC16", 19, 9083611, 9083611, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083611G>A", "-", "c.8204C>T", "c.(8203-8205)cCa>cTa", "p.P2735L"},
                new Object[]{"MUC16", 19, 9083644, 9083644, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083644G>A", "-", "c.8171C>T", "c.(8170-8172)cCt>cTt", "p.P2724L"},
                new Object[]{"MUC16", 19, 9084263, 9084263, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084263C>T", "-", "c.7552G>A", "c.(7552-7554)Ggc>Agc", "p.G2518S"},
                new Object[]{"MUC16", 19, 9084500, 9084500, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084500C>T", "-", "c.7315G>A", "c.(7315-7317)Ggg>Agg", "p.G2439R"},
                new Object[]{"MUC16", 19, 9084665, 9084665, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084665C>T", "-", "c.7150G>A", "c.(7150-7152)Gat>Aat", "p.D2384N"},
                new Object[]{"MUC16", 19, 9085498, 9085498, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085498G>A", "-", "c.6317C>T", "c.(6316-6318)cCa>cTa", "p.P2106L"},
                new Object[]{"MUC16", 19, 9085504, 9085504, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085504C>T", "-", "c.6311G>A", "c.(6310-6312)aGa>aAa", "p.R2104K"},
                new Object[]{"MUC16", 19, 9085580, 9085580, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085580C>T", "-", "c.6235G>A", "c.(6235-6237)Ggg>Agg", "p.G2079R"},
                new Object[]{"MUC16", 19, 9085734, 9085734, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085734G>A", "-", "c.6081C>T", "c.(6079-6081)tcC>tcT", "p.S2027S"},
                new Object[]{"MUC16", 19, 9085995, 9085995, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085995G>A", "-", "c.5820C>T", "c.(5818-5820)tcC>tcT", "p.S1940S"},
                new Object[]{"MUC16", 19, 9086464, 9086464, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086464G>A", "-", "c.5351C>T", "c.(5350-5352)tCt>tTt", "p.S1784F"},
                new Object[]{"MUC16", 19, 9086521, 9086521, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086521C>T", "-", "c.5294G>A", "c.(5293-5295)gGc>gAc", "p.G1765D"},
                new Object[]{"MUC16", 19, 9086960, 9086960, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086960C>T", "-", "c.4855G>A", "c.(4855-4857)Gag>Aag", "p.E1619K"},
                new Object[]{"MUC16", 19, 9087344, 9087344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087344G>A", "-", "c.4471C>T", "c.(4471-4473)Cct>Tct", "p.P1491S"},
                new Object[]{"MUC16", 19, 9087697, 9087697, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087697G>A", "-", "c.4118C>T", "c.(4117-4119)tCa>tTa", "p.S1373L"},
                new Object[]{"MUC16", 19, 9087887, 9087887, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087887G>A", "-", "c.3928C>T", "c.(3928-3930)Cct>Tct", "p.P1310S"},
                new Object[]{"MUC16", 19, 9088430, 9088430, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088430G>A", "-", "c.3385C>T", "c.(3385-3387)Ctg>Ttg", "p.L1129L"},
                new Object[]{"MUC16", 19, 9088726, 9088726, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088726G>A", "-", "c.3089C>T", "c.(3088-3090)cCa>cTa", "p.P1030L"},
                new Object[]{"MUC16", 19, 9088839, 9088839, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088839G>A", "-", "c.2976C>T", "c.(2974-2976)ctC>ctT", "p.L992L"},
                new Object[]{"MUC16", 19, 9089883, 9089883, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089883C>T", "-", "c.1932G>A", "c.(1930-1932)acG>acA", "p.T644T"},
                new Object[]{"MUC16", 19, 9089917, 9089917, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089917G>A", "-", "c.1898C>T", "c.(1897-1899)tCa>tTa", "p.S633L"},
                new Object[]{"MUC16", 19, 9090556, 9090556, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090556G>A", "-", "c.1259C>T", "c.(1258-1260)aCc>aTc", "p.T420I"},
                new Object[]{"MUC16", 19, 9090630, 9090630, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090630G>A", "-", "c.1185C>T", "c.(1183-1185)acC>acT", "p.T395T"},
                new Object[]{"MUC16", 19, 9091388, 9091388, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091388C>T", "-", "c.427G>A", "c.(427-429)Gaa>Aaa", "p.E143K"},
                new Object[]{"MUC16", 19, 9091556, 9091556, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091556G>A", "-", "c.259C>T", "c.(259-261)Cct>Tct", "p.P87S"},
                new Object[]{"MUC16", 19, 9091567, 9091567, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091567G>A", "-", "c.248C>T", "c.(247-249)tCc>tTc", "p.S83F"},
                new Object[]{"MUC16", 19, 8976750, 8976750, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8976750G>A", "-", "c.42316C>T", "c.(42316-42318)Ctt>Ttt", "p.L14106F"},
                new Object[]{"MUC16", 19, 8987264, 8987264, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8987264C>T", "-", "c.41823G>A", "c.(41821-41823)atG>atA", "p.M13941I"},
                new Object[]{"MUC16", 19, 8993436, 8993436, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8993436G>A", "-", "c.41653C>T", "c.(41653-41655)Ctg>Ttg", "p.L13885L"},
                new Object[]{"MUC16", 19, 8997177, 8997177, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8997177G>A", "-", "c.41019C>T", "c.(41017-41019)tcC>tcT", "p.S13673S"},
                new Object[]{"MUC16", 19, 9000453, 9000453, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9000453G>A", "-", "c.40531C>T", "c.(40531-40533)Ctt>Ttt", "p.L13511F"},
                new Object[]{"MUC16", 19, 9009273, 9009273, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9009273G>A", "-", "c.39200C>T", "c.(39199-39201)tCt>tTt", "p.S13067F"},
                new Object[]{"MUC16", 19, 9009648, 9009648, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9009648C>T", "-", "c.39078G>A", "c.(39076-39078)gaG>gaA", "p.E13026E"},
                new Object[]{"MUC16", 19, 9009703, 9009703, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9009703G>A", "-", "c.39023C>T", "c.(39022-39024)cCt>cTt", "p.P13008L"},
                new Object[]{"MUC16", 19, 9014585, 9014585, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014585C>T", "-", "c.38390G>A", "c.(38389-38391)gGc>gAc", "p.G12797D"},
                new Object[]{"MUC16", 19, 9014622, 9014622, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014622C>T", "-", "c.38353G>A", "c.(38353-38355)Gag>Aag", "p.E12785K"},
                new Object[]{"MUC16", 19, 9014636, 9014636, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9014636G>A", "-", "c.38339C>T", "c.(38338-38340)cCt>cTt", "p.P12780L"},
                new Object[]{"MUC16", 19, 9017436, 9017436, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9017436C>T", "-", "c.37888G>A", "c.(37888-37890)Gag>Aag", "p.E12630K"},
                new Object[]{"MUC16", 19, 9017450, 9017450, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9017450G>A", "-", "c.37874C>T", "c.(37873-37875)cCt>cTt", "p.P12625L"},
                new Object[]{"MUC16", 19, 9018484, 9018484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9018484G>A", "-", "c.37690C>T", "c.(37690-37692)Cct>Tct", "p.P12564S"},
                new Object[]{"MUC16", 19, 9021059, 9021059, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9021059C>T", "-", "c.37264G>A", "c.(37264-37266)Ggt>Agt", "p.G12422S"},
                new Object[]{"MUC16", 19, 9028347, 9028347, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9028347G>A", "-", "c.36445C>T", "c.(36445-36447)Cgc>Tgc", "p.R12149C"},
                new Object[]{"MUC16", 19, 9038103, 9038103, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9038103G>A", "-", "c.36173C>T", "c.(36172-36174)tCc>tTc", "p.S12058F"},
                new Object[]{"MUC16", 19, 9045590, 9045590, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045590G>A", "-", "c.36041C>T", "c.(36040-36042)gCc>gTc", "p.A12014V"},
                new Object[]{"MUC16", 19, 9046410, 9046410, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046410C>T", "-", "c.35221G>A", "c.(35221-35223)Gag>Aag", "p.E11741K"},
                new Object[]{"MUC16", 19, 9046907, 9046907, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046907G>A", "-", "c.34724C>T", "c.(34723-34725)gCc>gTc", "p.A11575V"},
                new Object[]{"MUC16", 19, 9047750, 9047750, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047750G>A", "-", "c.33881C>T", "c.(33880-33882)tCt>tTt", "p.S11294F"},
                new Object[]{"MUC16", 19, 9047864, 9047864, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047864G>A", "-", "c.33767C>T", "c.(33766-33768)tCc>tTc", "p.S11256F"},
                new Object[]{"MUC16", 19, 9048259, 9048259, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9048259C>T", "-", "c.33372G>A", "c.(33370-33372)gaG>gaA", "p.E11124E"},
                new Object[]{"MUC16", 19, 9048826, 9048826, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048826G>A", "-", "c.32805C>T", "c.(32803-32805)acC>acT", "p.T10935T"},
                new Object[]{"MUC16", 19, 9049049, 9049049, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049049G>A", "-", "c.32582C>T", "c.(32581-32583)tCc>tTc", "p.S10861F"},
                new Object[]{"MUC16", 19, 9049182, 9049182, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049182C>T", "-", "c.32449G>A", "c.(32449-32451)Gaa>Aaa", "p.E10817K"},
                new Object[]{"MUC16", 19, 9049518, 9049518, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049518C>T", "-", "c.32113G>A", "c.(32113-32115)Gaa>Aaa", "p.E10705K"},
                new Object[]{"MUC16", 19, 9049948, 9049948, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049948G>A", "-", "c.31683C>T", "c.(31681-31683)ttC>ttT", "p.F10561F"},
                new Object[]{"MUC16", 19, 9056223, 9056223, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056223C>T", "-", "c.31223G>A", "c.(31222-31224)gGa>gAa", "p.G10408E"},
                new Object[]{"MUC16", 19, 9056224, 9056224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056224C>T", "-", "c.31222G>A", "c.(31222-31224)Gga>Aga", "p.G10408R"},
                new Object[]{"MUC16", 19, 9056435, 9056435, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056435G>A", "-", "c.31011C>T", "c.(31009-31011)ttC>ttT", "p.F10337F"},
                new Object[]{"MUC16", 19, 9056563, 9056563, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056563G>A", "-", "c.30883C>T", "c.(30883-30885)Cca>Tca", "p.P10295S"},
                new Object[]{"MUC16", 19, 9057615, 9057615, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057615G>A", "-", "c.29831C>T", "c.(29830-29832)tCc>tTc", "p.S9944F"},
                new Object[]{"MUC16", 19, 9057713, 9057713, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057713C>T", "-", "c.29733G>A", "c.(29731-29733)atG>atA", "p.M9911I"},
                new Object[]{"MUC16", 19, 9057754, 9057754, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057754G>A", "-", "c.29692C>T", "c.(29692-29694)Ctt>Ttt", "p.L9898F"},
                new Object[]{"MUC16", 19, 9057787, 9057787, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057787C>T", "-", "c.29659G>A", "c.(29659-29661)Gag>Aag", "p.E9887K"},
                new Object[]{"MUC16", 19, 9057962, 9057962, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057962G>A", "-", "c.29484C>T", "c.(29482-29484)tcC>tcT", "p.S9828S"},
                new Object[]{"MUC16", 19, 9058360, 9058360, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9058360C>T", "-", "c.29086G>A", "c.(29086-29088)Gga>Aga", "p.G9696R"},
                new Object[]{"MUC16", 19, 9058581, 9058581, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058581G>A", "-", "c.28865C>T", "c.(28864-28866)cCc>cTc", "p.P9622L"},
                new Object[]{"MUC16", 19, 9058656, 9058656, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9058656G>A", "-", "c.28790C>T", "c.(28789-28791)tCc>tTc", "p.S9597F"},
                new Object[]{"MUC16", 19, 9059450, 9059450, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059450G>A", "-", "c.27996C>T", "c.(27994-27996)tcC>tcT", "p.S9332S"},
                new Object[]{"MUC16", 19, 9059860, 9059860, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9059860C>T", "-", "c.27586G>A", "c.(27586-27588)Gaa>Aaa", "p.E9196K"},
                new Object[]{"MUC16", 19, 9060569, 9060569, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060569G>A", "-", "c.26877C>T", "c.(26875-26877)ctC>ctT", "p.L8959L"},
                new Object[]{"MUC16", 19, 9060664, 9060664, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060664C>T", "-", "c.26782G>A", "c.(26782-26784)Gag>Aag", "p.E8928K"},
                new Object[]{"MUC16", 19, 9060837, 9060837, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060837G>A", "-", "c.26609C>T", "c.(26608-26610)tCc>tTc", "p.S8870F"},
                new Object[]{"MUC16", 19, 9061005, 9061005, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061005C>T", "-", "c.26441G>A", "c.(26440-26442)gGa>gAa", "p.G8814E"},
                new Object[]{"MUC16", 19, 9061161, 9061161, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061161G>A", "-", "c.26285C>T", "c.(26284-26286)tCa>tTa", "p.S8762L"},
                new Object[]{"MUC16", 19, 9061180, 9061180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061180G>A", "-", "c.26266C>T", "c.(26266-26268)Cct>Tct", "p.P8756S"},
                new Object[]{"MUC16", 19, 9061487, 9061487, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9061487C>T", "-", "c.25959G>A", "c.(25957-25959)gtG>gtA", "p.V8653V"},
                new Object[]{"MUC16", 19, 9061525, 9061525, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061525G>A", "-", "c.25921C>T", "c.(25921-25923)Ccc>Tcc", "p.P8641S"},
                new Object[]{"MUC16", 19, 9062045, 9062045, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062045G>A", "-", "c.25401C>T", "c.(25399-25401)ttC>ttT", "p.F8467F"},
                new Object[]{"MUC16", 19, 9062075, 9062075, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062075C>T", "-", "c.25371G>A", "c.(25369-25371)agG>agA", "p.R8457R"},
                new Object[]{"MUC16", 19, 9062169, 9062169, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062169C>T", "-", "c.25277G>A", "c.(25276-25278)aGg>aAg", "p.R8426K"},
                new Object[]{"MUC16", 19, 9062500, 9062500, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062500C>T", "-", "c.24946G>A", "c.(24946-24948)Gaa>Aaa", "p.E8316K"},
                new Object[]{"MUC16", 19, 9063345, 9063345, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063345G>A", "-", "c.24101C>T", "c.(24100-24102)tCa>tTa", "p.S8034L"},
                new Object[]{"MUC16", 19, 9063593, 9063593, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063593C>T", "-", "c.23853G>A", "c.(23851-23853)agG>agA", "p.R7951R"},
                new Object[]{"MUC16", 19, 9063965, 9063965, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063965G>A", "-", "c.23481C>T", "c.(23479-23481)tcC>tcT", "p.S7827S"},
                new Object[]{"MUC16", 19, 9064290, 9064290, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064290G>A", "-", "c.23156C>T", "c.(23155-23157)tCa>tTa", "p.S7719L"},
                new Object[]{"MUC16", 19, 9064299, 9064299, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064299G>A", "-", "c.23147C>T", "c.(23146-23148)cCt>cTt", "p.P7716L"},
                new Object[]{"MUC16", 19, 9064305, 9064305, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064305G>A", "-", "c.23141C>T", "c.(23140-23142)cCc>cTc", "p.P7714L"},
                new Object[]{"MUC16", 19, 9064619, 9064619, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064619G>A", "-", "c.22827C>T", "c.(22825-22827)gcC>gcT", "p.A7609A"},
                new Object[]{"MUC16", 19, 9064667, 9064667, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064667G>A", "-", "c.22779C>T", "c.(22777-22779)tcC>tcT", "p.S7593S"},
                new Object[]{"MUC16", 19, 9064856, 9064856, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9064856C>T", "-", "c.22590G>A", "c.(22588-22590)agG>agA", "p.R7530R"},
                new Object[]{"MUC16", 19, 9065396, 9065396, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065396G>A", "-", "c.22050C>T", "c.(22048-22050)tcC>tcT", "p.S7350S"},
                new Object[]{"MUC16", 19, 9065888, 9065888, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065888C>T", "-", "c.21558G>A", "c.(21556-21558)gtG>gtA", "p.V7186V"},
                new Object[]{"MUC16", 19, 9066331, 9066331, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9066331A>T", "-", "c.21115T>A", "c.(21115-21117)Tct>Act", "p.S7039T"},
                new Object[]{"MUC16", 19, 9066520, 9066520, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066520G>A", "-", "c.20926C>T", "c.(20926-20928)Ccc>Tcc", "p.P6976S"},
                new Object[]{"MUC16", 19, 9067224, 9067224, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067224G>A", "-", "c.20222C>T", "c.(20221-20223)cCt>cTt", "p.P6741L"},
                new Object[]{"MUC16", 19, 9067464, 9067464, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067464C>T", "-", "c.19982G>A", "c.(19981-19983)gGa>gAa", "p.G6661E"},
                new Object[]{"MUC16", 19, 9067484, 9067484, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067484G>A", "-", "c.19962C>T", "c.(19960-19962)tcC>tcT", "p.S6654S"},
                new Object[]{"MUC16", 19, 9067623, 9067623, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067623G>A", "-", "c.19823C>T", "c.(19822-19824)tCg>tTg", "p.S6608L"},
                new Object[]{"MUC16", 19, 9067679, 9067679, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067679G>A", "-", "c.19767C>T", "c.(19765-19767)tcC>tcT", "p.S6589S"},
                new Object[]{"MUC16", 19, 9068061, 9068061, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9068061C>T", "-", "c.19385G>A", "c.(19384-19386)tGg>tAg", "p.W6462*"},
                new Object[]{"MUC16", 19, 9069180, 9069180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069180G>A", "-", "c.18266C>T", "c.(18265-18267)tCa>tTa", "p.S6089L"},
                new Object[]{"MUC16", 19, 9069366, 9069366, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069366G>A", "-", "c.18080C>T", "c.(18079-18081)tCc>tTc", "p.S6027F"},
                new Object[]{"MUC16", 19, 9069622, 9069622, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069622G>A", "-", "c.17824C>T", "c.(17824-17826)Ctt>Ttt", "p.L5942F"},
                new Object[]{"MUC16", 19, 9069754, 9069754, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069754G>A", "-", "c.17692C>T", "c.(17692-17694)Cca>Tca", "p.P5898S"},
                new Object[]{"MUC16", 19, 9069821, 9069821, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069821G>A", "-", "c.17625C>T", "c.(17623-17625)acC>acT", "p.T5875T"},
                new Object[]{"MUC16", 19, 9070255, 9070255, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070255C>T", "-", "c.17191G>A", "c.(17191-17193)Gaa>Aaa", "p.E5731K"},
                new Object[]{"MUC16", 19, 9070360, 9070360, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070360C>T", "-", "c.17086G>A", "c.(17086-17088)Gag>Aag", "p.E5696K"},
                new Object[]{"MUC16", 19, 9070509, 9070509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070509G>A", "-", "c.16937C>T", "c.(16936-16938)tCc>tTc", "p.S5646F"},
                new Object[]{"MUC16", 19, 9070533, 9070533, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070533G>A", "-", "c.16913C>T", "c.(16912-16914)tCc>tTc", "p.S5638F"},
                new Object[]{"MUC16", 19, 9071252, 9071252, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071252G>A", "-", "c.16194C>T", "c.(16192-16194)atC>atT", "p.I5398I"},
                new Object[]{"MUC16", 19, 9071513, 9071513, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071513G>A", "-", "c.15933C>T", "c.(15931-15933)acC>acT", "p.T5311T"},
                new Object[]{"MUC16", 19, 9071765, 9071765, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071765G>A", "-", "c.15681C>T", "c.(15679-15681)gtC>gtT", "p.V5227V"},
                new Object[]{"MUC16", 19, 9071953, 9071953, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071953G>A", "-", "c.15493C>T", "c.(15493-15495)Cct>Tct", "p.P5165S"},
                new Object[]{"MUC16", 19, 9072087, 9072087, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072087G>A", "-", "c.15359C>T", "c.(15358-15360)tCt>tTt", "p.S5120F"},
                new Object[]{"MUC16", 19, 9072128, 9072128, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072128G>A", "-", "c.15318C>T", "c.(15316-15318)gcC>gcT", "p.A5106A"},
                new Object[]{"MUC16", 19, 9072407, 9072407, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072407C>T", "-", "c.15039G>A", "c.(15037-15039)ttG>ttA", "p.L5013L"},
                new Object[]{"MUC16", 19, 9072414, 9072414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072414G>A", "-", "c.15032C>T", "c.(15031-15033)tCa>tTa", "p.S5011L"},
                new Object[]{"MUC16", 19, 9073656, 9073656, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073656G>A", "-", "c.13790C>T", "c.(13789-13791)tCc>tTc", "p.S4597F"},
                new Object[]{"MUC16", 19, 9073721, 9073721, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9073721C>T", "-", "c.13725G>A", "c.(13723-13725)ggG>ggA", "p.G4575G"},
                new Object[]{"MUC16", 19, 9074222, 9074222, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074222G>A", "-", "c.13224C>T", "c.(13222-13224)acC>acT", "p.T4408T"},
                new Object[]{"MUC16", 19, 9074263, 9074263, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9074263C>T", "-", "c.13183G>A", "c.(13183-13185)Gga>Aga", "p.G4395R"},
                new Object[]{"MUC16", 19, 9074867, 9074867, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074867G>A", "-", "c.12579C>T", "c.(12577-12579)ttC>ttT", "p.F4193F"},
                new Object[]{"MUC16", 19, 9074991, 9074991, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074991G>A", "-", "c.12455C>T", "c.(12454-12456)tCt>tTt", "p.S4152F"},
                new Object[]{"MUC16", 19, 9075173, 9075173, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075173C>T", "-", "c.12273G>A", "c.(12271-12273)atG>atA", "p.M4091I"},
                new Object[]{"MUC16", 19, 9075287, 9075287, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075287G>A", "-", "c.12159C>T", "c.(12157-12159)tcC>tcT", "p.S4053S"},
                new Object[]{"MUC16", 19, 9075383, 9075383, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075383G>A", "-", "c.12063C>T", "c.(12061-12063)agC>agT", "p.S4021S"},
                new Object[]{"MUC16", 19, 9075484, 9075484, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9075484C>T", "-", "c.11962G>A", "c.(11962-11964)Gaa>Aaa", "p.E3988K"},
                new Object[]{"MUC16", 19, 9076695, 9076695, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076695G>A", "-", "c.10751C>T", "c.(10750-10752)tCt>tTt", "p.S3584F"},
                new Object[]{"MUC16", 19, 9077159, 9077159, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9077159C>T", "-", "c.10287G>A", "c.(10285-10287)tgG>tgA", "p.W3429*"},
                new Object[]{"MUC16", 19, 9077764, 9077764, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077764G>A", "-", "c.9682C>T", "c.(9682-9684)Cct>Tct", "p.P3228S"},
                new Object[]{"MUC16", 19, 9082364, 9082364, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9082364G>A", "-", "c.9451C>T", "c.(9451-9453)Cct>Tct", "p.P3151S"},
                new Object[]{"MUC16", 19, 9082505, 9082505, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082505C>T", "-", "c.9310G>A", "c.(9310-9312)Gag>Aag", "p.E3104K"},
                new Object[]{"MUC16", 19, 9082626, 9082626, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082626C>T", "-", "c.9189G>A", "c.(9187-9189)agG>agA", "p.R3063R"},
                new Object[]{"MUC16", 19, 9082977, 9082977, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9082977C>T", "-", "c.8838G>A", "c.(8836-8838)aaG>aaA", "p.K2946K"},
                new Object[]{"MUC16", 19, 9083067, 9083067, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083067G>A", "-", "c.8748C>T", "c.(8746-8748)acC>acT", "p.T2916T"},
                new Object[]{"MUC16", 19, 9083611, 9083611, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083611G>A", "-", "c.8204C>T", "c.(8203-8205)cCa>cTa", "p.P2735L"},
                new Object[]{"MUC16", 19, 9083644, 9083644, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083644G>A", "-", "c.8171C>T", "c.(8170-8172)cCt>cTt", "p.P2724L"},
                new Object[]{"MUC16", 19, 9084263, 9084263, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084263C>T", "-", "c.7552G>A", "c.(7552-7554)Ggc>Agc", "p.G2518S"},
                new Object[]{"MUC16", 19, 9084500, 9084500, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084500C>T", "-", "c.7315G>A", "c.(7315-7317)Ggg>Agg", "p.G2439R"},
                new Object[]{"MUC16", 19, 9084665, 9084665, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9084665C>T", "-", "c.7150G>A", "c.(7150-7152)Gat>Aat", "p.D2384N"},
                new Object[]{"MUC16", 19, 9085498, 9085498, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085498G>A", "-", "c.6317C>T", "c.(6316-6318)cCa>cTa", "p.P2106L"},
                new Object[]{"MUC16", 19, 9085504, 9085504, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085504C>T", "-", "c.6311G>A", "c.(6310-6312)aGa>aAa", "p.R2104K"},
                new Object[]{"MUC16", 19, 9085580, 9085580, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9085580C>T", "-", "c.6235G>A", "c.(6235-6237)Ggg>Agg", "p.G2079R"},
                new Object[]{"MUC16", 19, 9085734, 9085734, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085734G>A", "-", "c.6081C>T", "c.(6079-6081)tcC>tcT", "p.S2027S"},
                new Object[]{"MUC16", 19, 9085995, 9085995, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085995G>A", "-", "c.5820C>T", "c.(5818-5820)tcC>tcT", "p.S1940S"},
                new Object[]{"MUC16", 19, 9086464, 9086464, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086464G>A", "-", "c.5351C>T", "c.(5350-5352)tCt>tTt", "p.S1784F"},
                new Object[]{"MUC16", 19, 9086521, 9086521, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086521C>T", "-", "c.5294G>A", "c.(5293-5295)gGc>gAc", "p.G1765D"},
                new Object[]{"MUC16", 19, 9086960, 9086960, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086960C>T", "-", "c.4855G>A", "c.(4855-4857)Gag>Aag", "p.E1619K"},
                new Object[]{"MUC16", 19, 9087344, 9087344, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087344G>A", "-", "c.4471C>T", "c.(4471-4473)Cct>Tct", "p.P1491S"},
                new Object[]{"MUC16", 19, 9087697, 9087697, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087697G>A", "-", "c.4118C>T", "c.(4117-4119)tCa>tTa", "p.S1373L"},
                new Object[]{"MUC16", 19, 9087887, 9087887, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087887G>A", "-", "c.3928C>T", "c.(3928-3930)Cct>Tct", "p.P1310S"},
                new Object[]{"MUC16", 19, 9088430, 9088430, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088430G>A", "-", "c.3385C>T", "c.(3385-3387)Ctg>Ttg", "p.L1129L"},
                new Object[]{"MUC16", 19, 9088726, 9088726, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088726G>A", "-", "c.3089C>T", "c.(3088-3090)cCa>cTa", "p.P1030L"},
                new Object[]{"MUC16", 19, 9088839, 9088839, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088839G>A", "-", "c.2976C>T", "c.(2974-2976)ctC>ctT", "p.L992L"},
                new Object[]{"MUC16", 19, 9089883, 9089883, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9089883C>T", "-", "c.1932G>A", "c.(1930-1932)acG>acA", "p.T644T"},
                new Object[]{"MUC16", 19, 9089917, 9089917, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089917G>A", "-", "c.1898C>T", "c.(1897-1899)tCa>tTa", "p.S633L"},
                new Object[]{"MUC16", 19, 9090556, 9090556, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090556G>A", "-", "c.1259C>T", "c.(1258-1260)aCc>aTc", "p.T420I"},
                new Object[]{"MUC16", 19, 9090630, 9090630, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090630G>A", "-", "c.1185C>T", "c.(1183-1185)acC>acT", "p.T395T"},
                new Object[]{"MUC16", 19, 9091388, 9091388, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091388C>T", "-", "c.427G>A", "c.(427-429)Gaa>Aaa", "p.E143K"},
                new Object[]{"MUC16", 19, 9091556, 9091556, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091556G>A", "-", "c.259C>T", "c.(259-261)Cct>Tct", "p.P87S"},
                new Object[]{"MUC16", 19, 9091567, 9091567, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091567G>A", "-", "c.248C>T", "c.(247-249)tCc>tTc", "p.S83F"},
                new Object[]{"MUC16", 19, 9076527, 9076527, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076527G>A", "-", "c.10919C>T", "c.(10918-10920)aCc>aTc", "p.T3640I"},
                new Object[]{"MUC16", 19, 9071650, 9071650, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9071650C>T", "-", "c.15796G>A", "c.(15796-15798)Gaa>Aaa", "p.E5266K"},
                new Object[]{"MUC16", 19, 9059723, 9059723, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059723G>A", "-", "c.27723C>T", "c.(27721-27723)gtC>gtT", "p.V9241V"},
                new Object[]{"MUC16", 19, 9067233, 9067233, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9067233C>T", "-", "c.20213G>A", "c.(20212-20214)cGa>cAa", "p.R6738Q"},
                new Object[]{"MUC16", 19, 9070090, 9070090, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070090C>T", "-", "c.17356G>A", "c.(17356-17358)Gac>Aac", "p.D5786N"},
                new Object[]{"MUC16", 19, 9072845, 9072845, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9072845C>T", "-", "c.14601G>A", "c.(14599-14601)atG>atA", "p.M4867I"},
                new Object[]{"MUC16", 19, 9076180, 9076180, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9076180C>T", "-", "c.11266G>A", "c.(11266-11268)Ggg>Agg", "p.G3756R"},
                new Object[]{"MUC16", 19, 9056850, 9056850, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9056850G>A", "-", "c.30596C>T", "c.(30595-30597)tCc>tTc", "p.S10199F"},
                new Object[]{"MUC16", 19, 9076539, 9076539, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076539G>A", "-", "c.10907C>T", "c.(10906-10908)aCt>aTt", "p.T3636I"},
                new Object[]{"MUC16", 19, 9089680, 9089680, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089680G>A", "-", "c.2135C>T", "c.(2134-2136)cCa>cTa", "p.P712L"},
                new Object[]{"MUC16", 19, 8999499, 8999499, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8999499C>T", "-", "c.40676G>A", "c.(40675-40677)aGc>aAc", "p.S13559N"},
                new Object[]{"MUC16", 19, 9014198, 9014198, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9014198G>A", "-", "c.38450C>T", "c.(38449-38451)aCc>aTc", "p.T12817I"},
                new Object[]{"MUC16", 19, 9047124, 9047124, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047124G>A", "-", "c.34507C>T", "c.(34507-34509)Ccc>Tcc", "p.P11503S"},
                new Object[]{"MUC16", 19, 9048113, 9048113, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048113G>A", "-", "c.33518C>T", "c.(33517-33519)tCt>tTt", "p.S11173F"},
                new Object[]{"MUC16", 19, 9049971, 9049971, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049971G>A", "-", "c.31660C>T", "c.(31660-31662)Ccc>Tcc", "p.P10554S"},
                new Object[]{"MUC16", 19, 9063387, 9063387, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063387G>A", "-", "c.24059C>T", "c.(24058-24060)tCa>tTa", "p.S8020L"},
                new Object[]{"MUC16", 19, 9063570, 9063570, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9063570C>T", "-", "c.23876G>A", "c.(23875-23877)tGg>tAg", "p.W7959*"},
                new Object[]{"MUC16", 19, 9063956, 9063956, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063956G>A", "-", "c.23490C>T", "c.(23488-23490)acC>acT", "p.T7830T"},
                new Object[]{"MUC16", 19, 9064483, 9064483, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064483G>A", "-", "c.22963C>T", "c.(22963-22965)Cag>Tag", "p.Q7655*"},
                new Object[]{"MUC16", 19, 9070231, 9070231, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070231C>T", "-", "c.17215G>A", "c.(17215-17217)Gat>Aat", "p.D5739N"},
                new Object[]{"MUC16", 19, 9070515, 9070515, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070515G>A", "-", "c.16931C>T", "c.(16930-16932)cCt>cTt", "p.P5644L"},
                new Object[]{"MUC16", 19, 9070955, 9070955, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070955C>T", "-", "c.16491G>A", "c.(16489-16491)aaG>aaA", "p.K5497K"},
                new Object[]{"MUC16", 19, 9074625, 9074625, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074625G>A", "-", "c.12821C>T", "c.(12820-12822)cCa>cTa", "p.P4274L"},
                new Object[]{"MUC16", 19, 9076269, 9076269, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076269G>A", "-", "c.11177C>T", "c.(11176-11178)tCc>tTc", "p.S3726F"},
                new Object[]{"MUC16", 19, 9080501, 9080501, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9080501C>T", "-", "c.9530G>A", "c.(9529-9531)gGa>gAa", "p.G3177E"},
                new Object[]{"MUC16", 19, 9083098, 9083098, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083098G>A", "-", "c.8717C>T", "c.(8716-8718)tCt>tTt", "p.S2906F"},
                new Object[]{"MUC16", 19, 9085435, 9085435, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085435G>A", "-", "c.6380C>T", "c.(6379-6381)tCg>tTg", "p.S2127L"},
                new Object[]{"MUC16", 19, 9085591, 9085591, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085591G>A", "-", "c.6224C>T", "c.(6223-6225)tCa>tTa", "p.S2075L"},
                new Object[]{"MUC16", 19, 9085846, 9085846, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "T", "g.chr19:9085846A>T", "-", "c.5969T>A", "c.(5968-5970)gTt>gAt", "p.V1990D"},
                new Object[]{"MUC16", 19, 9086684, 9086684, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086684C>T", "-", "c.5131G>A", "c.(5131-5133)Gga>Aga", "p.G1711R"},
                new Object[]{"MUC16", 19, 9087601, 9087601, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9087601G>A", "-", "c.4214C>T", "c.(4213-4215)tCa>tTa", "p.S1405L"},
                new Object[]{"MUC16", 19, 9087899, 9087899, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087899C>T", "-", "c.3916G>A", "c.(3916-3918)Gag>Aag", "p.E1306K"},
                new Object[]{"MUC16", 19, 9088159, 9088159, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088159G>A", "-", "c.3656C>T", "c.(3655-3657)cCc>cTc", "p.P1219L"},
                new Object[]{"MUC16", 19, 9089035, 9089035, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089035G>A", "-", "c.2780C>T", "c.(2779-2781)tCa>tTa", "p.S927L"},
                new Object[]{"MUC16", 19, 9091661, 9091661, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091661C>T", "-", "c.154G>A", "c.(154-156)Gaa>Aaa", "p.E52K"},
                new Object[]{"MUC16", 19, 9049259, 9049259, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049259C>A", "-", "c.32372G>T", "c.(32371-32373)cGg>cTg", "p.R10791L"},
                new Object[]{"MUC16", 19, 9050108, 9050108, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050108G>T", "-", "c.31523C>A", "c.(31522-31524)cCc>cAc", "p.P10508H"},
                new Object[]{"MUC16", 19, 9058976, 9058976, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9058976G>T", "-", "c.28470C>A", "c.(28468-28470)ccC>ccA", "p.P9490P"},
                new Object[]{"MUC16", 19, 9064509, 9064509, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064509C>A", "-", "c.22937G>T", "c.(22936-22938)tGg>tTg", "p.W7646L"},
                new Object[]{"MUC16", 19, 9067654, 9067654, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9067654C>A", "-", "c.19792G>T", "c.(19792-19794)Ggg>Tgg", "p.G6598W"},
                new Object[]{"MUC16", 19, 9071966, 9071966, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9071966C>A", "-", "c.15480G>T", "c.(15478-15480)gtG>gtT", "p.V5160V"},
                new Object[]{"MUC16", 19, 9089293, 9089293, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9089293G>T", "-", "c.2522C>A", "c.(2521-2523)cCa>cAa", "p.P841Q"},
                new Object[]{"MUC16", 19, 9090379, 9090379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9090379G>T", "-", "c.1436C>A", "c.(1435-1437)cCa>cAa", "p.P479Q"},
                new Object[]{"MUC16", 19, 8998736, 8998736, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8998736C>T", "-", "c.40847G>A", "c.(40846-40848)gGa>gAa", "p.G13616E"},
                new Object[]{"MUC16", 19, 9006663, 9006663, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9006663C>A", "-", "c.39585G>T", "c.(39583-39585)acG>acT", "p.T13195T"},
                new Object[]{"MUC16", 19, 9064126, 9064126, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064126C>A", "-", "c.23320G>T", "c.(23320-23322)Ggg>Tgg", "p.G7774W"},
                new Object[]{"MUC16", 19, 9070181, 9070181, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9070181C>A", "-", "c.17265G>T", "c.(17263-17265)atG>atT", "p.M5755I"},
                new Object[]{"MUC16", 19, 9077804, 9077804, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077804G>T", "-", "c.9642C>A", "c.(9640-9642)ccC>ccA", "p.P3214P"},
                new Object[]{"MUC16", 19, 9086664, 9086664, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9086664C>A", "-", "c.5151G>T", "c.(5149-5151)aaG>aaT", "p.K1717N"},
                new Object[]{"MUC16", 19, 9088011, 9088011, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088011G>T", "-", "c.3804C>A", "c.(3802-3804)acC>acA", "p.T1268T"},
                new Object[]{"MUC16", 19, 8969281, 8969281, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:8969281C>T", "-", "c.43063G>A", "c.(43063-43065)Gat>Aat", "p.D14355N"},
                new Object[]{"MUC16", 19, 8999489, 8999489, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8999489C>A", "-", "c.40686G>T", "c.(40684-40686)ctG>ctT", "p.L13562L"},
                new Object[]{"MUC16", 19, 9050036, 9050036, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9050036G>T", "-", "c.31595C>A", "c.(31594-31596)cCt>cAt", "p.P10532H"},
                new Object[]{"MUC16", 19, 9050121, 9050121, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050121C>A", "-", "c.31510G>T", "c.(31510-31512)Gga>Tga", "p.G10504*"},
                new Object[]{"MUC16", 19, 9067605, 9067605, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9067605G>T", "-", "c.19841C>A", "c.(19840-19842)tCa>tAa", "p.S6614*"},
                new Object[]{"MUC16", 19, 9087366, 9087366, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9087366C>A", "-", "c.4449G>T", "c.(4447-4449)atG>atT", "p.M1483I"},
                new Object[]{"MUC16", 19, 9008331, 9008331, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9008331C>A", "-", "c.39221G>T", "c.(39220-39222)gGg>gTg", "p.G13074V"},
                new Object[]{"MUC16", 19, 9017469, 9017469, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9017469G>T", "-", "c.37855C>A", "c.(37855-37857)Cgt>Agt", "p.R12619S"},
                new Object[]{"MUC16", 19, 9020025, 9020025, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9020025C>A", "-", "c.37470G>T", "c.(37468-37470)ctG>ctT", "p.L12490L"},
                new Object[]{"MUC16", 19, 9050228, 9050228, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9050228C>A", "-", "c.31403G>T", "c.(31402-31404)gGg>gTg", "p.G10468V"},
                new Object[]{"MUC16", 19, 9061892, 9061892, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9061892G>T", "-", "c.25554C>A", "c.(25552-25554)acC>acA", "p.T8518T"},
                new Object[]{"MUC16", 19, 9063824, 9063824, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9063824G>T", "-", "c.23622C>A", "c.(23620-23622)ccC>ccA", "p.P7874P"},
                new Object[]{"MUC16", 19, 9064143, 9064143, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9064143G>T", "-", "c.23303C>A", "c.(23302-23304)cCt>cAt", "p.P7768H"},
                new Object[]{"MUC16", 19, 9064231, 9064231, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9064231C>A", "-", "c.23215G>T", "c.(23215-23217)Gga>Tga", "p.G7739*"},
                new Object[]{"MUC16", 19, 9065753, 9065753, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9065753C>A", "-", "c.21693G>T", "c.(21691-21693)ttG>ttT", "p.L7231F"},
                new Object[]{"MUC16", 19, 9069935, 9069935, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9069935G>T", "-", "c.17511C>A", "c.(17509-17511)ccC>ccA", "p.P5837P"},
                new Object[]{"MUC16", 19, 9077379, 9077379, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077379C>A", "-", "c.10067G>T", "c.(10066-10068)gGg>gTg", "p.G3356V"},
                new Object[]{"MUC16", 19, 9082426, 9082426, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9082426G>T", "-", "c.9389C>A", "c.(9388-9390)cCc>cAc", "p.P3130H"},
                new Object[]{"MUC16", 19, 9082454, 9082454, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9082454G>T", "-", "c.9361C>A", "c.(9361-9363)Cca>Aca", "p.P3121T"},
                new Object[]{"MUC16", 19, 9088886, 9088886, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088886C>A", "-", "c.2929G>T", "c.(2929-2931)Ggg>Tgg", "p.G977W"},
                new Object[]{"MUC16", 19, 9088900, 9088900, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088900G>T", "-", "c.2915C>A", "c.(2914-2916)cCc>cAc", "p.P972H"},
                new Object[]{"MUC16", 19, 9013882, 9013882, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9013882C>T", "-", "c.38508G>A", "c.(38506-38508)ggG>ggA", "p.G12836G"},
                new Object[]{"MUC16", 19, 9019338, 9019338, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9019338G>A", "-", "c.37549C>T", "c.(37549-37551)Cct>Tct", "p.P12517S"},
                new Object[]{"MUC16", 19, 9045613, 9045613, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9045613G>A", "-", "c.36018C>T", "c.(36016-36018)acC>acT", "p.T12006T"},
                new Object[]{"MUC16", 19, 9045877, 9045877, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9045877C>T", "-", "c.35754G>A", "c.(35752-35754)tgG>tgA", "p.W11918*"},
                new Object[]{"MUC16", 19, 9046043, 9046043, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9046043G>A", "-", "c.35588C>T", "c.(35587-35589)cCa>cTa", "p.P11863L"},
                new Object[]{"MUC16", 19, 9048241, 9048241, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048241G>A", "-", "c.33390C>T", "c.(33388-33390)gcC>gcT", "p.A11130A"},
                new Object[]{"MUC16", 19, 9057093, 9057093, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057093G>A", "-", "c.30353C>T", "c.(30352-30354)tCc>tTc", "p.S10118F"},
                new Object[]{"MUC16", 19, 9060940, 9060940, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9060940G>A", "-", "c.26506C>T", "c.(26506-26508)Cct>Tct", "p.P8836S"},
                new Object[]{"MUC16", 19, 9062601, 9062601, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062601G>A", "-", "c.24845C>T", "c.(24844-24846)tCc>tTc", "p.S8282F"},
                new Object[]{"MUC16", 19, 9063573, 9063573, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063573G>A", "-", "c.23873C>T", "c.(23872-23874)tCa>tTa", "p.S7958L"},
                new Object[]{"MUC16", 19, 9063963, 9063963, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9063963G>A", "-", "c.23483C>T", "c.(23482-23484)tCc>tTc", "p.S7828F"},
                new Object[]{"MUC16", 19, 9067342, 9067342, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067342G>A", "-", "c.20104C>T", "c.(20104-20106)Cca>Tca", "p.P6702S"},
                new Object[]{"MUC16", 19, 9069097, 9069097, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9069097C>T", "-", "c.18349G>A", "c.(18349-18351)Gat>Aat", "p.D6117N"},
                new Object[]{"MUC16", 19, 9070394, 9070394, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9070394C>T", "-", "c.17052G>A", "c.(17050-17052)acG>acA", "p.T5684T"},
                new Object[]{"MUC16", 19, 9071371, 9071371, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071371G>A", "-", "c.16075C>T", "c.(16075-16077)Ccc>Tcc", "p.P5359S"},
                new Object[]{"MUC16", 19, 9071723, 9071723, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9071723G>A", "-", "c.15723C>T", "c.(15721-15723)tcC>tcT", "p.S5241S"},
                new Object[]{"MUC16", 19, 9072091, 9072091, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072091G>A", "-", "c.15355C>T", "c.(15355-15357)Cct>Tct", "p.P5119S"},
                new Object[]{"MUC16", 19, 9072251, 9072251, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072251G>A", "-", "c.15195C>T", "c.(15193-15195)tcC>tcT", "p.S5065S"},
                new Object[]{"MUC16", 19, 9072320, 9072320, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072320G>A", "-", "c.15126C>T", "c.(15124-15126)tcC>tcT", "p.S5042S"},
                new Object[]{"MUC16", 19, 9072763, 9072763, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072763G>A", "-", "c.14683C>T", "c.(14683-14685)Cct>Tct", "p.P4895S"},
                new Object[]{"MUC16", 19, 9073527, 9073527, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9073527G>T", "-", "c.13919C>A", "c.(13918-13920)tCt>tAt", "p.S4640Y"},
                new Object[]{"MUC16", 19, 9073586, 9073586, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073586G>A", "-", "c.13860C>T", "c.(13858-13860)atC>atT", "p.I4620I"},
                new Object[]{"MUC16", 19, 9074665, 9074665, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074665G>A", "-", "c.12781C>T", "c.(12781-12783)Cct>Tct", "p.P4261S"},
                new Object[]{"MUC16", 19, 9075414, 9075414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075414G>A", "-", "c.12032C>T", "c.(12031-12033)tCc>tTc", "p.S4011F"},
                new Object[]{"MUC16", 19, 9077766, 9077766, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077766G>A", "-", "c.9680C>T", "c.(9679-9681)tCt>tTt", "p.S3227F"},
                new Object[]{"MUC16", 19, 9080501, 9080501, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9080501C>T", "-", "c.9530G>A", "c.(9529-9531)gGa>gAa", "p.G3177E"},
                new Object[]{"MUC16", 19, 9083076, 9083076, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083076G>A", "-", "c.8739C>T", "c.(8737-8739)tcC>tcT", "p.S2913S"},
                new Object[]{"MUC16", 19, 9089120, 9089120, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089120G>A", "-", "c.2695C>T", "c.(2695-2697)Ccc>Tcc", "p.P899S"},
                new Object[]{"MUC16", 19, 9089446, 9089446, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089446G>A", "-", "c.2369C>T", "c.(2368-2370)tCc>tTc", "p.S790F"},
                new Object[]{"MUC16", 19, 9089866, 9089866, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089866G>A", "-", "c.1949C>T", "c.(1948-1950)tCc>tTc", "p.S650F"},
                new Object[]{"MUC16", 19, 9089986, 9089986, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089986G>A", "-", "c.1829C>T", "c.(1828-1830)tCa>tTa", "p.S610L"},
                new Object[]{"MUC16", 19, 9090653, 9090653, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090653C>T", "-", "c.1162G>A", "c.(1162-1164)Gaa>Aaa", "p.E388K"},
                new Object[]{"MUC16", 19, 9091052, 9091052, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091052C>T", "-", "c.763G>A", "c.(763-765)Gaa>Aaa", "p.E255K"},
                new Object[]{"MUC16", 19, 9059329, 9059329, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059329G>A", "-", "c.28117C>T", "c.(28117-28119)Cct>Tct", "p.P9373S"},
                new Object[]{"MUC16", 19, 9090179, 9090179, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9090179C>T", "-", "c.1636G>A", "c.(1636-1638)Gag>Aag", "p.E546K"}
                );
    }
    static List<Object[]> provideMnpDataForMuc16_5() {
        return Arrays.asList(
                new Object[]{"MUC16", 19, 9057936, 9057936, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057936G>A", "-", "c.29510C>T", "c.(29509-29511)aCc>aTc", "p.T9837I"},
                new Object[]{"MUC16", 19, 9088904, 9088904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9088904T>C", "-", "c.2911A>G", "c.(2911-2913)Agt>Ggt", "p.S971G"},
                new Object[]{"MUC16", 19, 9046738, 9046738, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9046738C>T", "-", "c.34893G>A", "c.(34891-34893)gtG>gtA", "p.V11631V"},
                new Object[]{"MUC16", 19, 9056720, 9056720, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9056720C>T", "-", "c.30726G>A", "c.(30724-30726)ggG>ggA", "p.G10242G"},
                new Object[]{"MUC16", 19, 9057290, 9057290, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:9057290T>G", "-", "c.30156A>C", "c.(30154-30156)tcA>tcC", "p.S10052S"},
                new Object[]{"MUC16", 19, 9060457, 9060457, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9060457T>C", "-", "c.26989A>G", "c.(26989-26991)Aca>Gca", "p.T8997A"},
                new Object[]{"MUC16", 19, 9065721, 9065721, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9065721G>A", "-", "c.21725C>T", "c.(21724-21726)tCc>tTc", "p.S7242F"},
                new Object[]{"MUC16", 19, 9070856, 9070856, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070856G>A", "-", "c.16590C>T", "c.(16588-16590)tcC>tcT", "p.S5530S"},
                new Object[]{"MUC16", 19, 9073747, 9073747, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9073747G>A", "-", "c.13699C>T", "c.(13699-13701)Cca>Tca", "p.P4567S"},
                new Object[]{"MUC16", 19, 9080519, 9080519, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9080519G>A", "-", "c.9512C>T", "c.(9511-9513)tCa>tTa", "p.S3171L"},
                new Object[]{"MUC16", 19, 9084051, 9084051, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "T", "C", "g.chr19:9084051T>C", "-", "c.7764A>G", "c.(7762-7764)gaA>gaG", "p.E2588E"},
                new Object[]{"MUC16", 19, 9085376, 9085376, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085376G>A", "-", "c.6439C>T", "c.(6439-6441)Cca>Tca", "p.P2147S"},
                new Object[]{"MUC16", 19, 9066695, 9066695, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9066695C>T", "-", "c.20751G>A", "c.(20749-20751)atG>atA", "p.M6917I"},
                new Object[]{"MUC16", 19, 9074139, 9074139, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074139G>A", "-", "c.13307C>T", "c.(13306-13308)cCc>cTc", "p.P4436L"},
                new Object[]{"MUC16", 19, 9005636, 9005636, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9005636C>A", "-", "c.39770G>T", "c.(39769-39771)tGg>tTg", "p.W13257L"},
                new Object[]{"MUC16", 19, 9046005, 9046005, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9046005C>A", "-", "c.35626G>T", "c.(35626-35628)Ggc>Tgc", "p.G11876C"},
                new Object[]{"MUC16", 19, 9049941, 9049941, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9049941C>T", "-", "c.31690G>A", "c.(31690-31692)Gaa>Aaa", "p.E10564K"},
                new Object[]{"MUC16", 19, 9057176, 9057176, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9057176G>T", "-", "c.30270C>A", "c.(30268-30270)acC>acA", "p.T10090T"},
                new Object[]{"MUC16", 19, 9060131, 9060131, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9060131C>T", "-", "c.27315G>A", "c.(27313-27315)ggG>ggA", "p.G9105G"},
                new Object[]{"MUC16", 19, 9062015, 9062015, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9062015C>T", "-", "c.25431G>A", "c.(25429-25431)gcG>gcA", "p.A8477A"},
                new Object[]{"MUC16", 19, 9065364, 9065364, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9065364C>T", "-", "c.22082G>A", "c.(22081-22083)aGa>aAa", "p.R7361K"},
                new Object[]{"MUC16", 19, 9066073, 9066073, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9066073G>A", "-", "c.21373C>T", "c.(21373-21375)Cct>Tct", "p.P7125S"},
                new Object[]{"MUC16", 19, 9069398, 9069398, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9069398C>A", "-", "c.18048G>T", "c.(18046-18048)atG>atT", "p.M6016I"},
                new Object[]{"MUC16", 19, 9072625, 9072625, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9072625G>A", "-", "c.14821C>T", "c.(14821-14823)Cct>Tct", "p.P4941S"},
                new Object[]{"MUC16", 19, 9074658, 9074658, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9074658G>T", "-", "c.12788C>A", "c.(12787-12789)cCa>cAa", "p.P4263Q"},
                new Object[]{"MUC16", 19, 9074867, 9074867, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9074867G>A", "-", "c.12579C>T", "c.(12577-12579)ttC>ttT", "p.F4193F"},
                new Object[]{"MUC16", 19, 9076429, 9076429, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076429G>A", "-", "c.11017C>T", "c.(11017-11019)Ccc>Tcc", "p.P3673S"},
                new Object[]{"MUC16", 19, 9076674, 9076674, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9076674G>A", "-", "c.10772C>T", "c.(10771-10773)tCc>tTc", "p.S3591F"},
                new Object[]{"MUC16", 19, 9077246, 9077246, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9077246G>T", "-", "c.10200C>A", "c.(10198-10200)ccC>ccA", "p.P3400P"},
                new Object[]{"MUC16", 19, 9085579, 9085579, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9085579C>A", "-", "c.6236G>T", "c.(6235-6237)gGg>gTg", "p.G2079V"},
                new Object[]{"MUC16", 19, 9086131, 9086131, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9086131G>A", "-", "c.5684C>T", "c.(5683-5685)tCc>tTc", "p.S1895F"},
                new Object[]{"MUC16", 19, 9088055, 9088055, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088055C>A", "-", "c.3760G>T", "c.(3760-3762)Gga>Tga", "p.G1254*"},
                new Object[]{"MUC16", 19, 9091108, 9091108, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091108G>A", "-", "c.707C>T", "c.(706-708)tCc>tTc", "p.S236F"},
                new Object[]{"MUC16", 19, 9091470, 9091470, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9091470C>T", "-", "c.345G>A", "c.(343-345)agG>agA", "p.R115R"},
                new Object[]{"MUC16", 19, 9088023, 9088023, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9088023G>T", "-", "c.3792C>A", "c.(3790-3792)acC>acA", "p.T1264T"},
                new Object[]{"MUC16", 19, 9073306, 9073306, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9073306C>A", "-", "c.14140G>T", "c.(14140-14142)Ggg>Tgg", "p.G4714W"},
                new Object[]{"MUC16", 19, 8996340, 8996340, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:8996340G>A", "-", "c.41232C>T", "c.(41230-41232)aaC>aaT", "p.N13744N"},
                new Object[]{"MUC16", 19, 9059447, 9059447, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9059447G>A", "-", "c.27999C>T", "c.(27997-27999)atC>atT", "p.I9333I"},
                new Object[]{"MUC16", 19, 9017418, 9017418, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9017418G>A", "-", "c.37906C>T", "c.(37906-37908)Ctg>Ttg", "p.L12636L"},
                new Object[]{"MUC16", 19, 9043442, 9043442, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9043442C>T", "-", "c.36087G>A", "c.(36085-36087)tgG>tgA", "p.W12029*"},
                new Object[]{"MUC16", 19, 9047148, 9047148, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047148G>A", "-", "c.34483C>T", "c.(34483-34485)Cct>Tct", "p.P11495S"},
                new Object[]{"MUC16", 19, 9047352, 9047352, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047352C>T", "-", "c.34279G>A", "c.(34279-34281)Ggt>Agt", "p.G11427S"},
                new Object[]{"MUC16", 19, 9056341, 9056341, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "G", "g.chr19:9056341T>G", "-", "c.31105A>C", "c.(31105-31107)Agc>Cgc", "p.S10369R"},
                new Object[]{"MUC16", 19, 9057364, 9057364, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057364G>A", "-", "c.30082C>T", "c.(30082-30084)Cct>Tct", "p.P10028S"},
                new Object[]{"MUC16", 19, 9059844, 9059844, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "T", "g.chr19:9059844G>T", "-", "c.27602C>A", "c.(27601-27603)cCa>cAa", "p.P9201Q"},
                new Object[]{"MUC16", 19, 9068444, 9068444, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9068444G>A", "-", "c.19002C>T", "c.(19000-19002)atC>atT", "p.I6334I"},
                new Object[]{"MUC16", 19, 9077510, 9077510, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077510G>A", "-", "c.9936C>T", "c.(9934-9936)tcC>tcT", "p.S3312S"},
                new Object[]{"MUC16", 19, 9089000, 9089000, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:9089000T>A", "-", "c.2815A>T", "c.(2815-2817)Ata>Tta", "p.I939L"},
                new Object[]{"MUC16", 19, 9090748, 9090748, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9090748G>A", "-", "c.1067C>T", "c.(1066-1068)tCc>tTc", "p.S356F"},
                new Object[]{"MUC16", 19, 9048527, 9048527, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9048527G>A", "-", "c.33104C>T", "c.(33103-33105)tCa>tTa", "p.S11035L"},
                new Object[]{"MUC16", 19, 9061664, 9061664, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9061664G>A", "-", "c.25782C>T", "c.(25780-25782)ctC>ctT", "p.L8594L"},
                new Object[]{"MUC16", 19, 9064379, 9064379, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9064379G>A", "-", "c.23067C>T", "c.(23065-23067)tcC>tcT", "p.S7689S"},
                new Object[]{"MUC16", 19, 9067623, 9067623, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067623G>A", "-", "c.19823C>T", "c.(19822-19824)tCg>tTg", "p.S6608L"},
                new Object[]{"MUC16", 19, 9069895, 9069895, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9069895G>A", "-", "c.17551C>T", "c.(17551-17553)Cct>Tct", "p.P5851S"},
                new Object[]{"MUC16", 19, 9075928, 9075928, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075928G>A", "-", "c.11518C>T", "c.(11518-11520)Cca>Tca", "p.P3840S"},
                new Object[]{"MUC16", 19, 9087897, 9087897, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9087897C>T", "-", "c.3918G>A", "c.(3916-3918)gaG>gaA", "p.E1306E"},
                new Object[]{"MUC16", 19, 9089422, 9089422, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9089422G>A", "-", "c.2393C>T", "c.(2392-2394)tCa>tTa", "p.S798L"},
                new Object[]{"MUC16", 19, 9020077, 9020077, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9020077C>T", "-", "c.37418G>A", "c.(37417-37419)aGa>aAa", "p.R12473K"},
                new Object[]{"MUC16", 19, 9049206, 9049206, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9049206G>A", "-", "c.32425C>T", "c.(32425-32427)Cga>Tga", "p.R10809*"},
                new Object[]{"MUC16", 19, 9050129, 9050129, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9050129G>A", "-", "c.31502C>T", "c.(31501-31503)cCc>cTc", "p.P10501L"},
                new Object[]{"MUC16", 19, 9057378, 9057378, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9057378G>A", "-", "c.30068C>T", "c.(30067-30069)tCt>tTt", "p.S10023F"},
                new Object[]{"MUC16", 19, 9057632, 9057632, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9057632C>T", "-", "c.29814G>A", "c.(29812-29814)gtG>gtA", "p.V9938V"},
                new Object[]{"MUC16", 19, 9062543, 9062543, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9062543G>A", "-", "c.24903C>T", "c.(24901-24903)aaC>aaT", "p.N8301N"},
                new Object[]{"MUC16", 19, 9073956, 9073956, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "A", "C", "g.chr19:9073956A>C", "-", "c.13490T>G", "c.(13489-13491)tTg>tGg", "p.L4497W"},
                new Object[]{"MUC16", 19, 9086857, 9086857, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9086857C>T", "-", "c.4958G>A", "c.(4957-4959)gGa>gAa", "p.G1653E"},
                new Object[]{"MUC16", 19, 9091108, 9091108, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9091108G>A", "-", "c.707C>T", "c.(706-708)tCc>tTc", "p.S236F"},
                new Object[]{"MUC16", 19, 9047904, 9047904, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9047904C>T", "-", "c.33727G>A", "c.(33727-33729)Ggg>Agg", "p.G11243R"},
                new Object[]{"MUC16", 19, 9075170, 9075170, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9075170G>A", "-", "c.12276C>T", "c.(12274-12276)atC>atT", "p.I4092I"},
                new Object[]{"MUC16", 19, 9077594, 9077594, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9077594G>A", "-", "c.9852C>T", "c.(9850-9852)tcC>tcT", "p.S3284S"},
                new Object[]{"MUC16", 19, 9083160, 9083160, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9083160G>A", "-", "c.8655C>T", "c.(8653-8655)atC>atT", "p.I2885I"},
                new Object[]{"MUC16", 19, 9085017, 9085017, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9085017G>A", "-", "c.6798C>T", "c.(6796-6798)ttC>ttT", "p.F2266F"},
                new Object[]{"MUC16", 19, 9088834, 9088834, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9088834G>A", "-", "c.2981C>T", "c.(2980-2982)gCt>gTt", "p.A994V"},
                new Object[]{"MUC16", 19, 9014700, 9014700, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "T", "g.chr19:9014700C>T", "-", "c.38275G>A", "c.(38275-38277)Gag>Aag", "p.E12759K"},
                new Object[]{"MUC16", 19, 9047714, 9047714, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9047714G>A", "-", "c.33917C>T", "c.(33916-33918)gCc>gTc", "p.A11306V"},
                new Object[]{"MUC16", 19, 9067330, 9067330, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9067330G>A", "-", "c.20116C>T", "c.(20116-20118)Cat>Tat", "p.H6706Y"},
                new Object[]{"MUC16", 19, 9070709, 9070709, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9070709G>A", "-", "c.16737C>T", "c.(16735-16737)atC>atT", "p.I5579I"},
                new Object[]{"MUC16", 19, 9049481, 9049481, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049481C>A", "-", "c.32150G>T", "c.(32149-32151)gGg>gTg", "p.G10717V"},
                new Object[]{"MUC16", 19, 9049481, 9049481, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9049481C>A", "-", "c.32150G>T", "c.(32149-32151)gGg>gTg", "p.G10717V"},
                new Object[]{"MUC16", 19, 9088055, 9088055, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9088055C>A", "-", "c.3760G>T", "c.(3760-3762)Gga>Tga", "p.G1254*"}
        );
    }

    static List<Object[]> provideEdgeCasesForMUC16Data_1() {
        return Arrays.asList(
                new Object[]{"MUC16", 19, 8959608, 8959608, GencodeFuncotation.VariantClassification.NONSTOP, GencodeFuncotation.VariantType.SNP, "T", "A", "g.chr19:8959608T>A", "-", "c.43524A>T", "c.(43522-43524)tgA>tgT", "p.*14508C"},
                new Object[]{"MUC16", 19, 8959609, 8959609, GencodeFuncotation.VariantClassification.NONSTOP, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8959609C>A", "-", "c.43523G>T", "c.(43522-43524)tGa>tTa", "p.*14508L"},
                new Object[]{"MUC16", 19, 8959610, 8959610, GencodeFuncotation.VariantClassification.NONSTOP, GencodeFuncotation.VariantType.SNP, "A", "G", "g.chr19:8959610A>G", "-", "c.43522T>C", "c.(43522-43524)Tga>Cga", "p.*14508R"},
                new Object[]{"MUC16", 19, 9069475, 9069475, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9069475C>A", "-", "c.17971G>T", "c.(17971-17973)Ggt>Tgt", "p.G5991C"},
                new Object[]{"MUC16", 19, 9069850, 9069850, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9069850C>A", "-", "c.17596G>T", "c.(17596-17598)Ggt>Tgt", "p.G5866C"},
                new Object[]{"MUC16", 19, 9072272, 9072273, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9072272_9072273GG>AA", "-", "c.15173_15174CC>TT", "c.(15172-15174)aCC>aTT", "p.T5058I"},
                new Object[]{"MUC16", 19, 9071877, 9071878, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9071877_9071878GG>AA", "-", "c.15568_15569CC>TT", "c.(15568-15570)CCt>TTt", "p.P5190F"},
                new Object[]{"MUC16", 19, 9062258, 9062259, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9062258_9062259GG>AA", "-", "c.25187_25188CC>TT", "c.(25186-25188)tCC>tTT", "p.S8396F"},
                new Object[]{"MUC16", 19, 8997168, 8997169, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CT", "TA", "g.chr19:8997168_8997169CT>TA", "-", "c.41027_41028AG>TA", "c.(41026-41028)aAG>aTA", "p.K13676I"},
                new Object[]{"MUC16", 19, 9071830, 9071831, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9071830_9071831CC>TT", "-", "c.15615_15616GG>AA", "c.(15613-15618)acGGac>acAAac", "p.D5206N"},
                new Object[]{"MUC16", 19, 9046744, 9046745, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9046744_9046745CC>TT", "-", "c.34886_34887GG>AA", "c.(34885-34887)gGG>gAA", "p.G11629E"},
                new Object[]{"MUC16", 19, 9056775, 9056776, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9056775_9056776GG>AA", "-", "c.30670_30671CC>TT", "c.(30670-30672)CCa>TTa", "p.P10224L"},
                new Object[]{"MUC16", 19, 8996321, 8996321, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8996321C>A", "-", "c.41251G>T", "c.(41251-41253)Ggt>Tgt", "p.G13751C"},
                new Object[]{"MUC16", 19, 9065944, 9065945, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9065944_9065945CC>TT", "-", "c.21501_21502GG>AA", "c.(21499-21504)aaGGac>aaAAac", "p.D7168N"},
                new Object[]{"MUC16", 19, 9046027, 9046028, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9046027_9046028GG>AA", "-", "c.35603_35604CC>TT", "c.(35602-35604)tCC>tTT", "p.S11868F"},
                new Object[]{"MUC16", 19, 9063951, 9063952, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9063951_9063952CC>TT", "-", "c.23494_23495GG>AA", "c.(23494-23496)GGa>AAa", "p.G7832K"},

                // Check the case that our input ref allele is NOT the same as the reference genome:
                new Object[]{"MUC16", 19, 8996322, 8996322, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:8996322C>A", "-", "c.41250G>T", "c.(41248-41250)aaG>aaT", "p.K13750N"},

                new Object[]{"MUC16", 19, 9005204, 9005205, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9005204_9005205GG>AA", "-", "c.39872_39873CC>TT", "c.(39871-39873)cCC>cTT", "p.P13291L"},
                new Object[]{"MUC16", 19, 9008192, 9008193, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9008192_9008193CC>TT", "-", "c.39359_39360GG>AA", "c.(39358-39360)cGG>cAA", "p.R13120Q"},
                new Object[]{"MUC16", 19, 8999533, 8999534, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:8999533_8999534CC>TT", "-", "c.40641_40642GG>AA", "c.(40639-40644)gtGGat>gtAAat", "p.D13548N"},
                new Object[]{"MUC16", 19, 9086951, 9086952, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9086951_9086952GG>AA", "-", "c.4863_4864CC>TT", "c.(4861-4866)ggCCca>ggTTca", "p.P1622S"},
                new Object[]{"MUC16", 19, 9067646, 9067647, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9067646_9067647GG>AA", "-", "c.19799_19800CC>TT", "c.(19798-19800)aCC>aTT", "p.T6600I"},
                new Object[]{"MUC16", 19, 9018197, 9018197, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9018197C>A", "-", "c.37741G>T", "c.(37741-37743)Ggt>Tgt", "p.G12581C"},
                new Object[]{"MUC16", 19, 9075993, 9075994, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9075993_9075994GG>AA", "-", "c.11452_11453CC>TT", "c.(11452-11454)CCc>TTc", "p.P3818F"},
                new Object[]{"MUC16", 19, 9011398, 9011398, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9011398C>A", "-", "c.38835G>T", "c.(38833-38835)tgG>tgT", "p.W12945C"},
                new Object[]{"MUC16", 19, 9075413, 9075414, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9075413_9075414GG>AA", "-", "c.12032_12033CC>TT", "c.(12031-12033)tCC>tTT", "p.S4011F"},
                new Object[]{"MUC16", 19, 9091429, 9091430, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9091429_9091430GG>AA", "-", "c.385_386CC>TT", "c.(385-387)CCa>TTa", "p.P129L"},
                new Object[]{"MUC16", 19, 9068060, 9068060, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9068060C>A", "-", "c.19386G>T", "c.(19384-19386)tgG>tgT", "p.W6462C"},
                new Object[]{"MUC16", 19, 9008173, 9008173, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9008173C>A", "-", "c.39379G>T", "c.(39379-39381)Ggt>Tgt", "p.G13127C"},
                new Object[]{"MUC16", 19, 9077267, 9077267, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9077267C>A", "-", "c.10179G>T", "c.(10177-10179)tgG>tgT", "p.W3393C"},
                new Object[]{"MUC16", 19, 9070016, 9070017, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "AG", "GT", "g.chr19:9070016_9070017AG>GT", "-", "c.17429_17430CT>AC", "c.(17428-17430)aCT>aAC", "p.T5810N"},
                new Object[]{"MUC16", 19, 9011322, 9011322, GencodeFuncotation.VariantClassification.SPLICE_SITE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9011322C>A", "-", "c.38911G>T", "c.(38911-38913)Ggt>Tgt", "p.G12971C"},
                new Object[]{"MUC16", 19, 9048762, 9048762, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9048762C>A", "-", "c.32869G>T", "c.(32869-32871)Ggt>Tgt", "p.G10957C"},
                new Object[]{"MUC16", 19, 9074546, 9074547, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CT", "TA", "g.chr19:9074546_9074547CT>TA", "-", "c.12899_12900AG>TA", "c.(12898-12900)gAG>gTA", "p.E4300V"},
                new Object[]{"MUC16", 19, 9070072, 9070073, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9070072_9070073CC>TT", "-", "c.17373_17374GG>AA", "c.(17371-17376)gaGGag>gaAAag", "p.E5792K"},
                new Object[]{"MUC16", 19, 9073561, 9073562, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9073561_9073562CC>TT", "-", "c.13884_13885GG>AA", "c.(13882-13887)ggGGct>ggAAct", "p.A4629T"},
                new Object[]{"MUC16", 19, 9076249, 9076250, GencodeFuncotation.VariantClassification.SILENT, GencodeFuncotation.VariantType.DNP, "GA", "AT", "g.chr19:9076249_9076250GA>AT", "-", "c.11196_11197TC>AT", "c.(11194-11199)tcTCtg>tcATtg", "p.S3732S"},
                new Object[]{"MUC16", 19, 9070072, 9070073, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9070072_9070073CC>TT", "-", "c.17373_17374GG>AA", "c.(17371-17376)gaGGag>gaAAag", "p.E5792K"},
                new Object[]{"MUC16", 19, 9073561, 9073562, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "TT", "g.chr19:9073561_9073562CC>TT", "-", "c.13884_13885GG>AA", "c.(13882-13887)ggGGct>ggAAct", "p.A4629T"},
                new Object[]{"MUC16", 19, 9059696, 9059697, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9059696_9059697GG>AA", "-", "c.27749_27750CC>TT", "c.(27748-27750)gCC>gTT", "p.A9250V"},
                new Object[]{"MUC16", 19, 9059503, 9059503, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "C", "A", "g.chr19:9059503C>A", "-", "c.27943G>T", "c.(27943-27945)Ggt>Tgt", "p.G9315C"},
                new Object[]{"MUC16", 19, 9009652, 9009653, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "AT", "g.chr19:9009652_9009653CC>AT", "-", "c.39073_39074GG>AT", "c.(39073-39075)GGg>ATg", "p.G13025M"},
                new Object[]{"MUC16", 19, 9002624, 9002624, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.SNP, "G", "A", "g.chr19:9002624G>A", "-", "c.40192C>T", "c.(40192-40194)Cgt>Tgt", "p.R13398C"},
                new Object[]{"MUC16", 19, 9064314, 9064315, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "GG", "AA", "g.chr19:9064314_9064315GG>AA", "-", "c.23131_23132CC>TT", "c.(23131-23133)CCc>TTc", "p.P7711F"},

                new Object[]{"MUC16", 19, 9049481, 9049482, GencodeFuncotation.VariantClassification.MISSENSE, GencodeFuncotation.VariantType.DNP, "CC", "AA", "g.chr19:9049481_9049482CC>AA", "-", "c.32149_32150GG>TT", "c.(32149-32151)GGg>TTg", "p.G10717L"},
                new Object[]{"MUC16", 19, 9088055, 9088056, GencodeFuncotation.VariantClassification.NONSENSE, GencodeFuncotation.VariantType.DNP, "CG", "AT", "g.chr19:9088055_9088056CG>AT", "-", "c.3759_3760CG>AT", "c.(3757-3762)ctCGga>ctATga", "p.G1254*"}
                );
    }
}
